/*
 * @(#)TychoIndex.java
 *
 * Copyright (C) 1997-2007 Seiichi Yoshida
 * All rights reserved.
 */

package net.aerith.misao.catalog.io;
import java.io.*;
import java.net.*;
import java.util.Vector;
import net.aerith.misao.util.*;
import net.aerith.misao.util.star.*;
import net.aerith.misao.catalog.*;
import net.aerith.misao.catalog.star.*;

/**
 * The <code>TychoIndex</code> represents the index to read the Tycho
 * Catalogue.
 *
 * @author  Seiichi Yoshida (comet@aerith.net)
 * @version 2003 May 19
 */

public class TychoIndex {
	/**
	 * The smallest R.A. in degree of the block.
	 */
	public static int[] ra_start;

	/**
	 * The largest R.A. in degree of the block.
	 */
	public static int[] ra_end;

	/**
	 * The smallest Decl. in degree of the block.
	 */
	public static int[] decl_start;

	/**
	 * The largest Decl. in degree of the block.
	 */
	public static int[] decl_end;

	/**
	 * Initializes the R.A. of each blocks.
	 */
	private final static void initialize_ra ( ) {
		ra_start[0] = 0;
		ra_end[0] = 8;
		ra_start[1] = 2;
		ra_end[1] = 15;
		ra_start[2] = 7;
		ra_end[2] = 23;
		ra_start[3] = 15;
		ra_end[3] = 24;
		ra_start[4] = 22;
		ra_end[4] = 30;
		ra_start[5] = 22;
		ra_end[5] = 38;
		ra_start[6] = 30;
		ra_end[6] = 45;
		ra_start[7] = 37;
		ra_end[7] = 50;
		ra_start[8] = 45;
		ra_end[8] = 53;
		ra_start[9] = 50;
		ra_end[9] = 60;
		ra_start[10] = 55;
		ra_end[10] = 68;
		ra_start[11] = 60;
		ra_end[11] = 74;
		ra_start[12] = 67;
		ra_end[12] = 75;
		ra_start[13] = 67;
		ra_end[13] = 77;
		ra_start[14] = 75;
		ra_end[14] = 83;
		ra_start[15] = 75;
		ra_end[15] = 83;
		ra_start[16] = 75;
		ra_end[16] = 83;
		ra_start[17] = 77;
		ra_end[17] = 89;
		ra_start[18] = 82;
		ra_end[18] = 90;
		ra_start[19] = 82;
		ra_end[19] = 92;
		ra_start[20] = 90;
		ra_end[20] = 98;
		ra_start[21] = 90;
		ra_end[21] = 98;
		ra_start[22] = 90;
		ra_end[22] = 98;
		ra_start[23] = 95;
		ra_end[23] = 104;
		ra_start[24] = 97;
		ra_end[24] = 105;
		ra_start[25] = 97;
		ra_end[25] = 105;
		ra_start[26] = 97;
		ra_end[26] = 105;
		ra_start[27] = 97;
		ra_end[27] = 107;
		ra_start[28] = 105;
		ra_end[28] = 113;
		ra_start[29] = 105;
		ra_end[29] = 113;
		ra_start[30] = 105;
		ra_end[30] = 113;
		ra_start[31] = 105;
		ra_end[31] = 113;
		ra_start[32] = 108;
		ra_end[32] = 119;
		ra_start[33] = 112;
		ra_end[33] = 120;
		ra_start[34] = 112;
		ra_end[34] = 120;
		ra_start[35] = 112;
		ra_end[35] = 124;
		ra_start[36] = 120;
		ra_end[36] = 128;
		ra_start[37] = 120;
		ra_end[37] = 128;
		ra_start[38] = 120;
		ra_end[38] = 134;
		ra_start[39] = 127;
		ra_end[39] = 135;
		ra_start[40] = 127;
		ra_end[40] = 135;
		ra_start[41] = 133;
		ra_end[41] = 143;
		ra_start[42] = 135;
		ra_end[42] = 148;
		ra_start[43] = 142;
		ra_end[43] = 150;
		ra_start[44] = 147;
		ra_end[44] = 158;
		ra_start[45] = 150;
		ra_end[45] = 165;
		ra_start[46] = 157;
		ra_end[46] = 173;
		ra_start[47] = 165;
		ra_end[47] = 180;
		ra_start[48] = 172;
		ra_end[48] = 185;
		ra_start[49] = 180;
		ra_end[49] = 188;
		ra_start[50] = 185;
		ra_end[50] = 195;
		ra_start[51] = 190;
		ra_end[51] = 203;
		ra_start[52] = 195;
		ra_end[52] = 210;
		ra_start[53] = 202;
		ra_end[53] = 215;
		ra_start[54] = 210;
		ra_end[54] = 218;
		ra_start[55] = 215;
		ra_end[55] = 225;
		ra_start[56] = 218;
		ra_end[56] = 233;
		ra_start[57] = 225;
		ra_end[57] = 240;
		ra_start[58] = 232;
		ra_end[58] = 244;
		ra_start[59] = 240;
		ra_end[59] = 248;
		ra_start[60] = 240;
		ra_end[60] = 255;
		ra_start[61] = 247;
		ra_end[61] = 255;
		ra_start[62] = 247;
		ra_end[62] = 257;
		ra_start[63] = 255;
		ra_end[63] = 263;
		ra_start[64] = 255;
		ra_end[64] = 263;
		ra_start[65] = 258;
		ra_end[65] = 270;
		ra_start[66] = 262;
		ra_end[66] = 270;
		ra_start[67] = 262;
		ra_end[67] = 270;
		ra_start[68] = 266;
		ra_end[68] = 278;
		ra_start[69] = 270;
		ra_end[69] = 278;
		ra_start[70] = 270;
		ra_end[70] = 278;
		ra_start[71] = 271;
		ra_end[71] = 284;
		ra_start[72] = 277;
		ra_end[72] = 285;
		ra_start[73] = 277;
		ra_end[73] = 285;
		ra_start[74] = 279;
		ra_end[74] = 291;
		ra_start[75] = 285;
		ra_end[75] = 293;
		ra_start[76] = 285;
		ra_end[76] = 293;
		ra_start[77] = 284;
		ra_end[77] = 297;
		ra_start[78] = 292;
		ra_end[78] = 300;
		ra_start[79] = 292;
		ra_end[79] = 300;
		ra_start[80] = 292;
		ra_end[80] = 300;
		ra_start[81] = 298;
		ra_end[81] = 308;
		ra_start[82] = 300;
		ra_end[82] = 308;
		ra_start[83] = 300;
		ra_end[83] = 308;
		ra_start[84] = 300;
		ra_end[84] = 308;
		ra_start[85] = 305;
		ra_end[85] = 315;
		ra_start[86] = 307;
		ra_end[86] = 315;
		ra_start[87] = 307;
		ra_end[87] = 315;
		ra_start[88] = 307;
		ra_end[88] = 319;
		ra_start[89] = 315;
		ra_end[89] = 323;
		ra_start[90] = 315;
		ra_end[90] = 329;
		ra_start[91] = 322;
		ra_end[91] = 330;
		ra_start[92] = 322;
		ra_end[92] = 338;
		ra_start[93] = 330;
		ra_end[93] = 338;
		ra_start[94] = 335;
		ra_end[94] = 345;
		ra_start[95] = 337;
		ra_end[95] = 353;
		ra_start[96] = 345;
		ra_end[96] = 358;
		ra_start[97] = 352;
		ra_end[97] = 360;
		ra_start[98] = 0;
		ra_end[98] = 360;
		ra_start[99] = 0;
		ra_end[99] = 16;
		ra_start[100] = 7;
		ra_end[100] = 21;
		ra_start[101] = 15;
		ra_end[101] = 23;
		ra_start[102] = 20;
		ra_end[102] = 31;
		ra_start[103] = 22;
		ra_end[103] = 39;
		ra_start[104] = 30;
		ra_end[104] = 46;
		ra_start[105] = 38;
		ra_end[105] = 54;
		ra_start[106] = 45;
		ra_end[106] = 62;
		ra_start[107] = 53;
		ra_end[107] = 69;
		ra_start[108] = 61;
		ra_end[108] = 71;
		ra_start[109] = 68;
		ra_end[109] = 77;
		ra_start[110] = 68;
		ra_end[110] = 77;
		ra_start[111] = 76;
		ra_end[111] = 85;
		ra_start[112] = 76;
		ra_end[112] = 85;
		ra_start[113] = 76;
		ra_end[113] = 92;
		ra_start[114] = 84;
		ra_end[114] = 92;
		ra_start[115] = 84;
		ra_end[115] = 92;
		ra_start[116] = 86;
		ra_end[116] = 96;
		ra_start[117] = 91;
		ra_end[117] = 100;
		ra_start[118] = 91;
		ra_end[118] = 100;
		ra_start[119] = 91;
		ra_end[119] = 100;
		ra_start[120] = 91;
		ra_end[120] = 104;
		ra_start[121] = 99;
		ra_end[121] = 108;
		ra_start[122] = 99;
		ra_end[122] = 108;
		ra_start[123] = 99;
		ra_end[123] = 108;
		ra_start[124] = 99;
		ra_end[124] = 110;
		ra_start[125] = 107;
		ra_end[125] = 115;
		ra_start[126] = 107;
		ra_end[126] = 115;
		ra_start[127] = 107;
		ra_end[127] = 115;
		ra_start[128] = 111;
		ra_end[128] = 123;
		ra_start[129] = 114;
		ra_end[129] = 123;
		ra_start[130] = 114;
		ra_end[130] = 123;
		ra_start[131] = 120;
		ra_end[131] = 131;
		ra_start[132] = 122;
		ra_end[132] = 131;
		ra_start[133] = 122;
		ra_end[133] = 136;
		ra_start[134] = 130;
		ra_end[134] = 138;
		ra_start[135] = 130;
		ra_end[135] = 146;
		ra_start[136] = 137;
		ra_end[136] = 146;
		ra_start[137] = 143;
		ra_end[137] = 154;
		ra_start[138] = 145;
		ra_end[138] = 161;
		ra_start[139] = 153;
		ra_end[139] = 169;
		ra_start[140] = 160;
		ra_end[140] = 174;
		ra_start[141] = 168;
		ra_end[141] = 179;
		ra_start[142] = 176;
		ra_end[142] = 184;
		ra_start[143] = 181;
		ra_end[143] = 192;
		ra_start[144] = 184;
		ra_end[144] = 200;
		ra_start[145] = 191;
		ra_end[145] = 207;
		ra_start[146] = 199;
		ra_end[146] = 215;
		ra_start[147] = 206;
		ra_end[147] = 218;
		ra_start[148] = 214;
		ra_end[148] = 223;
		ra_start[149] = 219;
		ra_end[149] = 230;
		ra_start[150] = 224;
		ra_end[150] = 238;
		ra_start[151] = 230;
		ra_end[151] = 246;
		ra_start[152] = 237;
		ra_end[152] = 246;
		ra_start[153] = 245;
		ra_end[153] = 253;
		ra_start[154] = 245;
		ra_end[154] = 253;
		ra_start[155] = 248;
		ra_end[155] = 261;
		ra_start[156] = 252;
		ra_end[156] = 261;
		ra_start[157] = 252;
		ra_end[157] = 265;
		ra_start[158] = 260;
		ra_end[158] = 269;
		ra_start[159] = 260;
		ra_end[159] = 269;
		ra_start[160] = 260;
		ra_end[160] = 272;
		ra_start[161] = 268;
		ra_end[161] = 276;
		ra_start[162] = 268;
		ra_end[162] = 276;
		ra_start[163] = 268;
		ra_end[163] = 276;
		ra_start[164] = 270;
		ra_end[164] = 278;
		ra_start[165] = 275;
		ra_end[165] = 284;
		ra_start[166] = 275;
		ra_end[166] = 284;
		ra_start[167] = 275;
		ra_end[167] = 284;
		ra_start[168] = 275;
		ra_end[168] = 288;
		ra_start[169] = 283;
		ra_end[169] = 292;
		ra_start[170] = 283;
		ra_end[170] = 292;
		ra_start[171] = 283;
		ra_end[171] = 292;
		ra_start[172] = 289;
		ra_end[172] = 299;
		ra_start[173] = 291;
		ra_end[173] = 299;
		ra_start[174] = 291;
		ra_end[174] = 299;
		ra_start[175] = 291;
		ra_end[175] = 299;
		ra_start[176] = 291;
		ra_end[176] = 299;
		ra_start[177] = 296;
		ra_end[177] = 305;
		ra_start[178] = 298;
		ra_end[178] = 307;
		ra_start[179] = 298;
		ra_end[179] = 307;
		ra_start[180] = 298;
		ra_end[180] = 307;
		ra_start[181] = 298;
		ra_end[181] = 307;
		ra_start[182] = 304;
		ra_end[182] = 315;
		ra_start[183] = 306;
		ra_end[183] = 315;
		ra_start[184] = 306;
		ra_end[184] = 315;
		ra_start[185] = 306;
		ra_end[185] = 315;
		ra_start[186] = 312;
		ra_end[186] = 322;
		ra_start[187] = 314;
		ra_end[187] = 322;
		ra_start[188] = 314;
		ra_end[188] = 328;
		ra_start[189] = 321;
		ra_end[189] = 330;
		ra_start[190] = 321;
		ra_end[190] = 337;
		ra_start[191] = 329;
		ra_end[191] = 338;
		ra_start[192] = 331;
		ra_end[192] = 345;
		ra_start[193] = 337;
		ra_end[193] = 347;
		ra_start[194] = 344;
		ra_end[194] = 353;
		ra_start[195] = 344;
		ra_end[195] = 360;
		ra_start[196] = 0;
		ra_end[196] = 360;
		ra_start[197] = 0;
		ra_end[197] = 8;
		ra_start[198] = 0;
		ra_end[198] = 16;
		ra_start[199] = 8;
		ra_end[199] = 16;
		ra_start[200] = 13;
		ra_end[200] = 24;
		ra_start[201] = 16;
		ra_end[201] = 32;
		ra_start[202] = 24;
		ra_end[202] = 35;
		ra_start[203] = 32;
		ra_end[203] = 40;
		ra_start[204] = 37;
		ra_end[204] = 48;
		ra_start[205] = 40;
		ra_end[205] = 56;
		ra_start[206] = 48;
		ra_end[206] = 60;
		ra_start[207] = 56;
		ra_end[207] = 64;
		ra_start[208] = 60;
		ra_end[208] = 72;
		ra_start[209] = 64;
		ra_end[209] = 76;
		ra_start[210] = 72;
		ra_end[210] = 80;
		ra_start[211] = 72;
		ra_end[211] = 86;
		ra_start[212] = 80;
		ra_end[212] = 88;
		ra_start[213] = 80;
		ra_end[213] = 88;
		ra_start[214] = 80;
		ra_end[214] = 90;
		ra_start[215] = 88;
		ra_end[215] = 96;
		ra_start[216] = 88;
		ra_end[216] = 96;
		ra_start[217] = 88;
		ra_end[217] = 96;
		ra_start[218] = 88;
		ra_end[218] = 96;
		ra_start[219] = 94;
		ra_end[219] = 104;
		ra_start[220] = 96;
		ra_end[220] = 104;
		ra_start[221] = 96;
		ra_end[221] = 104;
		ra_start[222] = 96;
		ra_end[222] = 106;
		ra_start[223] = 104;
		ra_end[223] = 112;
		ra_start[224] = 104;
		ra_end[224] = 112;
		ra_start[225] = 104;
		ra_end[225] = 112;
		ra_start[226] = 108;
		ra_end[226] = 120;
		ra_start[227] = 112;
		ra_end[227] = 120;
		ra_start[228] = 112;
		ra_end[228] = 121;
		ra_start[229] = 120;
		ra_end[229] = 128;
		ra_start[230] = 120;
		ra_end[230] = 128;
		ra_start[231] = 124;
		ra_end[231] = 136;
		ra_start[232] = 128;
		ra_end[232] = 136;
		ra_start[233] = 130;
		ra_end[233] = 144;
		ra_start[234] = 136;
		ra_end[234] = 150;
		ra_start[235] = 144;
		ra_end[235] = 152;
		ra_start[236] = 149;
		ra_end[236] = 160;
		ra_start[237] = 152;
		ra_end[237] = 168;
		ra_start[238] = 160;
		ra_end[238] = 176;
		ra_start[239] = 168;
		ra_end[239] = 184;
		ra_start[240] = 176;
		ra_end[240] = 192;
		ra_start[241] = 184;
		ra_end[241] = 200;
		ra_start[242] = 192;
		ra_end[242] = 208;
		ra_start[243] = 200;
		ra_end[243] = 211;
		ra_start[244] = 208;
		ra_end[244] = 216;
		ra_start[245] = 210;
		ra_end[245] = 224;
		ra_start[246] = 216;
		ra_end[246] = 232;
		ra_start[247] = 224;
		ra_end[247] = 240;
		ra_start[248] = 232;
		ra_end[248] = 244;
		ra_start[249] = 240;
		ra_end[249] = 249;
		ra_start[250] = 240;
		ra_end[250] = 256;
		ra_start[251] = 248;
		ra_end[251] = 256;
		ra_start[252] = 248;
		ra_end[252] = 260;
		ra_start[253] = 256;
		ra_end[253] = 264;
		ra_start[254] = 256;
		ra_end[254] = 264;
		ra_start[255] = 256;
		ra_end[255] = 268;
		ra_start[256] = 264;
		ra_end[256] = 272;
		ra_start[257] = 264;
		ra_end[257] = 272;
		ra_start[258] = 264;
		ra_end[258] = 274;
		ra_start[259] = 272;
		ra_end[259] = 280;
		ra_start[260] = 272;
		ra_end[260] = 280;
		ra_start[261] = 272;
		ra_end[261] = 280;
		ra_start[262] = 272;
		ra_end[262] = 280;
		ra_start[263] = 278;
		ra_end[263] = 288;
		ra_start[264] = 280;
		ra_end[264] = 288;
		ra_start[265] = 280;
		ra_end[265] = 288;
		ra_start[266] = 280;
		ra_end[266] = 290;
		ra_start[267] = 288;
		ra_end[267] = 296;
		ra_start[268] = 288;
		ra_end[268] = 296;
		ra_start[269] = 288;
		ra_end[269] = 296;
		ra_start[270] = 288;
		ra_end[270] = 298;
		ra_start[271] = 296;
		ra_end[271] = 304;
		ra_start[272] = 296;
		ra_end[272] = 304;
		ra_start[273] = 296;
		ra_end[273] = 304;
		ra_start[274] = 296;
		ra_end[274] = 304;
		ra_start[275] = 296;
		ra_end[275] = 304;
		ra_start[276] = 300;
		ra_end[276] = 306;
		ra_start[277] = 304;
		ra_end[277] = 312;
		ra_start[278] = 304;
		ra_end[278] = 312;
		ra_start[279] = 304;
		ra_end[279] = 310;
		ra_start[280] = 304;
		ra_end[280] = 312;
		ra_start[281] = 308;
		ra_end[281] = 316;
		ra_start[282] = 312;
		ra_end[282] = 320;
		ra_start[283] = 312;
		ra_end[283] = 320;
		ra_start[284] = 312;
		ra_end[284] = 320;
		ra_start[285] = 316;
		ra_end[285] = 328;
		ra_start[286] = 320;
		ra_end[286] = 328;
		ra_start[287] = 322;
		ra_end[287] = 336;
		ra_start[288] = 328;
		ra_end[288] = 336;
		ra_start[289] = 328;
		ra_end[289] = 344;
		ra_start[290] = 336;
		ra_end[290] = 344;
		ra_start[291] = 336;
		ra_end[291] = 352;
		ra_start[292] = 344;
		ra_end[292] = 352;
		ra_start[293] = 349;
		ra_end[293] = 360;
		ra_start[294] = 0;
		ra_end[294] = 360;
		ra_start[295] = 0;
		ra_end[295] = 9;
		ra_start[296] = 0;
		ra_end[296] = 11;
		ra_start[297] = 8;
		ra_end[297] = 17;
		ra_start[298] = 8;
		ra_end[298] = 23;
		ra_start[299] = 16;
		ra_end[299] = 26;
		ra_start[300] = 19;
		ra_end[300] = 34;
		ra_start[301] = 25;
		ra_end[301] = 38;
		ra_start[302] = 33;
		ra_end[302] = 42;
		ra_start[303] = 33;
		ra_end[303] = 51;
		ra_start[304] = 41;
		ra_end[304] = 51;
		ra_start[305] = 48;
		ra_end[305] = 59;
		ra_start[306] = 50;
		ra_end[306] = 59;
		ra_start[307] = 54;
		ra_end[307] = 67;
		ra_start[308] = 58;
		ra_end[308] = 76;
		ra_start[309] = 66;
		ra_end[309] = 78;
		ra_start[310] = 75;
		ra_end[310] = 84;
		ra_start[311] = 75;
		ra_end[311] = 86;
		ra_start[312] = 83;
		ra_end[312] = 93;
		ra_start[313] = 83;
		ra_end[313] = 93;
		ra_start[314] = 83;
		ra_end[314] = 93;
		ra_start[315] = 83;
		ra_end[315] = 95;
		ra_start[316] = 92;
		ra_end[316] = 101;
		ra_start[317] = 92;
		ra_end[317] = 101;
		ra_start[318] = 92;
		ra_end[318] = 101;
		ra_start[319] = 92;
		ra_end[319] = 103;
		ra_start[320] = 100;
		ra_end[320] = 109;
		ra_start[321] = 100;
		ra_end[321] = 109;
		ra_start[322] = 100;
		ra_end[322] = 109;
		ra_start[323] = 103;
		ra_end[323] = 116;
		ra_start[324] = 108;
		ra_end[324] = 118;
		ra_start[325] = 108;
		ra_end[325] = 120;
		ra_start[326] = 117;
		ra_end[326] = 126;
		ra_start[327] = 117;
		ra_end[327] = 126;
		ra_start[328] = 121;
		ra_end[328] = 134;
		ra_start[329] = 125;
		ra_end[329] = 134;
		ra_start[330] = 131;
		ra_end[330] = 143;
		ra_start[331] = 133;
		ra_end[331] = 151;
		ra_start[332] = 142;
		ra_end[332] = 154;
		ra_start[333] = 150;
		ra_end[333] = 160;
		ra_start[334] = 153;
		ra_end[334] = 168;
		ra_start[335] = 159;
		ra_end[335] = 176;
		ra_start[336] = 167;
		ra_end[336] = 185;
		ra_start[337] = 175;
		ra_end[337] = 193;
		ra_start[338] = 184;
		ra_end[338] = 201;
		ra_start[339] = 192;
		ra_end[339] = 207;
		ra_start[340] = 200;
		ra_end[340] = 210;
		ra_start[341] = 206;
		ra_end[341] = 218;
		ra_start[342] = 212;
		ra_end[342] = 226;
		ra_start[343] = 217;
		ra_end[343] = 235;
		ra_start[344] = 226;
		ra_end[344] = 241;
		ra_start[345] = 234;
		ra_end[345] = 243;
		ra_start[346] = 237;
		ra_end[346] = 252;
		ra_start[347] = 242;
		ra_end[347] = 252;
		ra_start[348] = 251;
		ra_end[348] = 260;
		ra_start[349] = 251;
		ra_end[349] = 260;
		ra_start[350] = 253;
		ra_end[350] = 268;
		ra_start[351] = 259;
		ra_end[351] = 268;
		ra_start[352] = 259;
		ra_end[352] = 268;
		ra_start[353] = 263;
		ra_end[353] = 277;
		ra_start[354] = 267;
		ra_end[354] = 277;
		ra_start[355] = 267;
		ra_end[355] = 277;
		ra_start[356] = 270;
		ra_end[356] = 279;
		ra_start[357] = 276;
		ra_end[357] = 285;
		ra_start[358] = 276;
		ra_end[358] = 285;
		ra_start[359] = 276;
		ra_end[359] = 285;
		ra_start[360] = 276;
		ra_end[360] = 285;
		ra_start[361] = 280;
		ra_end[361] = 291;
		ra_start[362] = 284;
		ra_end[362] = 293;
		ra_start[363] = 284;
		ra_end[363] = 294;
		ra_start[364] = 284;
		ra_end[364] = 294;
		ra_start[365] = 284;
		ra_end[365] = 293;
		ra_start[366] = 290;
		ra_end[366] = 300;
		ra_start[367] = 293;
		ra_end[367] = 302;
		ra_start[368] = 293;
		ra_end[368] = 302;
		ra_start[369] = 293;
		ra_end[369] = 302;
		ra_start[370] = 293;
		ra_end[370] = 302;
		ra_start[371] = 295;
		ra_end[371] = 302;
		ra_start[372] = 299;
		ra_end[372] = 306;
		ra_start[373] = 301;
		ra_end[373] = 310;
		ra_start[374] = 301;
		ra_end[374] = 310;
		ra_start[375] = 301;
		ra_end[375] = 310;
		ra_start[376] = 301;
		ra_end[376] = 310;
		ra_start[377] = 303;
		ra_end[377] = 310;
		ra_start[378] = 307;
		ra_end[378] = 319;
		ra_start[379] = 309;
		ra_end[379] = 319;
		ra_start[380] = 309;
		ra_end[380] = 319;
		ra_start[381] = 309;
		ra_end[381] = 319;
		ra_start[382] = 313;
		ra_end[382] = 325;
		ra_start[383] = 318;
		ra_end[383] = 327;
		ra_start[384] = 318;
		ra_end[384] = 327;
		ra_start[385] = 318;
		ra_end[385] = 329;
		ra_start[386] = 326;
		ra_end[386] = 335;
		ra_start[387] = 326;
		ra_end[387] = 335;
		ra_start[388] = 328;
		ra_end[388] = 344;
		ra_start[389] = 334;
		ra_end[389] = 344;
		ra_start[390] = 334;
		ra_end[390] = 344;
		ra_start[391] = 341;
		ra_end[391] = 352;
		ra_start[392] = 343;
		ra_end[392] = 352;
		ra_start[393] = 343;
		ra_end[393] = 360;
		ra_start[394] = 351;
		ra_end[394] = 360;
		ra_start[395] = 0;
		ra_end[395] = 360;
		ra_start[396] = 0;
		ra_end[396] = 9;
		ra_start[397] = 0;
		ra_end[397] = 12;
		ra_start[398] = 9;
		ra_end[398] = 18;
		ra_start[399] = 9;
		ra_end[399] = 21;
		ra_start[400] = 18;
		ra_end[400] = 27;
		ra_start[401] = 18;
		ra_end[401] = 27;
		ra_start[402] = 20;
		ra_end[402] = 36;
		ra_start[403] = 27;
		ra_end[403] = 36;
		ra_start[404] = 27;
		ra_end[404] = 45;
		ra_start[405] = 36;
		ra_end[405] = 45;
		ra_start[406] = 36;
		ra_end[406] = 50;
		ra_start[407] = 45;
		ra_end[407] = 54;
		ra_start[408] = 45;
		ra_end[408] = 61;
		ra_start[409] = 54;
		ra_end[409] = 63;
		ra_start[410] = 54;
		ra_end[410] = 66;
		ra_start[411] = 63;
		ra_end[411] = 72;
		ra_start[412] = 63;
		ra_end[412] = 75;
		ra_start[413] = 72;
		ra_end[413] = 81;
		ra_start[414] = 72;
		ra_end[414] = 81;
		ra_start[415] = 72;
		ra_end[415] = 84;
		ra_start[416] = 81;
		ra_end[416] = 90;
		ra_start[417] = 81;
		ra_end[417] = 90;
		ra_start[418] = 81;
		ra_end[418] = 90;
		ra_start[419] = 81;
		ra_end[419] = 90;
		ra_start[420] = 81;
		ra_end[420] = 93;
		ra_start[421] = 90;
		ra_end[421] = 99;
		ra_start[422] = 90;
		ra_end[422] = 99;
		ra_start[423] = 90;
		ra_end[423] = 99;
		ra_start[424] = 94;
		ra_end[424] = 108;
		ra_start[425] = 99;
		ra_end[425] = 108;
		ra_start[426] = 99;
		ra_end[426] = 108;
		ra_start[427] = 103;
		ra_end[427] = 117;
		ra_start[428] = 108;
		ra_end[428] = 117;
		ra_start[429] = 108;
		ra_end[429] = 124;
		ra_start[430] = 117;
		ra_end[430] = 126;
		ra_start[431] = 117;
		ra_end[431] = 132;
		ra_start[432] = 126;
		ra_end[432] = 135;
		ra_start[433] = 126;
		ra_end[433] = 144;
		ra_start[434] = 135;
		ra_end[434] = 144;
		ra_start[435] = 141;
		ra_end[435] = 153;
		ra_start[436] = 144;
		ra_end[436] = 162;
		ra_start[437] = 152;
		ra_end[437] = 167;
		ra_start[438] = 162;
		ra_end[438] = 171;
		ra_start[439] = 166;
		ra_end[439] = 180;
		ra_start[440] = 175;
		ra_end[440] = 189;
		ra_start[441] = 184;
		ra_end[441] = 198;
		ra_start[442] = 189;
		ra_end[442] = 207;
		ra_start[443] = 198;
		ra_end[443] = 213;
		ra_start[444] = 207;
		ra_end[444] = 216;
		ra_start[445] = 210;
		ra_end[445] = 225;
		ra_start[446] = 216;
		ra_end[446] = 234;
		ra_start[447] = 225;
		ra_end[447] = 234;
		ra_start[448] = 231;
		ra_end[448] = 243;
		ra_start[449] = 234;
		ra_end[449] = 249;
		ra_start[450] = 243;
		ra_end[450] = 252;
		ra_start[451] = 243;
		ra_end[451] = 261;
		ra_start[452] = 252;
		ra_end[452] = 261;
		ra_start[453] = 252;
		ra_end[453] = 265;
		ra_start[454] = 261;
		ra_end[454] = 270;
		ra_start[455] = 261;
		ra_end[455] = 270;
		ra_start[456] = 261;
		ra_end[456] = 275;
		ra_start[457] = 270;
		ra_end[457] = 279;
		ra_start[458] = 270;
		ra_end[458] = 279;
		ra_start[459] = 270;
		ra_end[459] = 279;
		ra_start[460] = 272;
		ra_end[460] = 284;
		ra_start[461] = 281;
		ra_end[461] = 288;
		ra_start[462] = 279;
		ra_end[462] = 288;
		ra_start[463] = 279;
		ra_end[463] = 288;
		ra_start[464] = 279;
		ra_end[464] = 288;
		ra_start[465] = 279;
		ra_end[465] = 291;
		ra_start[466] = 288;
		ra_end[466] = 295;
		ra_start[467] = 292;
		ra_end[467] = 297;
		ra_start[468] = 288;
		ra_end[468] = 297;
		ra_start[469] = 290;
		ra_end[469] = 297;
		ra_start[470] = 288;
		ra_end[470] = 297;
		ra_start[471] = 288;
		ra_end[471] = 297;
		ra_start[472] = 288;
		ra_end[472] = 295;
		ra_start[473] = 292;
		ra_end[473] = 300;
		ra_start[474] = 297;
		ra_end[474] = 304;
		ra_start[475] = 301;
		ra_end[475] = 306;
		ra_start[476] = 297;
		ra_end[476] = 306;
		ra_start[477] = 299;
		ra_end[477] = 306;
		ra_start[478] = 297;
		ra_end[478] = 306;
		ra_start[479] = 299;
		ra_end[479] = 306;
		ra_start[480] = 297;
		ra_end[480] = 306;
		ra_start[481] = 299;
		ra_end[481] = 304;
		ra_start[482] = 301;
		ra_end[482] = 309;
		ra_start[483] = 306;
		ra_end[483] = 313;
		ra_start[484] = 306;
		ra_end[484] = 315;
		ra_start[485] = 308;
		ra_end[485] = 315;
		ra_start[486] = 306;
		ra_end[486] = 315;
		ra_start[487] = 308;
		ra_end[487] = 315;
		ra_start[488] = 306;
		ra_end[488] = 315;
		ra_start[489] = 308;
		ra_end[489] = 315;
		ra_start[490] = 312;
		ra_end[490] = 322;
		ra_start[491] = 315;
		ra_end[491] = 324;
		ra_start[492] = 315;
		ra_end[492] = 324;
		ra_start[493] = 315;
		ra_end[493] = 321;
		ra_start[494] = 315;
		ra_end[494] = 324;
		ra_start[495] = 315;
		ra_end[495] = 322;
		ra_start[496] = 320;
		ra_end[496] = 331;
		ra_start[497] = 324;
		ra_end[497] = 333;
		ra_start[498] = 324;
		ra_end[498] = 333;
		ra_start[499] = 324;
		ra_end[499] = 333;
		ra_start[500] = 328;
		ra_end[500] = 342;
		ra_start[501] = 333;
		ra_end[501] = 342;
		ra_start[502] = 333;
		ra_end[502] = 342;
		ra_start[503] = 335;
		ra_end[503] = 349;
		ra_start[504] = 342;
		ra_end[504] = 351;
		ra_start[505] = 342;
		ra_end[505] = 351;
		ra_start[506] = 344;
		ra_end[506] = 360;
		ra_start[507] = 351;
		ra_end[507] = 360;
		ra_start[508] = 351;
		ra_end[508] = 360;
		ra_start[509] = 0;
		ra_end[509] = 360;
		ra_start[510] = 0;
		ra_end[510] = 10;
		ra_start[511] = 0;
		ra_end[511] = 10;
		ra_start[512] = 5;
		ra_end[512] = 20;
		ra_start[513] = 10;
		ra_end[513] = 20;
		ra_start[514] = 10;
		ra_end[514] = 20;
		ra_start[515] = 17;
		ra_end[515] = 30;
		ra_start[516] = 20;
		ra_end[516] = 30;
		ra_start[517] = 20;
		ra_end[517] = 30;
		ra_start[518] = 25;
		ra_end[518] = 38;
		ra_start[519] = 30;
		ra_end[519] = 40;
		ra_start[520] = 30;
		ra_end[520] = 40;
		ra_start[521] = 30;
		ra_end[521] = 40;
		ra_start[522] = 37;
		ra_end[522] = 50;
		ra_start[523] = 40;
		ra_end[523] = 50;
		ra_start[524] = 40;
		ra_end[524] = 50;
		ra_start[525] = 40;
		ra_end[525] = 53;
		ra_start[526] = 50;
		ra_end[526] = 60;
		ra_start[527] = 50;
		ra_end[527] = 60;
		ra_start[528] = 50;
		ra_end[528] = 60;
		ra_start[529] = 52;
		ra_end[529] = 70;
		ra_start[530] = 60;
		ra_end[530] = 70;
		ra_start[531] = 60;
		ra_end[531] = 70;
		ra_start[532] = 66;
		ra_end[532] = 80;
		ra_start[533] = 70;
		ra_end[533] = 80;
		ra_start[534] = 70;
		ra_end[534] = 80;
		ra_start[535] = 70;
		ra_end[535] = 80;
		ra_start[536] = 72;
		ra_end[536] = 83;
		ra_start[537] = 80;
		ra_end[537] = 90;
		ra_start[538] = 80;
		ra_end[538] = 90;
		ra_start[539] = 80;
		ra_end[539] = 90;
		ra_start[540] = 80;
		ra_end[540] = 90;
		ra_start[541] = 87;
		ra_end[541] = 100;
		ra_start[542] = 90;
		ra_end[542] = 100;
		ra_start[543] = 90;
		ra_end[543] = 100;
		ra_start[544] = 92;
		ra_end[544] = 108;
		ra_start[545] = 100;
		ra_end[545] = 110;
		ra_start[546] = 100;
		ra_end[546] = 110;
		ra_start[547] = 103;
		ra_end[547] = 120;
		ra_start[548] = 110;
		ra_end[548] = 120;
		ra_start[549] = 110;
		ra_end[549] = 127;
		ra_start[550] = 120;
		ra_end[550] = 130;
		ra_start[551] = 120;
		ra_end[551] = 137;
		ra_start[552] = 130;
		ra_end[552] = 140;
		ra_start[553] = 130;
		ra_end[553] = 150;
		ra_start[554] = 140;
		ra_end[554] = 153;
		ra_start[555] = 150;
		ra_end[555] = 160;
		ra_start[556] = 150;
		ra_end[556] = 170;
		ra_start[557] = 160;
		ra_end[557] = 175;
		ra_start[558] = 170;
		ra_end[558] = 180;
		ra_start[559] = 171;
		ra_end[559] = 190;
		ra_start[560] = 180;
		ra_end[560] = 200;
		ra_start[561] = 190;
		ra_end[561] = 207;
		ra_start[562] = 200;
		ra_end[562] = 210;
		ra_start[563] = 206;
		ra_end[563] = 220;
		ra_start[564] = 210;
		ra_end[564] = 230;
		ra_start[565] = 220;
		ra_end[565] = 237;
		ra_start[566] = 230;
		ra_end[566] = 240;
		ra_start[567] = 230;
		ra_end[567] = 250;
		ra_start[568] = 240;
		ra_end[568] = 250;
		ra_start[569] = 246;
		ra_end[569] = 260;
		ra_start[570] = 250;
		ra_end[570] = 260;
		ra_start[571] = 250;
		ra_end[571] = 268;
		ra_start[572] = 260;
		ra_end[572] = 270;
		ra_start[573] = 260;
		ra_end[573] = 270;
		ra_start[574] = 262;
		ra_end[574] = 278;
		ra_start[575] = 270;
		ra_end[575] = 280;
		ra_start[576] = 270;
		ra_end[576] = 280;
		ra_start[577] = 270;
		ra_end[577] = 280;
		ra_start[578] = 277;
		ra_end[578] = 290;
		ra_start[579] = 280;
		ra_end[579] = 290;
		ra_start[580] = 280;
		ra_end[580] = 290;
		ra_start[581] = 280;
		ra_end[581] = 290;
		ra_start[582] = 282;
		ra_end[582] = 293;
		ra_start[583] = 290;
		ra_end[583] = 298;
		ra_start[584] = 290;
		ra_end[584] = 300;
		ra_start[585] = 290;
		ra_end[585] = 298;
		ra_start[586] = 290;
		ra_end[586] = 300;
		ra_start[587] = 290;
		ra_end[587] = 298;
		ra_start[588] = 290;
		ra_end[588] = 300;
		ra_start[589] = 292;
		ra_end[589] = 303;
		ra_start[590] = 300;
		ra_end[590] = 308;
		ra_start[591] = 305;
		ra_end[591] = 310;
		ra_start[592] = 300;
		ra_end[592] = 310;
		ra_start[593] = 302;
		ra_end[593] = 310;
		ra_start[594] = 300;
		ra_end[594] = 310;
		ra_start[595] = 302;
		ra_end[595] = 310;
		ra_start[596] = 300;
		ra_end[596] = 310;
		ra_start[597] = 305;
		ra_end[597] = 313;
		ra_start[598] = 310;
		ra_end[598] = 318;
		ra_start[599] = 310;
		ra_end[599] = 320;
		ra_start[600] = 310;
		ra_end[600] = 320;
		ra_start[601] = 310;
		ra_end[601] = 320;
		ra_start[602] = 310;
		ra_end[602] = 320;
		ra_start[603] = 310;
		ra_end[603] = 320;
		ra_start[604] = 317;
		ra_end[604] = 328;
		ra_start[605] = 320;
		ra_end[605] = 330;
		ra_start[606] = 320;
		ra_end[606] = 330;
		ra_start[607] = 320;
		ra_end[607] = 330;
		ra_start[608] = 320;
		ra_end[608] = 330;
		ra_start[609] = 322;
		ra_end[609] = 333;
		ra_start[610] = 330;
		ra_end[610] = 340;
		ra_start[611] = 330;
		ra_end[611] = 340;
		ra_start[612] = 330;
		ra_end[612] = 340;
		ra_start[613] = 330;
		ra_end[613] = 340;
		ra_start[614] = 335;
		ra_end[614] = 348;
		ra_start[615] = 340;
		ra_end[615] = 350;
		ra_start[616] = 340;
		ra_end[616] = 350;
		ra_start[617] = 340;
		ra_end[617] = 350;
		ra_start[618] = 347;
		ra_end[618] = 360;
		ra_start[619] = 350;
		ra_end[619] = 360;
		ra_start[620] = 350;
		ra_end[620] = 360;
		ra_start[621] = 0;
		ra_end[621] = 360;
		ra_start[622] = 0;
		ra_end[622] = 12;
		ra_start[623] = 0;
		ra_end[623] = 12;
		ra_start[624] = 0;
		ra_end[624] = 12;
		ra_start[625] = 0;
		ra_end[625] = 12;
		ra_start[626] = 8;
		ra_end[626] = 23;
		ra_start[627] = 11;
		ra_end[627] = 23;
		ra_start[628] = 11;
		ra_end[628] = 23;
		ra_start[629] = 11;
		ra_end[629] = 23;
		ra_start[630] = 16;
		ra_end[630] = 29;
		ra_start[631] = 22;
		ra_end[631] = 34;
		ra_start[632] = 22;
		ra_end[632] = 34;
		ra_start[633] = 25;
		ra_end[633] = 34;
		ra_start[634] = 22;
		ra_end[634] = 34;
		ra_start[635] = 28;
		ra_end[635] = 40;
		ra_start[636] = 33;
		ra_end[636] = 45;
		ra_start[637] = 33;
		ra_end[637] = 45;
		ra_start[638] = 33;
		ra_end[638] = 45;
		ra_start[639] = 33;
		ra_end[639] = 45;
		ra_start[640] = 33;
		ra_end[640] = 48;
		ra_start[641] = 45;
		ra_end[641] = 57;
		ra_start[642] = 45;
		ra_end[642] = 57;
		ra_start[643] = 45;
		ra_end[643] = 57;
		ra_start[644] = 45;
		ra_end[644] = 57;
		ra_start[645] = 53;
		ra_end[645] = 68;
		ra_start[646] = 56;
		ra_end[646] = 68;
		ra_start[647] = 56;
		ra_end[647] = 68;
		ra_start[648] = 59;
		ra_end[648] = 76;
		ra_start[649] = 67;
		ra_end[649] = 79;
		ra_start[650] = 67;
		ra_end[650] = 79;
		ra_start[651] = 67;
		ra_end[651] = 82;
		ra_start[652] = 78;
		ra_end[652] = 90;
		ra_start[653] = 78;
		ra_end[653] = 90;
		ra_start[654] = 78;
		ra_end[654] = 93;
		ra_start[655] = 90;
		ra_end[655] = 102;
		ra_start[656] = 90;
		ra_end[656] = 102;
		ra_start[657] = 90;
		ra_end[657] = 104;
		ra_start[658] = 101;
		ra_end[658] = 113;
		ra_start[659] = 101;
		ra_end[659] = 113;
		ra_start[660] = 101;
		ra_end[660] = 124;
		ra_start[661] = 112;
		ra_end[661] = 124;
		ra_start[662] = 116;
		ra_end[662] = 135;
		ra_start[663] = 123;
		ra_end[663] = 139;
		ra_start[664] = 135;
		ra_end[664] = 147;
		ra_start[665] = 135;
		ra_end[665] = 154;
		ra_start[666] = 146;
		ra_end[666] = 158;
		ra_start[667] = 150;
		ra_end[667] = 169;
		ra_start[668] = 157;
		ra_end[668] = 175;
		ra_start[669] = 168;
		ra_end[669] = 180;
		ra_start[670] = 174;
		ra_end[670] = 192;
		ra_start[671] = 180;
		ra_end[671] = 203;
		ra_start[672] = 191;
		ra_end[672] = 210;
		ra_start[673] = 202;
		ra_end[673] = 214;
		ra_start[674] = 206;
		ra_end[674] = 225;
		ra_start[675] = 213;
		ra_end[675] = 237;
		ra_start[676] = 225;
		ra_end[676] = 237;
		ra_start[677] = 232;
		ra_end[677] = 248;
		ra_start[678] = 236;
		ra_end[678] = 248;
		ra_start[679] = 244;
		ra_end[679] = 259;
		ra_start[680] = 247;
		ra_end[680] = 259;
		ra_start[681] = 255;
		ra_end[681] = 270;
		ra_start[682] = 258;
		ra_end[682] = 270;
		ra_start[683] = 258;
		ra_end[683] = 279;
		ra_start[684] = 270;
		ra_end[684] = 282;
		ra_start[685] = 270;
		ra_end[685] = 282;
		ra_start[686] = 270;
		ra_end[686] = 285;
		ra_start[687] = 281;
		ra_end[687] = 293;
		ra_start[688] = 281;
		ra_end[688] = 293;
		ra_start[689] = 281;
		ra_end[689] = 293;
		ra_start[690] = 281;
		ra_end[690] = 293;
		ra_start[691] = 290;
		ra_end[691] = 301;
		ra_start[692] = 292;
		ra_end[692] = 304;
		ra_start[693] = 295;
		ra_end[693] = 304;
		ra_start[694] = 292;
		ra_end[694] = 304;
		ra_start[695] = 292;
		ra_end[695] = 304;
		ra_start[696] = 295;
		ra_end[696] = 307;
		ra_start[697] = 303;
		ra_end[697] = 313;
		ra_start[698] = 303;
		ra_end[698] = 315;
		ra_start[699] = 303;
		ra_end[699] = 313;
		ra_start[700] = 303;
		ra_end[700] = 315;
		ra_start[701] = 304;
		ra_end[701] = 315;
		ra_start[702] = 303;
		ra_end[702] = 313;
		ra_start[703] = 309;
		ra_end[703] = 320;
		ra_start[704] = 317;
		ra_end[704] = 327;
		ra_start[705] = 315;
		ra_end[705] = 327;
		ra_start[706] = 317;
		ra_end[706] = 327;
		ra_start[707] = 315;
		ra_end[707] = 327;
		ra_start[708] = 315;
		ra_end[708] = 327;
		ra_start[709] = 317;
		ra_end[709] = 327;
		ra_start[710] = 323;
		ra_end[710] = 332;
		ra_start[711] = 326;
		ra_end[711] = 338;
		ra_start[712] = 326;
		ra_end[712] = 335;
		ra_start[713] = 326;
		ra_end[713] = 338;
		ra_start[714] = 326;
		ra_end[714] = 335;
		ra_start[715] = 326;
		ra_end[715] = 338;
		ra_start[716] = 326;
		ra_end[716] = 335;
		ra_start[717] = 331;
		ra_end[717] = 341;
		ra_start[718] = 337;
		ra_end[718] = 346;
		ra_start[719] = 337;
		ra_end[719] = 349;
		ra_start[720] = 337;
		ra_end[720] = 349;
		ra_start[721] = 337;
		ra_end[721] = 346;
		ra_start[722] = 337;
		ra_end[722] = 349;
		ra_start[723] = 340;
		ra_end[723] = 352;
		ra_start[724] = 348;
		ra_end[724] = 360;
		ra_start[725] = 348;
		ra_end[725] = 360;
		ra_start[726] = 348;
		ra_end[726] = 360;
		ra_start[727] = 348;
		ra_end[727] = 360;
		ra_start[728] = 0;
		ra_end[728] = 360;
		ra_start[729] = 0;
		ra_end[729] = 10;
		ra_start[730] = 0;
		ra_end[730] = 14;
		ra_start[731] = 0;
		ra_end[731] = 14;
		ra_start[732] = 0;
		ra_end[732] = 14;
		ra_start[733] = 0;
		ra_end[733] = 14;
		ra_start[734] = 0;
		ra_end[734] = 14;
		ra_start[735] = 10;
		ra_end[735] = 20;
		ra_start[736] = 13;
		ra_end[736] = 27;
		ra_start[737] = 13;
		ra_end[737] = 24;
		ra_start[738] = 13;
		ra_end[738] = 27;
		ra_start[739] = 13;
		ra_end[739] = 24;
		ra_start[740] = 13;
		ra_end[740] = 27;
		ra_start[741] = 16;
		ra_end[741] = 27;
		ra_start[742] = 23;
		ra_end[742] = 34;
		ra_start[743] = 26;
		ra_end[743] = 40;
		ra_start[744] = 26;
		ra_end[744] = 37;
		ra_start[745] = 26;
		ra_end[745] = 40;
		ra_start[746] = 26;
		ra_end[746] = 37;
		ra_start[747] = 33;
		ra_end[747] = 40;
		ra_start[748] = 26;
		ra_end[748] = 40;
		ra_start[749] = 30;
		ra_end[749] = 40;
		ra_start[750] = 36;
		ra_end[750] = 54;
		ra_start[751] = 40;
		ra_end[751] = 54;
		ra_start[752] = 40;
		ra_end[752] = 54;
		ra_start[753] = 46;
		ra_end[753] = 64;
		ra_start[754] = 53;
		ra_end[754] = 67;
		ra_start[755] = 53;
		ra_end[755] = 67;
		ra_start[756] = 60;
		ra_end[756] = 80;
		ra_start[757] = 66;
		ra_end[757] = 80;
		ra_start[758] = 66;
		ra_end[758] = 84;
		ra_start[759] = 80;
		ra_end[759] = 94;
		ra_start[760] = 80;
		ra_end[760] = 94;
		ra_start[761] = 83;
		ra_end[761] = 104;
		ra_start[762] = 93;
		ra_end[762] = 107;
		ra_start[763] = 93;
		ra_end[763] = 107;
		ra_start[764] = 100;
		ra_end[764] = 120;
		ra_start[765] = 106;
		ra_end[765] = 120;
		ra_start[766] = 106;
		ra_end[766] = 132;
		ra_start[767] = 120;
		ra_end[767] = 134;
		ra_start[768] = 124;
		ra_end[768] = 147;
		ra_start[769] = 133;
		ra_end[769] = 152;
		ra_start[770] = 146;
		ra_end[770] = 160;
		ra_start[771] = 146;
		ra_end[771] = 174;
		ra_start[772] = 160;
		ra_end[772] = 178;
		ra_start[773] = 173;
		ra_end[773] = 187;
		ra_start[774] = 173;
		ra_end[774] = 200;
		ra_start[775] = 186;
		ra_end[775] = 207;
		ra_start[776] = 200;
		ra_end[776] = 214;
		ra_start[777] = 209;
		ra_end[777] = 227;
		ra_start[778] = 213;
		ra_end[778] = 236;
		ra_start[779] = 226;
		ra_end[779] = 240;
		ra_start[780] = 231;
		ra_end[780] = 254;
		ra_start[781] = 240;
		ra_end[781] = 254;
		ra_start[782] = 248;
		ra_end[782] = 267;
		ra_start[783] = 253;
		ra_end[783] = 267;
		ra_start[784] = 256;
		ra_end[784] = 280;
		ra_start[785] = 266;
		ra_end[785] = 280;
		ra_start[786] = 266;
		ra_end[786] = 280;
		ra_start[787] = 273;
		ra_end[787] = 290;
		ra_start[788] = 280;
		ra_end[788] = 294;
		ra_start[789] = 280;
		ra_end[789] = 294;
		ra_start[790] = 280;
		ra_end[790] = 294;
		ra_start[791] = 286;
		ra_end[791] = 300;
		ra_start[792] = 293;
		ra_end[792] = 307;
		ra_start[793] = 293;
		ra_end[793] = 307;
		ra_start[794] = 293;
		ra_end[794] = 307;
		ra_start[795] = 293;
		ra_end[795] = 307;
		ra_start[796] = 296;
		ra_end[796] = 310;
		ra_start[797] = 306;
		ra_end[797] = 321;
		ra_start[798] = 306;
		ra_end[798] = 320;
		ra_start[799] = 306;
		ra_end[799] = 320;
		ra_start[800] = 306;
		ra_end[800] = 324;
		ra_start[801] = 320;
		ra_end[801] = 330;
		ra_start[802] = 320;
		ra_end[802] = 334;
		ra_start[803] = 320;
		ra_end[803] = 334;
		ra_start[804] = 320;
		ra_end[804] = 334;
		ra_start[805] = 320;
		ra_end[805] = 334;
		ra_start[806] = 326;
		ra_end[806] = 339;
		ra_start[807] = 336;
		ra_end[807] = 347;
		ra_start[808] = 333;
		ra_end[808] = 347;
		ra_start[809] = 336;
		ra_end[809] = 347;
		ra_start[810] = 333;
		ra_end[810] = 347;
		ra_start[811] = 337;
		ra_end[811] = 347;
		ra_start[812] = 333;
		ra_end[812] = 347;
		ra_start[813] = 343;
		ra_end[813] = 354;
		ra_start[814] = 350;
		ra_end[814] = 360;
		ra_start[815] = 346;
		ra_end[815] = 360;
		ra_start[816] = 347;
		ra_end[816] = 360;
		ra_start[817] = 346;
		ra_end[817] = 360;
		ra_start[818] = 346;
		ra_end[818] = 360;
		ra_start[819] = 0;
		ra_end[819] = 360;
		ra_start[820] = 4;
		ra_end[820] = 18;
		ra_start[821] = 0;
		ra_end[821] = 18;
		ra_start[822] = 0;
		ra_end[822] = 18;
		ra_start[823] = 0;
		ra_end[823] = 18;
		ra_start[824] = 0;
		ra_end[824] = 22;
		ra_start[825] = 19;
		ra_end[825] = 30;
		ra_start[826] = 17;
		ra_end[826] = 35;
		ra_start[827] = 18;
		ra_end[827] = 35;
		ra_start[828] = 17;
		ra_end[828] = 35;
		ra_start[829] = 17;
		ra_end[829] = 39;
		ra_start[830] = 34;
		ra_end[830] = 52;
		ra_start[831] = 34;
		ra_end[831] = 52;
		ra_start[832] = 34;
		ra_end[832] = 52;
		ra_start[833] = 34;
		ra_end[833] = 54;
		ra_start[834] = 51;
		ra_end[834] = 69;
		ra_start[835] = 51;
		ra_end[835] = 69;
		ra_start[836] = 51;
		ra_end[836] = 69;
		ra_start[837] = 64;
		ra_end[837] = 86;
		ra_start[838] = 68;
		ra_end[838] = 86;
		ra_start[839] = 68;
		ra_end[839] = 86;
		ra_start[840] = 81;
		ra_end[840] = 103;
		ra_start[841] = 85;
		ra_end[841] = 103;
		ra_start[842] = 85;
		ra_end[842] = 108;
		ra_start[843] = 102;
		ra_end[843] = 120;
		ra_start[844] = 102;
		ra_end[844] = 120;
		ra_start[845] = 107;
		ra_end[845] = 138;
		ra_start[846] = 120;
		ra_end[846] = 138;
		ra_start[847] = 125;
		ra_end[847] = 155;
		ra_start[848] = 137;
		ra_end[848] = 155;
		ra_start[849] = 148;
		ra_end[849] = 172;
		ra_start[850] = 154;
		ra_end[850] = 177;
		ra_start[851] = 171;
		ra_end[851] = 189;
		ra_start[852] = 171;
		ra_end[852] = 206;
		ra_start[853] = 188;
		ra_end[853] = 216;
		ra_start[854] = 205;
		ra_end[854] = 223;
		ra_start[855] = 206;
		ra_end[855] = 240;
		ra_start[856] = 222;
		ra_end[856] = 240;
		ra_start[857] = 234;
		ra_end[857] = 258;
		ra_start[858] = 240;
		ra_end[858] = 260;
		ra_start[859] = 257;
		ra_end[859] = 275;
		ra_start[860] = 257;
		ra_end[860] = 275;
		ra_start[861] = 261;
		ra_end[861] = 292;
		ra_start[862] = 274;
		ra_end[862] = 292;
		ra_start[863] = 274;
		ra_end[863] = 292;
		ra_start[864] = 274;
		ra_end[864] = 300;
		ra_start[865] = 291;
		ra_end[865] = 309;
		ra_start[866] = 291;
		ra_end[866] = 309;
		ra_start[867] = 291;
		ra_end[867] = 309;
		ra_start[868] = 293;
		ra_end[868] = 322;
		ra_start[869] = 308;
		ra_end[869] = 326;
		ra_start[870] = 308;
		ra_end[870] = 326;
		ra_start[871] = 308;
		ra_end[871] = 330;
		ra_start[872] = 326;
		ra_end[872] = 343;
		ra_start[873] = 325;
		ra_end[873] = 343;
		ra_start[874] = 325;
		ra_end[874] = 343;
		ra_start[875] = 325;
		ra_end[875] = 348;
		ra_start[876] = 342;
		ra_end[876] = 356;
		ra_start[877] = 342;
		ra_end[877] = 360;
		ra_start[878] = 347;
		ra_end[878] = 360;
		ra_start[879] = 342;
		ra_end[879] = 360;
		ra_start[880] = 0;
		ra_end[880] = 360;
		ra_start[881] = 0;
		ra_end[881] = 24;
		ra_start[882] = 0;
		ra_end[882] = 24;
		ra_start[883] = 0;
		ra_end[883] = 24;
		ra_start[884] = 12;
		ra_end[884] = 48;
		ra_start[885] = 24;
		ra_end[885] = 48;
		ra_start[886] = 24;
		ra_end[886] = 48;
		ra_start[887] = 24;
		ra_end[887] = 66;
		ra_start[888] = 48;
		ra_end[888] = 72;
		ra_start[889] = 48;
		ra_end[889] = 72;
		ra_start[890] = 48;
		ra_end[890] = 78;
		ra_start[891] = 72;
		ra_end[891] = 96;
		ra_start[892] = 72;
		ra_end[892] = 96;
		ra_start[893] = 72;
		ra_end[893] = 96;
		ra_start[894] = 90;
		ra_end[894] = 120;
		ra_start[895] = 96;
		ra_end[895] = 120;
		ra_start[896] = 96;
		ra_end[896] = 128;
		ra_start[897] = 120;
		ra_end[897] = 144;
		ra_start[898] = 120;
		ra_end[898] = 144;
		ra_start[899] = 128;
		ra_end[899] = 168;
		ra_start[900] = 144;
		ra_end[900] = 168;
		ra_start[901] = 160;
		ra_end[901] = 192;
		ra_start[902] = 168;
		ra_end[902] = 200;
		ra_start[903] = 192;
		ra_end[903] = 216;
		ra_start[904] = 192;
		ra_end[904] = 239;
		ra_start[905] = 216;
		ra_end[905] = 240;
		ra_start[906] = 224;
		ra_end[906] = 264;
		ra_start[907] = 240;
		ra_end[907] = 264;
		ra_start[908] = 240;
		ra_end[908] = 282;
		ra_start[909] = 264;
		ra_end[909] = 288;
		ra_start[910] = 264;
		ra_end[910] = 288;
		ra_start[911] = 276;
		ra_end[911] = 312;
		ra_start[912] = 288;
		ra_end[912] = 312;
		ra_start[913] = 288;
		ra_end[913] = 318;
		ra_start[914] = 312;
		ra_end[914] = 336;
		ra_start[915] = 312;
		ra_end[915] = 336;
		ra_start[916] = 312;
		ra_end[916] = 348;
		ra_start[917] = 336;
		ra_end[917] = 360;
		ra_start[918] = 336;
		ra_end[918] = 360;
		ra_start[919] = 0;
		ra_end[919] = 360;
		ra_start[920] = 0;
		ra_end[920] = 40;
		ra_start[921] = 0;
		ra_end[921] = 40;
		ra_start[922] = 0;
		ra_end[922] = 60;
		ra_start[923] = 40;
		ra_end[923] = 80;
		ra_start[924] = 40;
		ra_end[924] = 80;
		ra_start[925] = 40;
		ra_end[925] = 100;
		ra_start[926] = 80;
		ra_end[926] = 120;
		ra_start[927] = 80;
		ra_end[927] = 120;
		ra_start[928] = 80;
		ra_end[928] = 147;
		ra_start[929] = 120;
		ra_end[929] = 160;
		ra_start[930] = 120;
		ra_end[930] = 187;
		ra_start[931] = 160;
		ra_end[931] = 200;
		ra_start[932] = 160;
		ra_end[932] = 227;
		ra_start[933] = 200;
		ra_end[933] = 241;
		ra_start[934] = 200;
		ra_end[934] = 260;
		ra_start[935] = 240;
		ra_end[935] = 280;
		ra_start[936] = 240;
		ra_end[936] = 280;
		ra_start[937] = 250;
		ra_end[937] = 319;
		ra_start[938] = 280;
		ra_end[938] = 320;
		ra_start[939] = 280;
		ra_end[939] = 330;
		ra_start[940] = 320;
		ra_end[940] = 360;
		ra_start[941] = 320;
		ra_end[941] = 360;
		ra_start[942] = 0;
		ra_end[942] = 360;
		ra_start[943] = 0;
		ra_end[943] = 115;
		ra_start[944] = 0;
		ra_end[944] = 120;
		ra_start[945] = 0;
		ra_end[945] = 180;
		ra_start[946] = 120;
		ra_end[946] = 240;
		ra_start[947] = 121;
		ra_end[947] = 290;
		ra_start[948] = 240;
		ra_end[948] = 360;
		ra_start[949] = 0;
		ra_end[949] = 360;
		ra_start[950] = 0;
		ra_end[950] = 8;
		ra_start[951] = 5;
		ra_end[951] = 15;
		ra_start[952] = 10;
		ra_end[952] = 23;
		ra_start[953] = 15;
		ra_end[953] = 30;
		ra_start[954] = 22;
		ra_end[954] = 34;
		ra_start[955] = 30;
		ra_end[955] = 39;
		ra_start[956] = 37;
		ra_end[956] = 45;
		ra_start[957] = 40;
		ra_end[957] = 53;
		ra_start[958] = 45;
		ra_end[958] = 60;
		ra_start[959] = 52;
		ra_end[959] = 65;
		ra_start[960] = 60;
		ra_end[960] = 68;
		ra_start[961] = 62;
		ra_end[961] = 75;
		ra_start[962] = 67;
		ra_end[962] = 75;
		ra_start[963] = 67;
		ra_end[963] = 79;
		ra_start[964] = 75;
		ra_end[964] = 83;
		ra_start[965] = 75;
		ra_end[965] = 83;
		ra_start[966] = 75;
		ra_end[966] = 84;
		ra_start[967] = 82;
		ra_end[967] = 90;
		ra_start[968] = 82;
		ra_end[968] = 90;
		ra_start[969] = 82;
		ra_end[969] = 96;
		ra_start[970] = 90;
		ra_end[970] = 98;
		ra_start[971] = 90;
		ra_end[971] = 98;
		ra_start[972] = 90;
		ra_end[972] = 100;
		ra_start[973] = 97;
		ra_end[973] = 105;
		ra_start[974] = 97;
		ra_end[974] = 105;
		ra_start[975] = 97;
		ra_end[975] = 105;
		ra_start[976] = 97;
		ra_end[976] = 105;
		ra_start[977] = 101;
		ra_end[977] = 109;
		ra_start[978] = 105;
		ra_end[978] = 113;
		ra_start[979] = 105;
		ra_end[979] = 113;
		ra_start[980] = 105;
		ra_end[980] = 113;
		ra_start[981] = 105;
		ra_end[981] = 113;
		ra_start[982] = 105;
		ra_end[982] = 113;
		ra_start[983] = 110;
		ra_end[983] = 120;
		ra_start[984] = 112;
		ra_end[984] = 120;
		ra_start[985] = 112;
		ra_end[985] = 120;
		ra_start[986] = 112;
		ra_end[986] = 120;
		ra_start[987] = 116;
		ra_end[987] = 126;
		ra_start[988] = 120;
		ra_end[988] = 128;
		ra_start[989] = 120;
		ra_end[989] = 128;
		ra_start[990] = 120;
		ra_end[990] = 128;
		ra_start[991] = 123;
		ra_end[991] = 135;
		ra_start[992] = 127;
		ra_end[992] = 135;
		ra_start[993] = 127;
		ra_end[993] = 135;
		ra_start[994] = 129;
		ra_end[994] = 143;
		ra_start[995] = 135;
		ra_end[995] = 143;
		ra_start[996] = 140;
		ra_end[996] = 150;
		ra_start[997] = 142;
		ra_end[997] = 154;
		ra_start[998] = 150;
		ra_end[998] = 158;
		ra_start[999] = 152;
		ra_end[999] = 165;
		ra_start[1000] = 157;
		ra_end[1000] = 173;
		ra_start[1001] = 165;
		ra_end[1001] = 180;
		ra_start[1002] = 172;
		ra_end[1002] = 184;
		ra_start[1003] = 180;
		ra_end[1003] = 188;
		ra_start[1004] = 185;
		ra_end[1004] = 195;
		ra_start[1005] = 190;
		ra_end[1005] = 203;
		ra_start[1006] = 195;
		ra_end[1006] = 210;
		ra_start[1007] = 202;
		ra_end[1007] = 214;
		ra_start[1008] = 210;
		ra_end[1008] = 218;
		ra_start[1009] = 215;
		ra_end[1009] = 225;
		ra_start[1010] = 217;
		ra_end[1010] = 233;
		ra_start[1011] = 225;
		ra_end[1011] = 240;
		ra_start[1012] = 232;
		ra_end[1012] = 246;
		ra_start[1013] = 240;
		ra_end[1013] = 248;
		ra_start[1014] = 241;
		ra_end[1014] = 255;
		ra_start[1015] = 247;
		ra_end[1015] = 261;
		ra_start[1016] = 255;
		ra_end[1016] = 265;
		ra_start[1017] = 262;
		ra_end[1017] = 270;
		ra_start[1018] = 262;
		ra_end[1018] = 278;
		ra_start[1019] = 270;
		ra_end[1019] = 285;
		ra_start[1020] = 277;
		ra_end[1020] = 285;
		ra_start[1021] = 277;
		ra_end[1021] = 287;
		ra_start[1022] = 285;
		ra_end[1022] = 293;
		ra_start[1023] = 285;
		ra_end[1023] = 293;
		ra_start[1024] = 285;
		ra_end[1024] = 297;
		ra_start[1025] = 292;
		ra_end[1025] = 300;
		ra_start[1026] = 292;
		ra_end[1026] = 300;
		ra_start[1027] = 298;
		ra_end[1027] = 308;
		ra_start[1028] = 300;
		ra_end[1028] = 308;
		ra_start[1029] = 300;
		ra_end[1029] = 309;
		ra_start[1030] = 307;
		ra_end[1030] = 315;
		ra_start[1031] = 307;
		ra_end[1031] = 315;
		ra_start[1032] = 307;
		ra_end[1032] = 319;
		ra_start[1033] = 315;
		ra_end[1033] = 323;
		ra_start[1034] = 315;
		ra_end[1034] = 330;
		ra_start[1035] = 322;
		ra_end[1035] = 330;
		ra_start[1036] = 324;
		ra_end[1036] = 338;
		ra_start[1037] = 330;
		ra_end[1037] = 343;
		ra_start[1038] = 337;
		ra_end[1038] = 345;
		ra_start[1039] = 342;
		ra_end[1039] = 353;
		ra_start[1040] = 345;
		ra_end[1040] = 360;
		ra_start[1041] = 0;
		ra_end[1041] = 360;
		ra_start[1042] = 0;
		ra_end[1042] = 12;
		ra_start[1043] = 7;
		ra_end[1043] = 19;
		ra_start[1044] = 15;
		ra_end[1044] = 23;
		ra_start[1045] = 19;
		ra_end[1045] = 31;
		ra_start[1046] = 22;
		ra_end[1046] = 39;
		ra_start[1047] = 30;
		ra_end[1047] = 46;
		ra_start[1048] = 38;
		ra_end[1048] = 51;
		ra_start[1049] = 45;
		ra_end[1049] = 57;
		ra_start[1050] = 53;
		ra_end[1050] = 62;
		ra_start[1051] = 56;
		ra_end[1051] = 69;
		ra_start[1052] = 61;
		ra_end[1052] = 72;
		ra_start[1053] = 68;
		ra_end[1053] = 77;
		ra_start[1054] = 68;
		ra_end[1054] = 77;
		ra_start[1055] = 74;
		ra_end[1055] = 85;
		ra_start[1056] = 76;
		ra_end[1056] = 85;
		ra_start[1057] = 76;
		ra_end[1057] = 89;
		ra_start[1058] = 84;
		ra_end[1058] = 92;
		ra_start[1059] = 84;
		ra_end[1059] = 92;
		ra_start[1060] = 86;
		ra_end[1060] = 99;
		ra_start[1061] = 91;
		ra_end[1061] = 100;
		ra_start[1062] = 91;
		ra_end[1062] = 100;
		ra_start[1063] = 95;
		ra_end[1063] = 106;
		ra_start[1064] = 99;
		ra_end[1064] = 108;
		ra_start[1065] = 99;
		ra_end[1065] = 108;
		ra_start[1066] = 99;
		ra_end[1066] = 108;
		ra_start[1067] = 99;
		ra_end[1067] = 108;
		ra_start[1068] = 103;
		ra_end[1068] = 112;
		ra_start[1069] = 107;
		ra_end[1069] = 115;
		ra_start[1070] = 107;
		ra_end[1070] = 115;
		ra_start[1071] = 107;
		ra_end[1071] = 115;
		ra_start[1072] = 107;
		ra_end[1072] = 115;
		ra_start[1073] = 107;
		ra_end[1073] = 113;
		ra_start[1074] = 111;
		ra_end[1074] = 117;
		ra_start[1075] = 114;
		ra_end[1075] = 123;
		ra_start[1076] = 114;
		ra_end[1076] = 123;
		ra_start[1077] = 114;
		ra_end[1077] = 123;
		ra_start[1078] = 114;
		ra_end[1078] = 123;
		ra_start[1079] = 114;
		ra_end[1079] = 121;
		ra_start[1080] = 118;
		ra_end[1080] = 129;
		ra_start[1081] = 122;
		ra_end[1081] = 131;
		ra_start[1082] = 122;
		ra_end[1082] = 131;
		ra_start[1083] = 122;
		ra_end[1083] = 131;
		ra_start[1084] = 126;
		ra_end[1084] = 136;
		ra_start[1085] = 130;
		ra_end[1085] = 138;
		ra_start[1086] = 130;
		ra_end[1086] = 138;
		ra_start[1087] = 134;
		ra_end[1087] = 146;
		ra_start[1088] = 137;
		ra_end[1088] = 146;
		ra_start[1089] = 139;
		ra_end[1089] = 154;
		ra_start[1090] = 145;
		ra_end[1090] = 154;
		ra_start[1091] = 149;
		ra_end[1091] = 161;
		ra_start[1092] = 153;
		ra_end[1092] = 166;
		ra_start[1093] = 160;
		ra_end[1093] = 169;
		ra_start[1094] = 163;
		ra_end[1094] = 177;
		ra_start[1095] = 168;
		ra_end[1095] = 184;
		ra_start[1096] = 176;
		ra_end[1096] = 189;
		ra_start[1097] = 183;
		ra_end[1097] = 192;
		ra_start[1098] = 186;
		ra_end[1098] = 200;
		ra_start[1099] = 191;
		ra_end[1099] = 207;
		ra_start[1100] = 199;
		ra_end[1100] = 210;
		ra_start[1101] = 206;
		ra_end[1101] = 215;
		ra_start[1102] = 209;
		ra_end[1102] = 223;
		ra_start[1103] = 214;
		ra_end[1103] = 230;
		ra_start[1104] = 222;
		ra_end[1104] = 230;
		ra_start[1105] = 225;
		ra_end[1105] = 238;
		ra_start[1106] = 229;
		ra_end[1106] = 244;
		ra_start[1107] = 237;
		ra_end[1107] = 246;
		ra_start[1108] = 237;
		ra_end[1108] = 253;
		ra_start[1109] = 245;
		ra_end[1109] = 261;
		ra_start[1110] = 252;
		ra_end[1110] = 269;
		ra_start[1111] = 260;
		ra_end[1111] = 269;
		ra_start[1112] = 264;
		ra_end[1112] = 276;
		ra_start[1113] = 268;
		ra_end[1113] = 280;
		ra_start[1114] = 275;
		ra_end[1114] = 284;
		ra_start[1115] = 275;
		ra_end[1115] = 284;
		ra_start[1116] = 277;
		ra_end[1116] = 289;
		ra_start[1117] = 283;
		ra_end[1117] = 292;
		ra_start[1118] = 283;
		ra_end[1118] = 292;
		ra_start[1119] = 284;
		ra_end[1119] = 295;
		ra_start[1120] = 291;
		ra_end[1120] = 299;
		ra_start[1121] = 291;
		ra_end[1121] = 299;
		ra_start[1122] = 294;
		ra_end[1122] = 307;
		ra_start[1123] = 298;
		ra_end[1123] = 307;
		ra_start[1124] = 298;
		ra_end[1124] = 311;
		ra_start[1125] = 306;
		ra_end[1125] = 315;
		ra_start[1126] = 306;
		ra_end[1126] = 315;
		ra_start[1127] = 308;
		ra_end[1127] = 322;
		ra_start[1128] = 314;
		ra_end[1128] = 322;
		ra_start[1129] = 314;
		ra_end[1129] = 330;
		ra_start[1130] = 321;
		ra_end[1130] = 330;
		ra_start[1131] = 325;
		ra_end[1131] = 338;
		ra_start[1132] = 329;
		ra_end[1132] = 345;
		ra_start[1133] = 337;
		ra_end[1133] = 348;
		ra_start[1134] = 344;
		ra_end[1134] = 353;
		ra_start[1135] = 347;
		ra_end[1135] = 360;
		ra_start[1136] = 0;
		ra_end[1136] = 360;
		ra_start[1137] = 0;
		ra_end[1137] = 16;
		ra_start[1138] = 8;
		ra_end[1138] = 24;
		ra_start[1139] = 16;
		ra_end[1139] = 28;
		ra_start[1140] = 24;
		ra_end[1140] = 36;
		ra_start[1141] = 32;
		ra_end[1141] = 40;
		ra_start[1142] = 36;
		ra_end[1142] = 48;
		ra_start[1143] = 40;
		ra_end[1143] = 56;
		ra_start[1144] = 48;
		ra_end[1144] = 64;
		ra_start[1145] = 56;
		ra_end[1145] = 64;
		ra_start[1146] = 61;
		ra_end[1146] = 72;
		ra_start[1147] = 64;
		ra_end[1147] = 72;
		ra_start[1148] = 69;
		ra_end[1148] = 80;
		ra_start[1149] = 72;
		ra_end[1149] = 80;
		ra_start[1150] = 72;
		ra_end[1150] = 86;
		ra_start[1151] = 80;
		ra_end[1151] = 88;
		ra_start[1152] = 80;
		ra_end[1152] = 88;
		ra_start[1153] = 80;
		ra_end[1153] = 92;
		ra_start[1154] = 88;
		ra_end[1154] = 96;
		ra_start[1155] = 88;
		ra_end[1155] = 96;
		ra_start[1156] = 88;
		ra_end[1156] = 96;
		ra_start[1157] = 92;
		ra_end[1157] = 102;
		ra_start[1158] = 96;
		ra_end[1158] = 104;
		ra_start[1159] = 96;
		ra_end[1159] = 104;
		ra_start[1160] = 96;
		ra_end[1160] = 104;
		ra_start[1161] = 98;
		ra_end[1161] = 106;
		ra_start[1162] = 104;
		ra_end[1162] = 110;
		ra_start[1163] = 104;
		ra_end[1163] = 112;
		ra_start[1164] = 106;
		ra_end[1164] = 112;
		ra_start[1165] = 104;
		ra_end[1165] = 112;
		ra_start[1166] = 106;
		ra_end[1166] = 112;
		ra_start[1167] = 104;
		ra_end[1167] = 112;
		ra_start[1168] = 108;
		ra_end[1168] = 112;
		ra_start[1169] = 110;
		ra_end[1169] = 118;
		ra_start[1170] = 112;
		ra_end[1170] = 120;
		ra_start[1171] = 112;
		ra_end[1171] = 118;
		ra_start[1172] = 112;
		ra_end[1172] = 120;
		ra_start[1173] = 114;
		ra_end[1173] = 120;
		ra_start[1174] = 112;
		ra_end[1174] = 120;
		ra_start[1175] = 114;
		ra_end[1175] = 120;
		ra_start[1176] = 118;
		ra_end[1176] = 126;
		ra_start[1177] = 120;
		ra_end[1177] = 128;
		ra_start[1178] = 120;
		ra_end[1178] = 128;
		ra_start[1179] = 120;
		ra_end[1179] = 128;
		ra_start[1180] = 120;
		ra_end[1180] = 128;
		ra_start[1181] = 126;
		ra_end[1181] = 136;
		ra_start[1182] = 128;
		ra_end[1182] = 136;
		ra_start[1183] = 128;
		ra_end[1183] = 136;
		ra_start[1184] = 130;
		ra_end[1184] = 142;
		ra_start[1185] = 136;
		ra_end[1185] = 144;
		ra_start[1186] = 136;
		ra_end[1186] = 144;
		ra_start[1187] = 142;
		ra_end[1187] = 152;
		ra_start[1188] = 144;
		ra_end[1188] = 152;
		ra_start[1189] = 150;
		ra_end[1189] = 160;
		ra_start[1190] = 152;
		ra_end[1190] = 160;
		ra_start[1191] = 158;
		ra_end[1191] = 168;
		ra_start[1192] = 160;
		ra_end[1192] = 176;
		ra_start[1193] = 168;
		ra_end[1193] = 176;
		ra_start[1194] = 170;
		ra_end[1194] = 184;
		ra_start[1195] = 176;
		ra_end[1195] = 184;
		ra_start[1196] = 181;
		ra_end[1196] = 192;
		ra_start[1197] = 184;
		ra_end[1197] = 198;
		ra_start[1198] = 192;
		ra_end[1198] = 200;
		ra_start[1199] = 197;
		ra_end[1199] = 208;
		ra_start[1200] = 200;
		ra_end[1200] = 216;
		ra_start[1201] = 208;
		ra_end[1201] = 220;
		ra_start[1202] = 216;
		ra_end[1202] = 224;
		ra_start[1203] = 216;
		ra_end[1203] = 232;
		ra_start[1204] = 224;
		ra_end[1204] = 232;
		ra_start[1205] = 224;
		ra_end[1205] = 240;
		ra_start[1206] = 232;
		ra_end[1206] = 240;
		ra_start[1207] = 232;
		ra_end[1207] = 248;
		ra_start[1208] = 240;
		ra_end[1208] = 256;
		ra_start[1209] = 248;
		ra_end[1209] = 256;
		ra_start[1210] = 252;
		ra_end[1210] = 264;
		ra_start[1211] = 256;
		ra_end[1211] = 264;
		ra_start[1212] = 256;
		ra_end[1212] = 268;
		ra_start[1213] = 264;
		ra_end[1213] = 272;
		ra_start[1214] = 264;
		ra_end[1214] = 272;
		ra_start[1215] = 266;
		ra_end[1215] = 276;
		ra_start[1216] = 274;
		ra_end[1216] = 280;
		ra_start[1217] = 272;
		ra_end[1217] = 280;
		ra_start[1218] = 272;
		ra_end[1218] = 280;
		ra_start[1219] = 272;
		ra_end[1219] = 280;
		ra_start[1220] = 272;
		ra_end[1220] = 280;
		ra_start[1221] = 277;
		ra_end[1221] = 288;
		ra_start[1222] = 280;
		ra_end[1222] = 288;
		ra_start[1223] = 280;
		ra_end[1223] = 288;
		ra_start[1224] = 280;
		ra_end[1224] = 290;
		ra_start[1225] = 288;
		ra_end[1225] = 296;
		ra_start[1226] = 288;
		ra_end[1226] = 296;
		ra_start[1227] = 288;
		ra_end[1227] = 296;
		ra_start[1228] = 292;
		ra_end[1228] = 304;
		ra_start[1229] = 296;
		ra_end[1229] = 304;
		ra_start[1230] = 296;
		ra_end[1230] = 312;
		ra_start[1231] = 304;
		ra_end[1231] = 312;
		ra_start[1232] = 304;
		ra_end[1232] = 312;
		ra_start[1233] = 310;
		ra_end[1233] = 320;
		ra_start[1234] = 312;
		ra_end[1234] = 322;
		ra_start[1235] = 320;
		ra_end[1235] = 328;
		ra_start[1236] = 320;
		ra_end[1236] = 334;
		ra_start[1237] = 328;
		ra_end[1237] = 336;
		ra_start[1238] = 330;
		ra_end[1238] = 344;
		ra_start[1239] = 336;
		ra_end[1239] = 352;
		ra_start[1240] = 344;
		ra_end[1240] = 360;
		ra_start[1241] = 0;
		ra_end[1241] = 360;
		ra_start[1242] = 0;
		ra_end[1242] = 9;
		ra_start[1243] = 5;
		ra_end[1243] = 17;
		ra_start[1244] = 8;
		ra_end[1244] = 26;
		ra_start[1245] = 16;
		ra_end[1245] = 30;
		ra_start[1246] = 25;
		ra_end[1246] = 34;
		ra_start[1247] = 29;
		ra_end[1247] = 42;
		ra_start[1248] = 33;
		ra_end[1248] = 51;
		ra_start[1249] = 41;
		ra_end[1249] = 56;
		ra_start[1250] = 50;
		ra_end[1250] = 59;
		ra_start[1251] = 53;
		ra_end[1251] = 67;
		ra_start[1252] = 58;
		ra_end[1252] = 67;
		ra_start[1253] = 64;
		ra_end[1253] = 76;
		ra_start[1254] = 66;
		ra_end[1254] = 76;
		ra_start[1255] = 73;
		ra_end[1255] = 84;
		ra_start[1256] = 75;
		ra_end[1256] = 84;
		ra_start[1257] = 75;
		ra_end[1257] = 90;
		ra_start[1258] = 83;
		ra_end[1258] = 93;
		ra_start[1259] = 83;
		ra_end[1259] = 93;
		ra_start[1260] = 84;
		ra_end[1260] = 97;
		ra_start[1261] = 92;
		ra_end[1261] = 101;
		ra_start[1262] = 92;
		ra_end[1262] = 101;
		ra_start[1263] = 92;
		ra_end[1263] = 101;
		ra_start[1264] = 92;
		ra_end[1264] = 103;
		ra_start[1265] = 100;
		ra_end[1265] = 107;
		ra_start[1266] = 100;
		ra_end[1266] = 109;
		ra_start[1267] = 100;
		ra_end[1267] = 107;
		ra_start[1268] = 100;
		ra_end[1268] = 109;
		ra_start[1269] = 102;
		ra_end[1269] = 109;
		ra_start[1270] = 100;
		ra_end[1270] = 109;
		ra_start[1271] = 102;
		ra_end[1271] = 111;
		ra_start[1272] = 108;
		ra_end[1272] = 114;
		ra_start[1273] = 113;
		ra_end[1273] = 118;
		ra_start[1274] = 108;
		ra_end[1274] = 118;
		ra_start[1275] = 110;
		ra_end[1275] = 118;
		ra_start[1276] = 108;
		ra_end[1276] = 118;
		ra_start[1277] = 108;
		ra_end[1277] = 116;
		ra_start[1278] = 108;
		ra_end[1278] = 118;
		ra_start[1279] = 108;
		ra_end[1279] = 116;
		ra_start[1280] = 113;
		ra_end[1280] = 120;
		ra_start[1281] = 117;
		ra_end[1281] = 124;
		ra_start[1282] = 118;
		ra_end[1282] = 126;
		ra_start[1283] = 117;
		ra_end[1283] = 124;
		ra_start[1284] = 117;
		ra_end[1284] = 126;
		ra_start[1285] = 117;
		ra_end[1285] = 124;
		ra_start[1286] = 117;
		ra_end[1286] = 126;
		ra_start[1287] = 117;
		ra_end[1287] = 122;
		ra_start[1288] = 119;
		ra_end[1288] = 126;
		ra_start[1289] = 123;
		ra_end[1289] = 130;
		ra_start[1290] = 125;
		ra_end[1290] = 134;
		ra_start[1291] = 125;
		ra_end[1291] = 134;
		ra_start[1292] = 125;
		ra_end[1292] = 134;
		ra_start[1293] = 125;
		ra_end[1293] = 134;
		ra_start[1294] = 129;
		ra_end[1294] = 141;
		ra_start[1295] = 133;
		ra_end[1295] = 143;
		ra_start[1296] = 133;
		ra_end[1296] = 143;
		ra_start[1297] = 134;
		ra_end[1297] = 147;
		ra_start[1298] = 142;
		ra_end[1298] = 151;
		ra_start[1299] = 142;
		ra_end[1299] = 151;
		ra_start[1300] = 146;
		ra_end[1300] = 160;
		ra_start[1301] = 150;
		ra_end[1301] = 160;
		ra_start[1302] = 150;
		ra_end[1302] = 168;
		ra_start[1303] = 159;
		ra_end[1303] = 168;
		ra_start[1304] = 159;
		ra_end[1304] = 170;
		ra_start[1305] = 167;
		ra_end[1305] = 176;
		ra_start[1306] = 167;
		ra_end[1306] = 176;
		ra_start[1307] = 171;
		ra_end[1307] = 185;
		ra_start[1308] = 175;
		ra_end[1308] = 185;
		ra_start[1309] = 177;
		ra_end[1309] = 193;
		ra_start[1310] = 184;
		ra_end[1310] = 195;
		ra_start[1311] = 192;
		ra_end[1311] = 201;
		ra_start[1312] = 192;
		ra_end[1312] = 210;
		ra_start[1313] = 200;
		ra_end[1313] = 210;
		ra_start[1314] = 201;
		ra_end[1314] = 218;
		ra_start[1315] = 209;
		ra_end[1315] = 218;
		ra_start[1316] = 209;
		ra_end[1316] = 226;
		ra_start[1317] = 217;
		ra_end[1317] = 227;
		ra_start[1318] = 217;
		ra_end[1318] = 233;
		ra_start[1319] = 226;
		ra_end[1319] = 235;
		ra_start[1320] = 226;
		ra_end[1320] = 239;
		ra_start[1321] = 234;
		ra_end[1321] = 243;
		ra_start[1322] = 234;
		ra_end[1322] = 243;
		ra_start[1323] = 237;
		ra_end[1323] = 252;
		ra_start[1324] = 242;
		ra_end[1324] = 252;
		ra_start[1325] = 249;
		ra_end[1325] = 260;
		ra_start[1326] = 251;
		ra_end[1326] = 260;
		ra_start[1327] = 251;
		ra_end[1327] = 260;
		ra_start[1328] = 257;
		ra_end[1328] = 268;
		ra_start[1329] = 259;
		ra_end[1329] = 268;
		ra_start[1330] = 261;
		ra_end[1330] = 272;
		ra_start[1331] = 267;
		ra_end[1331] = 277;
		ra_start[1332] = 267;
		ra_end[1332] = 277;
		ra_start[1333] = 267;
		ra_end[1333] = 277;
		ra_start[1334] = 267;
		ra_end[1334] = 279;
		ra_start[1335] = 276;
		ra_end[1335] = 285;
		ra_start[1336] = 276;
		ra_end[1336] = 285;
		ra_start[1337] = 276;
		ra_end[1337] = 287;
		ra_start[1338] = 284;
		ra_end[1338] = 293;
		ra_start[1339] = 284;
		ra_end[1339] = 294;
		ra_start[1340] = 284;
		ra_end[1340] = 296;
		ra_start[1341] = 293;
		ra_end[1341] = 302;
		ra_start[1342] = 293;
		ra_end[1342] = 302;
		ra_start[1343] = 297;
		ra_end[1343] = 310;
		ra_start[1344] = 301;
		ra_end[1344] = 310;
		ra_start[1345] = 301;
		ra_end[1345] = 315;
		ra_start[1346] = 309;
		ra_end[1346] = 319;
		ra_start[1347] = 309;
		ra_end[1347] = 325;
		ra_start[1348] = 318;
		ra_end[1348] = 327;
		ra_start[1349] = 318;
		ra_end[1349] = 335;
		ra_start[1350] = 326;
		ra_end[1350] = 335;
		ra_start[1351] = 332;
		ra_end[1351] = 344;
		ra_start[1352] = 334;
		ra_end[1352] = 352;
		ra_start[1353] = 343;
		ra_end[1353] = 358;
		ra_start[1354] = 351;
		ra_end[1354] = 360;
		ra_start[1355] = 0;
		ra_end[1355] = 360;
		ra_start[1356] = 0;
		ra_end[1356] = 18;
		ra_start[1357] = 9;
		ra_end[1357] = 27;
		ra_start[1358] = 18;
		ra_end[1358] = 27;
		ra_start[1359] = 23;
		ra_end[1359] = 36;
		ra_start[1360] = 28;
		ra_end[1360] = 45;
		ra_start[1361] = 36;
		ra_end[1361] = 48;
		ra_start[1362] = 45;
		ra_end[1362] = 54;
		ra_start[1363] = 45;
		ra_end[1363] = 62;
		ra_start[1364] = 54;
		ra_end[1364] = 63;
		ra_start[1365] = 57;
		ra_end[1365] = 72;
		ra_start[1366] = 63;
		ra_end[1366] = 72;
		ra_start[1367] = 66;
		ra_end[1367] = 81;
		ra_start[1368] = 72;
		ra_end[1368] = 81;
		ra_start[1369] = 72;
		ra_end[1369] = 88;
		ra_start[1370] = 81;
		ra_end[1370] = 90;
		ra_start[1371] = 81;
		ra_end[1371] = 90;
		ra_start[1372] = 83;
		ra_end[1372] = 97;
		ra_start[1373] = 90;
		ra_end[1373] = 99;
		ra_start[1374] = 90;
		ra_end[1374] = 99;
		ra_start[1375] = 90;
		ra_end[1375] = 102;
		ra_start[1376] = 99;
		ra_end[1376] = 108;
		ra_start[1377] = 99;
		ra_end[1377] = 108;
		ra_start[1378] = 99;
		ra_end[1378] = 108;
		ra_start[1379] = 99;
		ra_end[1379] = 108;
		ra_start[1380] = 105;
		ra_end[1380] = 113;
		ra_start[1381] = 110;
		ra_end[1381] = 117;
		ra_start[1382] = 108;
		ra_end[1382] = 117;
		ra_start[1383] = 112;
		ra_end[1383] = 117;
		ra_start[1384] = 108;
		ra_end[1384] = 116;
		ra_start[1385] = 108;
		ra_end[1385] = 117;
		ra_start[1386] = 112;
		ra_end[1386] = 122;
		ra_start[1387] = 119;
		ra_end[1387] = 124;
		ra_start[1388] = 117;
		ra_end[1388] = 126;
		ra_start[1389] = 117;
		ra_end[1389] = 124;
		ra_start[1390] = 117;
		ra_end[1390] = 127;
		ra_start[1391] = 117;
		ra_end[1391] = 125;
		ra_start[1392] = 117;
		ra_end[1392] = 126;
		ra_start[1393] = 119;
		ra_end[1393] = 126;
		ra_start[1394] = 123;
		ra_end[1394] = 131;
		ra_start[1395] = 126;
		ra_end[1395] = 135;
		ra_start[1396] = 126;
		ra_end[1396] = 135;
		ra_start[1397] = 126;
		ra_end[1397] = 135;
		ra_start[1398] = 126;
		ra_end[1398] = 135;
		ra_start[1399] = 126;
		ra_end[1399] = 133;
		ra_start[1400] = 130;
		ra_end[1400] = 140;
		ra_start[1401] = 135;
		ra_end[1401] = 144;
		ra_start[1402] = 135;
		ra_end[1402] = 144;
		ra_start[1403] = 136;
		ra_end[1403] = 144;
		ra_start[1404] = 135;
		ra_end[1404] = 144;
		ra_start[1405] = 139;
		ra_end[1405] = 151;
		ra_start[1406] = 144;
		ra_end[1406] = 153;
		ra_start[1407] = 144;
		ra_end[1407] = 153;
		ra_start[1408] = 144;
		ra_end[1408] = 153;
		ra_start[1409] = 148;
		ra_end[1409] = 162;
		ra_start[1410] = 153;
		ra_end[1410] = 162;
		ra_start[1411] = 153;
		ra_end[1411] = 162;
		ra_start[1412] = 157;
		ra_end[1412] = 171;
		ra_start[1413] = 162;
		ra_end[1413] = 171;
		ra_start[1414] = 162;
		ra_end[1414] = 171;
		ra_start[1415] = 166;
		ra_end[1415] = 180;
		ra_start[1416] = 171;
		ra_end[1416] = 180;
		ra_start[1417] = 171;
		ra_end[1417] = 183;
		ra_start[1418] = 180;
		ra_end[1418] = 189;
		ra_start[1419] = 180;
		ra_end[1419] = 189;
		ra_start[1420] = 182;
		ra_end[1420] = 198;
		ra_start[1421] = 189;
		ra_end[1421] = 198;
		ra_start[1422] = 189;
		ra_end[1422] = 205;
		ra_start[1423] = 198;
		ra_end[1423] = 207;
		ra_start[1424] = 198;
		ra_end[1424] = 207;
		ra_start[1425] = 204;
		ra_end[1425] = 216;
		ra_start[1426] = 207;
		ra_end[1426] = 216;
		ra_start[1427] = 207;
		ra_end[1427] = 219;
		ra_start[1428] = 216;
		ra_end[1428] = 225;
		ra_start[1429] = 216;
		ra_end[1429] = 225;
		ra_start[1430] = 216;
		ra_end[1430] = 229;
		ra_start[1431] = 225;
		ra_end[1431] = 234;
		ra_start[1432] = 225;
		ra_end[1432] = 234;
		ra_start[1433] = 229;
		ra_end[1433] = 241;
		ra_start[1434] = 234;
		ra_end[1434] = 243;
		ra_start[1435] = 234;
		ra_end[1435] = 243;
		ra_start[1436] = 236;
		ra_end[1436] = 250;
		ra_start[1437] = 243;
		ra_end[1437] = 252;
		ra_start[1438] = 243;
		ra_end[1438] = 252;
		ra_start[1439] = 245;
		ra_end[1439] = 261;
		ra_start[1440] = 252;
		ra_end[1440] = 261;
		ra_start[1441] = 252;
		ra_end[1441] = 261;
		ra_start[1442] = 252;
		ra_end[1442] = 261;
		ra_start[1443] = 258;
		ra_end[1443] = 268;
		ra_start[1444] = 261;
		ra_end[1444] = 270;
		ra_start[1445] = 263;
		ra_end[1445] = 270;
		ra_start[1446] = 261;
		ra_end[1446] = 270;
		ra_start[1447] = 261;
		ra_end[1447] = 270;
		ra_start[1448] = 265;
		ra_end[1448] = 277;
		ra_start[1449] = 270;
		ra_end[1449] = 279;
		ra_start[1450] = 270;
		ra_end[1450] = 279;
		ra_start[1451] = 270;
		ra_end[1451] = 279;
		ra_start[1452] = 272;
		ra_end[1452] = 282;
		ra_start[1453] = 279;
		ra_end[1453] = 288;
		ra_start[1454] = 279;
		ra_end[1454] = 288;
		ra_start[1455] = 279;
		ra_end[1455] = 288;
		ra_start[1456] = 281;
		ra_end[1456] = 295;
		ra_start[1457] = 288;
		ra_end[1457] = 297;
		ra_start[1458] = 288;
		ra_end[1458] = 299;
		ra_start[1459] = 297;
		ra_end[1459] = 306;
		ra_start[1460] = 297;
		ra_end[1460] = 306;
		ra_start[1461] = 301;
		ra_end[1461] = 315;
		ra_start[1462] = 306;
		ra_end[1462] = 315;
		ra_start[1463] = 306;
		ra_end[1463] = 322;
		ra_start[1464] = 315;
		ra_end[1464] = 324;
		ra_start[1465] = 315;
		ra_end[1465] = 333;
		ra_start[1466] = 324;
		ra_end[1466] = 333;
		ra_start[1467] = 328;
		ra_end[1467] = 342;
		ra_start[1468] = 333;
		ra_end[1468] = 348;
		ra_start[1469] = 342;
		ra_end[1469] = 351;
		ra_start[1470] = 348;
		ra_end[1470] = 360;
		ra_start[1471] = 0;
		ra_end[1471] = 360;
		ra_start[1472] = 0;
		ra_end[1472] = 18;
		ra_start[1473] = 10;
		ra_end[1473] = 24;
		ra_start[1474] = 20;
		ra_end[1474] = 30;
		ra_start[1475] = 20;
		ra_end[1475] = 40;
		ra_start[1476] = 30;
		ra_end[1476] = 44;
		ra_start[1477] = 40;
		ra_end[1477] = 50;
		ra_start[1478] = 43;
		ra_end[1478] = 60;
		ra_start[1479] = 50;
		ra_end[1479] = 60;
		ra_start[1480] = 56;
		ra_end[1480] = 70;
		ra_start[1481] = 60;
		ra_end[1481] = 74;
		ra_start[1482] = 70;
		ra_end[1482] = 80;
		ra_start[1483] = 70;
		ra_end[1483] = 80;
		ra_start[1484] = 76;
		ra_end[1484] = 90;
		ra_start[1485] = 80;
		ra_end[1485] = 90;
		ra_start[1486] = 80;
		ra_end[1486] = 90;
		ra_start[1487] = 88;
		ra_end[1487] = 100;
		ra_start[1488] = 90;
		ra_end[1488] = 100;
		ra_start[1489] = 90;
		ra_end[1489] = 100;
		ra_start[1490] = 95;
		ra_end[1490] = 108;
		ra_start[1491] = 100;
		ra_end[1491] = 110;
		ra_start[1492] = 100;
		ra_end[1492] = 110;
		ra_start[1493] = 100;
		ra_end[1493] = 110;
		ra_start[1494] = 105;
		ra_end[1494] = 118;
		ra_start[1495] = 110;
		ra_end[1495] = 120;
		ra_start[1496] = 110;
		ra_end[1496] = 120;
		ra_start[1497] = 110;
		ra_end[1497] = 120;
		ra_start[1498] = 110;
		ra_end[1498] = 120;
		ra_start[1499] = 115;
		ra_end[1499] = 123;
		ra_start[1500] = 122;
		ra_end[1500] = 128;
		ra_start[1501] = 120;
		ra_end[1501] = 130;
		ra_start[1502] = 122;
		ra_end[1502] = 130;
		ra_start[1503] = 120;
		ra_end[1503] = 130;
		ra_start[1504] = 120;
		ra_end[1504] = 130;
		ra_start[1505] = 120;
		ra_end[1505] = 128;
		ra_start[1506] = 125;
		ra_end[1506] = 133;
		ra_start[1507] = 130;
		ra_end[1507] = 138;
		ra_start[1508] = 130;
		ra_end[1508] = 140;
		ra_start[1509] = 132;
		ra_end[1509] = 140;
		ra_start[1510] = 130;
		ra_end[1510] = 140;
		ra_start[1511] = 130;
		ra_end[1511] = 140;
		ra_start[1512] = 130;
		ra_end[1512] = 140;
		ra_start[1513] = 137;
		ra_end[1513] = 145;
		ra_start[1514] = 140;
		ra_end[1514] = 150;
		ra_start[1515] = 140;
		ra_end[1515] = 150;
		ra_start[1516] = 140;
		ra_end[1516] = 150;
		ra_start[1517] = 140;
		ra_end[1517] = 150;
		ra_start[1518] = 142;
		ra_end[1518] = 153;
		ra_start[1519] = 150;
		ra_end[1519] = 160;
		ra_start[1520] = 150;
		ra_end[1520] = 160;
		ra_start[1521] = 150;
		ra_end[1521] = 160;
		ra_start[1522] = 150;
		ra_end[1522] = 160;
		ra_start[1523] = 155;
		ra_end[1523] = 165;
		ra_start[1524] = 160;
		ra_end[1524] = 170;
		ra_start[1525] = 160;
		ra_end[1525] = 170;
		ra_start[1526] = 160;
		ra_end[1526] = 170;
		ra_start[1527] = 163;
		ra_end[1527] = 178;
		ra_start[1528] = 170;
		ra_end[1528] = 180;
		ra_start[1529] = 170;
		ra_end[1529] = 180;
		ra_start[1530] = 170;
		ra_end[1530] = 185;
		ra_start[1531] = 180;
		ra_end[1531] = 190;
		ra_start[1532] = 180;
		ra_end[1532] = 190;
		ra_start[1533] = 180;
		ra_end[1533] = 198;
		ra_start[1534] = 190;
		ra_end[1534] = 200;
		ra_start[1535] = 190;
		ra_end[1535] = 200;
		ra_start[1536] = 192;
		ra_end[1536] = 208;
		ra_start[1537] = 200;
		ra_end[1537] = 210;
		ra_start[1538] = 200;
		ra_end[1538] = 210;
		ra_start[1539] = 200;
		ra_end[1539] = 215;
		ra_start[1540] = 210;
		ra_end[1540] = 220;
		ra_start[1541] = 210;
		ra_end[1541] = 220;
		ra_start[1542] = 210;
		ra_end[1542] = 220;
		ra_start[1543] = 217;
		ra_end[1543] = 230;
		ra_start[1544] = 220;
		ra_end[1544] = 230;
		ra_start[1545] = 220;
		ra_end[1545] = 230;
		ra_start[1546] = 220;
		ra_end[1546] = 230;
		ra_start[1547] = 220;
		ra_end[1547] = 230;
		ra_start[1548] = 230;
		ra_end[1548] = 240;
		ra_start[1549] = 230;
		ra_end[1549] = 240;
		ra_start[1550] = 230;
		ra_end[1550] = 240;
		ra_start[1551] = 230;
		ra_end[1551] = 240;
		ra_start[1552] = 235;
		ra_end[1552] = 246;
		ra_start[1553] = 240;
		ra_end[1553] = 250;
		ra_start[1554] = 240;
		ra_end[1554] = 250;
		ra_start[1555] = 240;
		ra_end[1555] = 252;
		ra_start[1556] = 250;
		ra_end[1556] = 260;
		ra_start[1557] = 250;
		ra_end[1557] = 260;
		ra_start[1558] = 250;
		ra_end[1558] = 260;
		ra_start[1559] = 250;
		ra_end[1559] = 260;
		ra_start[1560] = 250;
		ra_end[1560] = 260;
		ra_start[1561] = 257;
		ra_end[1561] = 268;
		ra_start[1562] = 260;
		ra_end[1562] = 270;
		ra_start[1563] = 260;
		ra_end[1563] = 270;
		ra_start[1564] = 260;
		ra_end[1564] = 270;
		ra_start[1565] = 260;
		ra_end[1565] = 270;
		ra_start[1566] = 260;
		ra_end[1566] = 270;
		ra_start[1567] = 267;
		ra_end[1567] = 278;
		ra_start[1568] = 270;
		ra_end[1568] = 280;
		ra_start[1569] = 270;
		ra_end[1569] = 280;
		ra_start[1570] = 270;
		ra_end[1570] = 280;
		ra_start[1571] = 270;
		ra_end[1571] = 283;
		ra_start[1572] = 280;
		ra_end[1572] = 290;
		ra_start[1573] = 280;
		ra_end[1573] = 290;
		ra_start[1574] = 280;
		ra_end[1574] = 290;
		ra_start[1575] = 287;
		ra_end[1575] = 300;
		ra_start[1576] = 290;
		ra_end[1576] = 300;
		ra_start[1577] = 290;
		ra_end[1577] = 305;
		ra_start[1578] = 300;
		ra_end[1578] = 310;
		ra_start[1579] = 300;
		ra_end[1579] = 310;
		ra_start[1580] = 305;
		ra_end[1580] = 320;
		ra_start[1581] = 310;
		ra_end[1581] = 320;
		ra_start[1582] = 310;
		ra_end[1582] = 328;
		ra_start[1583] = 320;
		ra_end[1583] = 330;
		ra_start[1584] = 320;
		ra_end[1584] = 340;
		ra_start[1585] = 330;
		ra_end[1585] = 340;
		ra_start[1586] = 333;
		ra_end[1586] = 350;
		ra_start[1587] = 340;
		ra_end[1587] = 360;
		ra_start[1588] = 0;
		ra_end[1588] = 360;
		ra_start[1589] = 0;
		ra_end[1589] = 12;
		ra_start[1590] = 0;
		ra_end[1590] = 23;
		ra_start[1591] = 11;
		ra_end[1591] = 27;
		ra_start[1592] = 22;
		ra_end[1592] = 34;
		ra_start[1593] = 26;
		ra_end[1593] = 45;
		ra_start[1594] = 33;
		ra_end[1594] = 53;
		ra_start[1595] = 45;
		ra_end[1595] = 57;
		ra_start[1596] = 48;
		ra_end[1596] = 68;
		ra_start[1597] = 56;
		ra_end[1597] = 68;
		ra_start[1598] = 60;
		ra_end[1598] = 79;
		ra_start[1599] = 67;
		ra_end[1599] = 79;
		ra_start[1600] = 71;
		ra_end[1600] = 90;
		ra_start[1601] = 78;
		ra_end[1601] = 90;
		ra_start[1602] = 78;
		ra_end[1602] = 96;
		ra_start[1603] = 90;
		ra_end[1603] = 102;
		ra_start[1604] = 90;
		ra_end[1604] = 102;
		ra_start[1605] = 90;
		ra_end[1605] = 102;
		ra_start[1606] = 98;
		ra_end[1606] = 110;
		ra_start[1607] = 101;
		ra_end[1607] = 113;
		ra_start[1608] = 101;
		ra_end[1608] = 113;
		ra_start[1609] = 101;
		ra_end[1609] = 113;
		ra_start[1610] = 109;
		ra_end[1610] = 121;
		ra_start[1611] = 112;
		ra_end[1611] = 124;
		ra_start[1612] = 115;
		ra_end[1612] = 124;
		ra_start[1613] = 112;
		ra_end[1613] = 124;
		ra_start[1614] = 112;
		ra_end[1614] = 124;
		ra_start[1615] = 121;
		ra_end[1615] = 130;
		ra_start[1616] = 124;
		ra_end[1616] = 135;
		ra_start[1617] = 123;
		ra_end[1617] = 133;
		ra_start[1618] = 123;
		ra_end[1618] = 135;
		ra_start[1619] = 123;
		ra_end[1619] = 133;
		ra_start[1620] = 123;
		ra_end[1620] = 135;
		ra_start[1621] = 129;
		ra_end[1621] = 141;
		ra_start[1622] = 137;
		ra_end[1622] = 147;
		ra_start[1623] = 135;
		ra_end[1623] = 147;
		ra_start[1624] = 135;
		ra_end[1624] = 147;
		ra_start[1625] = 135;
		ra_end[1625] = 147;
		ra_start[1626] = 135;
		ra_end[1626] = 144;
		ra_start[1627] = 140;
		ra_end[1627] = 152;
		ra_start[1628] = 149;
		ra_end[1628] = 158;
		ra_start[1629] = 146;
		ra_end[1629] = 158;
		ra_start[1630] = 146;
		ra_end[1630] = 158;
		ra_start[1631] = 149;
		ra_end[1631] = 158;
		ra_start[1632] = 146;
		ra_end[1632] = 158;
		ra_start[1633] = 151;
		ra_end[1633] = 164;
		ra_start[1634] = 157;
		ra_end[1634] = 169;
		ra_start[1635] = 157;
		ra_end[1635] = 169;
		ra_start[1636] = 157;
		ra_end[1636] = 169;
		ra_start[1637] = 157;
		ra_end[1637] = 169;
		ra_start[1638] = 163;
		ra_end[1638] = 178;
		ra_start[1639] = 168;
		ra_end[1639] = 180;
		ra_start[1640] = 168;
		ra_end[1640] = 180;
		ra_start[1641] = 168;
		ra_end[1641] = 180;
		ra_start[1642] = 168;
		ra_end[1642] = 180;
		ra_start[1643] = 177;
		ra_end[1643] = 192;
		ra_start[1644] = 180;
		ra_end[1644] = 192;
		ra_start[1645] = 180;
		ra_end[1645] = 192;
		ra_start[1646] = 180;
		ra_end[1646] = 192;
		ra_start[1647] = 185;
		ra_end[1647] = 200;
		ra_start[1648] = 191;
		ra_end[1648] = 203;
		ra_start[1649] = 191;
		ra_end[1649] = 203;
		ra_start[1650] = 191;
		ra_end[1650] = 203;
		ra_start[1651] = 196;
		ra_end[1651] = 209;
		ra_start[1652] = 202;
		ra_end[1652] = 214;
		ra_start[1653] = 202;
		ra_end[1653] = 214;
		ra_start[1654] = 202;
		ra_end[1654] = 214;
		ra_start[1655] = 202;
		ra_end[1655] = 217;
		ra_start[1656] = 213;
		ra_end[1656] = 225;
		ra_start[1657] = 213;
		ra_end[1657] = 225;
		ra_start[1658] = 213;
		ra_end[1658] = 225;
		ra_start[1659] = 213;
		ra_end[1659] = 225;
		ra_start[1660] = 216;
		ra_end[1660] = 228;
		ra_start[1661] = 225;
		ra_end[1661] = 237;
		ra_start[1662] = 225;
		ra_end[1662] = 237;
		ra_start[1663] = 225;
		ra_end[1663] = 237;
		ra_start[1664] = 225;
		ra_end[1664] = 237;
		ra_start[1665] = 225;
		ra_end[1665] = 237;
		ra_start[1666] = 227;
		ra_end[1666] = 237;
		ra_start[1667] = 233;
		ra_end[1667] = 245;
		ra_start[1668] = 236;
		ra_end[1668] = 248;
		ra_start[1669] = 236;
		ra_end[1669] = 248;
		ra_start[1670] = 236;
		ra_end[1670] = 248;
		ra_start[1671] = 236;
		ra_end[1671] = 248;
		ra_start[1672] = 236;
		ra_end[1672] = 245;
		ra_start[1673] = 241;
		ra_end[1673] = 248;
		ra_start[1674] = 245;
		ra_end[1674] = 256;
		ra_start[1675] = 247;
		ra_end[1675] = 259;
		ra_start[1676] = 247;
		ra_end[1676] = 259;
		ra_start[1677] = 247;
		ra_end[1677] = 259;
		ra_start[1678] = 247;
		ra_end[1678] = 259;
		ra_start[1679] = 250;
		ra_end[1679] = 262;
		ra_start[1680] = 258;
		ra_end[1680] = 268;
		ra_start[1681] = 258;
		ra_end[1681] = 270;
		ra_start[1682] = 258;
		ra_end[1682] = 270;
		ra_start[1683] = 258;
		ra_end[1683] = 270;
		ra_start[1684] = 258;
		ra_end[1684] = 270;
		ra_start[1685] = 264;
		ra_end[1685] = 279;
		ra_start[1686] = 270;
		ra_end[1686] = 282;
		ra_start[1687] = 270;
		ra_end[1687] = 282;
		ra_start[1688] = 270;
		ra_end[1688] = 282;
		ra_start[1689] = 272;
		ra_end[1689] = 287;
		ra_start[1690] = 281;
		ra_end[1690] = 293;
		ra_start[1691] = 281;
		ra_end[1691] = 293;
		ra_start[1692] = 281;
		ra_end[1692] = 296;
		ra_start[1693] = 292;
		ra_end[1693] = 304;
		ra_start[1694] = 292;
		ra_end[1694] = 304;
		ra_start[1695] = 292;
		ra_end[1695] = 310;
		ra_start[1696] = 303;
		ra_end[1696] = 315;
		ra_start[1697] = 303;
		ra_end[1697] = 315;
		ra_start[1698] = 309;
		ra_end[1698] = 327;
		ra_start[1699] = 315;
		ra_end[1699] = 327;
		ra_start[1700] = 317;
		ra_end[1700] = 338;
		ra_start[1701] = 326;
		ra_end[1701] = 338;
		ra_start[1702] = 330;
		ra_end[1702] = 349;
		ra_start[1703] = 337;
		ra_end[1703] = 357;
		ra_start[1704] = 348;
		ra_end[1704] = 360;
		ra_start[1705] = 0;
		ra_end[1705] = 360;
		ra_start[1706] = 0;
		ra_end[1706] = 23;
		ra_start[1707] = 13;
		ra_end[1707] = 27;
		ra_start[1708] = 22;
		ra_end[1708] = 40;
		ra_start[1709] = 26;
		ra_end[1709] = 49;
		ra_start[1710] = 40;
		ra_end[1710] = 54;
		ra_start[1711] = 44;
		ra_end[1711] = 67;
		ra_start[1712] = 53;
		ra_end[1712] = 67;
		ra_start[1713] = 63;
		ra_end[1713] = 80;
		ra_start[1714] = 66;
		ra_end[1714] = 80;
		ra_start[1715] = 75;
		ra_end[1715] = 94;
		ra_start[1716] = 80;
		ra_end[1716] = 94;
		ra_start[1717] = 80;
		ra_end[1717] = 97;
		ra_start[1718] = 93;
		ra_end[1718] = 107;
		ra_start[1719] = 93;
		ra_end[1719] = 107;
		ra_start[1720] = 93;
		ra_end[1720] = 107;
		ra_start[1721] = 103;
		ra_end[1721] = 120;
		ra_start[1722] = 106;
		ra_end[1722] = 120;
		ra_start[1723] = 106;
		ra_end[1723] = 120;
		ra_start[1724] = 106;
		ra_end[1724] = 124;
		ra_start[1725] = 121;
		ra_end[1725] = 134;
		ra_start[1726] = 120;
		ra_end[1726] = 134;
		ra_start[1727] = 120;
		ra_end[1727] = 134;
		ra_start[1728] = 120;
		ra_end[1728] = 134;
		ra_start[1729] = 126;
		ra_end[1729] = 137;
		ra_start[1730] = 133;
		ra_end[1730] = 144;
		ra_start[1731] = 135;
		ra_end[1731] = 147;
		ra_start[1732] = 133;
		ra_end[1732] = 144;
		ra_start[1733] = 134;
		ra_end[1733] = 147;
		ra_start[1734] = 133;
		ra_end[1734] = 144;
		ra_start[1735] = 133;
		ra_end[1735] = 147;
		ra_start[1736] = 133;
		ra_end[1736] = 147;
		ra_start[1737] = 143;
		ra_end[1737] = 154;
		ra_start[1738] = 150;
		ra_end[1738] = 160;
		ra_start[1739] = 146;
		ra_end[1739] = 160;
		ra_start[1740] = 150;
		ra_end[1740] = 160;
		ra_start[1741] = 146;
		ra_end[1741] = 160;
		ra_start[1742] = 146;
		ra_end[1742] = 157;
		ra_start[1743] = 153;
		ra_end[1743] = 160;
		ra_start[1744] = 146;
		ra_end[1744] = 160;
		ra_start[1745] = 150;
		ra_end[1745] = 157;
		ra_start[1746] = 153;
		ra_end[1746] = 160;
		ra_start[1747] = 156;
		ra_end[1747] = 167;
		ra_start[1748] = 163;
		ra_end[1748] = 174;
		ra_start[1749] = 160;
		ra_end[1749] = 174;
		ra_start[1750] = 163;
		ra_end[1750] = 174;
		ra_start[1751] = 160;
		ra_end[1751] = 174;
		ra_start[1752] = 160;
		ra_end[1752] = 170;
		ra_start[1753] = 160;
		ra_end[1753] = 174;
		ra_start[1754] = 160;
		ra_end[1754] = 167;
		ra_start[1755] = 163;
		ra_end[1755] = 167;
		ra_start[1756] = 163;
		ra_end[1756] = 174;
		ra_start[1757] = 170;
		ra_end[1757] = 177;
		ra_start[1758] = 173;
		ra_end[1758] = 187;
		ra_start[1759] = 173;
		ra_end[1759] = 187;
		ra_start[1760] = 176;
		ra_end[1760] = 187;
		ra_start[1761] = 173;
		ra_end[1761] = 185;
		ra_start[1762] = 173;
		ra_end[1762] = 187;
		ra_start[1763] = 173;
		ra_end[1763] = 180;
		ra_start[1764] = 177;
		ra_end[1764] = 190;
		ra_start[1765] = 186;
		ra_end[1765] = 196;
		ra_start[1766] = 186;
		ra_end[1766] = 200;
		ra_start[1767] = 187;
		ra_end[1767] = 200;
		ra_start[1768] = 186;
		ra_end[1768] = 197;
		ra_start[1769] = 186;
		ra_end[1769] = 200;
		ra_start[1770] = 190;
		ra_end[1770] = 200;
		ra_start[1771] = 196;
		ra_end[1771] = 207;
		ra_start[1772] = 200;
		ra_end[1772] = 214;
		ra_start[1773] = 201;
		ra_end[1773] = 214;
		ra_start[1774] = 200;
		ra_end[1774] = 210;
		ra_start[1775] = 200;
		ra_end[1775] = 214;
		ra_start[1776] = 200;
		ra_end[1776] = 210;
		ra_start[1777] = 207;
		ra_end[1777] = 224;
		ra_start[1778] = 213;
		ra_end[1778] = 227;
		ra_start[1779] = 213;
		ra_end[1779] = 227;
		ra_start[1780] = 213;
		ra_end[1780] = 227;
		ra_start[1781] = 213;
		ra_end[1781] = 227;
		ra_start[1782] = 213;
		ra_end[1782] = 224;
		ra_start[1783] = 220;
		ra_end[1783] = 234;
		ra_start[1784] = 230;
		ra_end[1784] = 237;
		ra_start[1785] = 226;
		ra_end[1785] = 240;
		ra_start[1786] = 226;
		ra_end[1786] = 238;
		ra_start[1787] = 226;
		ra_end[1787] = 240;
		ra_start[1788] = 230;
		ra_end[1788] = 240;
		ra_start[1789] = 226;
		ra_end[1789] = 240;
		ra_start[1790] = 233;
		ra_end[1790] = 244;
		ra_start[1791] = 240;
		ra_end[1791] = 247;
		ra_start[1792] = 243;
		ra_end[1792] = 254;
		ra_start[1793] = 240;
		ra_end[1793] = 254;
		ra_start[1794] = 243;
		ra_end[1794] = 254;
		ra_start[1795] = 240;
		ra_end[1795] = 254;
		ra_start[1796] = 243;
		ra_end[1796] = 254;
		ra_start[1797] = 240;
		ra_end[1797] = 254;
		ra_start[1798] = 246;
		ra_end[1798] = 257;
		ra_start[1799] = 253;
		ra_end[1799] = 267;
		ra_start[1800] = 253;
		ra_end[1800] = 267;
		ra_start[1801] = 253;
		ra_end[1801] = 267;
		ra_start[1802] = 253;
		ra_end[1802] = 267;
		ra_start[1803] = 256;
		ra_end[1803] = 274;
		ra_start[1804] = 266;
		ra_end[1804] = 280;
		ra_start[1805] = 266;
		ra_end[1805] = 280;
		ra_start[1806] = 266;
		ra_end[1806] = 284;
		ra_start[1807] = 280;
		ra_end[1807] = 294;
		ra_start[1808] = 280;
		ra_end[1808] = 294;
		ra_start[1809] = 280;
		ra_end[1809] = 297;
		ra_start[1810] = 293;
		ra_end[1810] = 307;
		ra_start[1811] = 293;
		ra_end[1811] = 307;
		ra_start[1812] = 293;
		ra_end[1812] = 320;
		ra_start[1813] = 306;
		ra_end[1813] = 320;
		ra_start[1814] = 306;
		ra_end[1814] = 334;
		ra_start[1815] = 320;
		ra_end[1815] = 334;
		ra_start[1816] = 320;
		ra_end[1816] = 347;
		ra_start[1817] = 333;
		ra_end[1817] = 347;
		ra_start[1818] = 342;
		ra_end[1818] = 360;
		ra_start[1819] = 0;
		ra_end[1819] = 360;
		ra_start[1820] = 0;
		ra_end[1820] = 18;
		ra_start[1821] = 0;
		ra_end[1821] = 35;
		ra_start[1822] = 17;
		ra_end[1822] = 36;
		ra_start[1823] = 34;
		ra_end[1823] = 52;
		ra_start[1824] = 34;
		ra_end[1824] = 69;
		ra_start[1825] = 51;
		ra_end[1825] = 69;
		ra_start[1826] = 57;
		ra_end[1826] = 86;
		ra_start[1827] = 68;
		ra_end[1827] = 86;
		ra_start[1828] = 68;
		ra_end[1828] = 95;
		ra_start[1829] = 85;
		ra_end[1829] = 103;
		ra_start[1830] = 85;
		ra_end[1830] = 103;
		ra_start[1831] = 85;
		ra_end[1831] = 112;
		ra_start[1832] = 102;
		ra_end[1832] = 120;
		ra_start[1833] = 102;
		ra_end[1833] = 120;
		ra_start[1834] = 102;
		ra_end[1834] = 120;
		ra_start[1835] = 115;
		ra_end[1835] = 133;
		ra_start[1836] = 120;
		ra_end[1836] = 138;
		ra_start[1837] = 120;
		ra_end[1837] = 138;
		ra_start[1838] = 120;
		ra_end[1838] = 138;
		ra_start[1839] = 124;
		ra_end[1839] = 142;
		ra_start[1840] = 138;
		ra_end[1840] = 150;
		ra_start[1841] = 145;
		ra_end[1841] = 155;
		ra_start[1842] = 137;
		ra_end[1842] = 155;
		ra_start[1843] = 137;
		ra_end[1843] = 155;
		ra_start[1844] = 138;
		ra_end[1844] = 155;
		ra_start[1845] = 137;
		ra_end[1845] = 155;
		ra_start[1846] = 150;
		ra_end[1846] = 163;
		ra_start[1847] = 158;
		ra_end[1847] = 168;
		ra_start[1848] = 162;
		ra_end[1848] = 168;
		ra_start[1849] = 163;
		ra_end[1849] = 172;
		ra_start[1850] = 154;
		ra_end[1850] = 172;
		ra_start[1851] = 154;
		ra_end[1851] = 172;
		ra_start[1852] = 154;
		ra_end[1852] = 172;
		ra_start[1853] = 154;
		ra_end[1853] = 172;
		ra_start[1854] = 168;
		ra_end[1854] = 178;
		ra_start[1855] = 175;
		ra_end[1855] = 185;
		ra_start[1856] = 180;
		ra_end[1856] = 189;
		ra_start[1857] = 171;
		ra_end[1857] = 189;
		ra_start[1858] = 171;
		ra_end[1858] = 184;
		ra_start[1859] = 180;
		ra_end[1859] = 189;
		ra_start[1860] = 171;
		ra_end[1860] = 189;
		ra_start[1861] = 180;
		ra_end[1861] = 189;
		ra_start[1862] = 171;
		ra_end[1862] = 189;
		ra_start[1863] = 184;
		ra_end[1863] = 198;
		ra_start[1864] = 192;
		ra_end[1864] = 202;
		ra_start[1865] = 188;
		ra_end[1865] = 206;
		ra_start[1866] = 188;
		ra_end[1866] = 202;
		ra_start[1867] = 197;
		ra_end[1867] = 206;
		ra_start[1868] = 188;
		ra_end[1868] = 206;
		ra_start[1869] = 188;
		ra_end[1869] = 206;
		ra_start[1870] = 188;
		ra_end[1870] = 202;
		ra_start[1871] = 197;
		ra_end[1871] = 210;
		ra_start[1872] = 205;
		ra_end[1872] = 219;
		ra_start[1873] = 205;
		ra_end[1873] = 223;
		ra_start[1874] = 205;
		ra_end[1874] = 215;
		ra_start[1875] = 210;
		ra_end[1875] = 223;
		ra_start[1876] = 205;
		ra_end[1876] = 223;
		ra_start[1877] = 210;
		ra_end[1877] = 223;
		ra_start[1878] = 205;
		ra_end[1878] = 223;
		ra_start[1879] = 210;
		ra_end[1879] = 226;
		ra_start[1880] = 222;
		ra_end[1880] = 236;
		ra_start[1881] = 222;
		ra_end[1881] = 240;
		ra_start[1882] = 223;
		ra_end[1882] = 240;
		ra_start[1883] = 222;
		ra_end[1883] = 240;
		ra_start[1884] = 224;
		ra_end[1884] = 240;
		ra_start[1885] = 222;
		ra_end[1885] = 236;
		ra_start[1886] = 231;
		ra_end[1886] = 245;
		ra_start[1887] = 240;
		ra_end[1887] = 253;
		ra_start[1888] = 241;
		ra_end[1888] = 258;
		ra_start[1889] = 239;
		ra_end[1889] = 249;
		ra_start[1890] = 244;
		ra_end[1890] = 258;
		ra_start[1891] = 240;
		ra_end[1891] = 258;
		ra_start[1892] = 244;
		ra_end[1892] = 258;
		ra_start[1893] = 240;
		ra_end[1893] = 258;
		ra_start[1894] = 244;
		ra_end[1894] = 258;
		ra_start[1895] = 252;
		ra_end[1895] = 270;
		ra_start[1896] = 257;
		ra_end[1896] = 275;
		ra_start[1897] = 257;
		ra_end[1897] = 275;
		ra_start[1898] = 257;
		ra_end[1898] = 275;
		ra_start[1899] = 257;
		ra_end[1899] = 279;
		ra_start[1900] = 274;
		ra_end[1900] = 292;
		ra_start[1901] = 274;
		ra_end[1901] = 292;
		ra_start[1902] = 274;
		ra_end[1902] = 292;
		ra_start[1903] = 278;
		ra_end[1903] = 309;
		ra_start[1904] = 291;
		ra_end[1904] = 309;
		ra_start[1905] = 291;
		ra_end[1905] = 312;
		ra_start[1906] = 308;
		ra_end[1906] = 326;
		ra_start[1907] = 308;
		ra_end[1907] = 326;
		ra_start[1908] = 318;
		ra_end[1908] = 343;
		ra_start[1909] = 325;
		ra_end[1909] = 343;
		ra_start[1910] = 331;
		ra_end[1910] = 360;
		ra_start[1911] = 342;
		ra_end[1911] = 360;
		ra_start[1912] = 0;
		ra_end[1912] = 360;
		ra_start[1913] = 0;
		ra_end[1913] = 24;
		ra_start[1914] = 16;
		ra_end[1914] = 48;
		ra_start[1915] = 24;
		ra_end[1915] = 48;
		ra_start[1916] = 40;
		ra_end[1916] = 72;
		ra_start[1917] = 48;
		ra_end[1917] = 72;
		ra_start[1918] = 72;
		ra_end[1918] = 96;
		ra_start[1919] = 72;
		ra_end[1919] = 96;
		ra_start[1920] = 72;
		ra_end[1920] = 114;
		ra_start[1921] = 96;
		ra_end[1921] = 120;
		ra_start[1922] = 96;
		ra_end[1922] = 120;
		ra_start[1923] = 96;
		ra_end[1923] = 138;
		ra_start[1924] = 120;
		ra_end[1924] = 144;
		ra_start[1925] = 120;
		ra_end[1925] = 144;
		ra_start[1926] = 120;
		ra_end[1926] = 144;
		ra_start[1927] = 132;
		ra_end[1927] = 156;
		ra_start[1928] = 151;
		ra_end[1928] = 168;
		ra_start[1929] = 144;
		ra_end[1929] = 168;
		ra_start[1930] = 144;
		ra_end[1930] = 168;
		ra_start[1931] = 144;
		ra_end[1931] = 168;
		ra_start[1932] = 156;
		ra_end[1932] = 180;
		ra_start[1933] = 168;
		ra_end[1933] = 192;
		ra_start[1934] = 168;
		ra_end[1934] = 192;
		ra_start[1935] = 168;
		ra_end[1935] = 192;
		ra_start[1936] = 168;
		ra_end[1936] = 198;
		ra_start[1937] = 192;
		ra_end[1937] = 210;
		ra_start[1938] = 192;
		ra_end[1938] = 216;
		ra_start[1939] = 193;
		ra_end[1939] = 216;
		ra_start[1940] = 192;
		ra_end[1940] = 216;
		ra_start[1941] = 192;
		ra_end[1941] = 216;
		ra_start[1942] = 204;
		ra_end[1942] = 228;
		ra_start[1943] = 222;
		ra_end[1943] = 240;
		ra_start[1944] = 216;
		ra_end[1944] = 240;
		ra_start[1945] = 222;
		ra_end[1945] = 240;
		ra_start[1946] = 216;
		ra_end[1946] = 240;
		ra_start[1947] = 216;
		ra_end[1947] = 240;
		ra_start[1948] = 216;
		ra_end[1948] = 246;
		ra_start[1949] = 240;
		ra_end[1949] = 258;
		ra_start[1950] = 240;
		ra_end[1950] = 264;
		ra_start[1951] = 240;
		ra_end[1951] = 264;
		ra_start[1952] = 240;
		ra_end[1952] = 264;
		ra_start[1953] = 240;
		ra_end[1953] = 264;
		ra_start[1954] = 252;
		ra_end[1954] = 282;
		ra_start[1955] = 264;
		ra_end[1955] = 288;
		ra_start[1956] = 264;
		ra_end[1956] = 288;
		ra_start[1957] = 264;
		ra_end[1957] = 288;
		ra_start[1958] = 282;
		ra_end[1958] = 312;
		ra_start[1959] = 288;
		ra_end[1959] = 312;
		ra_start[1960] = 288;
		ra_end[1960] = 318;
		ra_start[1961] = 312;
		ra_end[1961] = 336;
		ra_start[1962] = 312;
		ra_end[1962] = 336;
		ra_start[1963] = 312;
		ra_end[1963] = 359;
		ra_start[1964] = 336;
		ra_end[1964] = 360;
		ra_start[1965] = 0;
		ra_end[1965] = 360;
		ra_start[1966] = 0;
		ra_end[1966] = 40;
		ra_start[1967] = 0;
		ra_end[1967] = 60;
		ra_start[1968] = 40;
		ra_end[1968] = 80;
		ra_start[1969] = 40;
		ra_end[1969] = 90;
		ra_start[1970] = 80;
		ra_end[1970] = 120;
		ra_start[1971] = 80;
		ra_end[1971] = 120;
		ra_start[1972] = 100;
		ra_end[1972] = 160;
		ra_start[1973] = 120;
		ra_end[1973] = 160;
		ra_start[1974] = 120;
		ra_end[1974] = 160;
		ra_start[1975] = 150;
		ra_end[1975] = 200;
		ra_start[1976] = 159;
		ra_end[1976] = 200;
		ra_start[1977] = 160;
		ra_end[1977] = 220;
		ra_start[1978] = 210;
		ra_end[1978] = 240;
		ra_start[1979] = 200;
		ra_end[1979] = 240;
		ra_start[1980] = 200;
		ra_end[1980] = 240;
		ra_start[1981] = 200;
		ra_end[1981] = 260;
		ra_start[1982] = 240;
		ra_end[1982] = 280;
		ra_start[1983] = 240;
		ra_end[1983] = 280;
		ra_start[1984] = 240;
		ra_end[1984] = 289;
		ra_start[1985] = 280;
		ra_end[1985] = 320;
		ra_start[1986] = 280;
		ra_end[1986] = 320;
		ra_start[1987] = 280;
		ra_end[1987] = 360;
		ra_start[1988] = 320;
		ra_end[1988] = 360;
		ra_start[1989] = 0;
		ra_end[1989] = 360;
		ra_start[1990] = 0;
		ra_end[1990] = 120;
		ra_start[1991] = 0;
		ra_end[1991] = 180;
		ra_start[1992] = 120;
		ra_end[1992] = 240;
		ra_start[1993] = 120;
		ra_end[1993] = 240;
		ra_start[1994] = 120;
		ra_end[1994] = 300;
		ra_start[1995] = 240;
		ra_end[1995] = 360;
		ra_start[1996] = 240;
		ra_end[1996] = 360;
	}

	/**
	 * Initializes the Decl. of each blocks.
	 */
	private final static void initialize_decl ( ) {
		decl_start[0] = 0;
		decl_end[0] = 8;
		decl_start[1] = 0;
		decl_end[1] = 8;
		decl_start[2] = 0;
		decl_end[2] = 8;
		decl_start[3] = 0;
		decl_end[3] = 8;
		decl_start[4] = 0;
		decl_end[4] = 8;
		decl_start[5] = 0;
		decl_end[5] = 8;
		decl_start[6] = 0;
		decl_end[6] = 8;
		decl_start[7] = 0;
		decl_end[7] = 8;
		decl_start[8] = 0;
		decl_end[8] = 8;
		decl_start[9] = 0;
		decl_end[9] = 8;
		decl_start[10] = 0;
		decl_end[10] = 8;
		decl_start[11] = 0;
		decl_end[11] = 8;
		decl_start[12] = 0;
		decl_end[12] = 6;
		decl_start[13] = 0;
		decl_end[13] = 8;
		decl_start[14] = 0;
		decl_end[14] = 4;
		decl_start[15] = 1;
		decl_end[15] = 6;
		decl_start[16] = 3;
		decl_end[16] = 8;
		decl_start[17] = 0;
		decl_end[17] = 8;
		decl_start[18] = 0;
		decl_end[18] = 6;
		decl_start[19] = 0;
		decl_end[19] = 8;
		decl_start[20] = 0;
		decl_end[20] = 4;
		decl_start[21] = 1;
		decl_end[21] = 6;
		decl_start[22] = 3;
		decl_end[22] = 8;
		decl_start[23] = 0;
		decl_end[23] = 8;
		decl_start[24] = 0;
		decl_end[24] = 4;
		decl_start[25] = 1;
		decl_end[25] = 6;
		decl_start[26] = 3;
		decl_end[26] = 8;
		decl_start[27] = 0;
		decl_end[27] = 8;
		decl_start[28] = 0;
		decl_end[28] = 2;
		decl_start[29] = 0;
		decl_end[29] = 4;
		decl_start[30] = 1;
		decl_end[30] = 6;
		decl_start[31] = 3;
		decl_end[31] = 8;
		decl_start[32] = 0;
		decl_end[32] = 8;
		decl_start[33] = 0;
		decl_end[33] = 4;
		decl_start[34] = 1;
		decl_end[34] = 8;
		decl_start[35] = 0;
		decl_end[35] = 8;
		decl_start[36] = 0;
		decl_end[36] = 4;
		decl_start[37] = 1;
		decl_end[37] = 8;
		decl_start[38] = 0;
		decl_end[38] = 8;
		decl_start[39] = 0;
		decl_end[39] = 6;
		decl_start[40] = 3;
		decl_end[40] = 8;
		decl_start[41] = 0;
		decl_end[41] = 7;
		decl_start[42] = 0;
		decl_end[42] = 8;
		decl_start[43] = 0;
		decl_end[43] = 8;
		decl_start[44] = 0;
		decl_end[44] = 8;
		decl_start[45] = 0;
		decl_end[45] = 8;
		decl_start[46] = 0;
		decl_end[46] = 8;
		decl_start[47] = 0;
		decl_end[47] = 8;
		decl_start[48] = 0;
		decl_end[48] = 8;
		decl_start[49] = 0;
		decl_end[49] = 8;
		decl_start[50] = 0;
		decl_end[50] = 8;
		decl_start[51] = 0;
		decl_end[51] = 8;
		decl_start[52] = 0;
		decl_end[52] = 8;
		decl_start[53] = 0;
		decl_end[53] = 8;
		decl_start[54] = 0;
		decl_end[54] = 8;
		decl_start[55] = 0;
		decl_end[55] = 8;
		decl_start[56] = 0;
		decl_end[56] = 8;
		decl_start[57] = 0;
		decl_end[57] = 8;
		decl_start[58] = 0;
		decl_end[58] = 8;
		decl_start[59] = 0;
		decl_end[59] = 6;
		decl_start[60] = 0;
		decl_end[60] = 8;
		decl_start[61] = 0;
		decl_end[61] = 6;
		decl_start[62] = 0;
		decl_end[62] = 8;
		decl_start[63] = 0;
		decl_end[63] = 6;
		decl_start[64] = 3;
		decl_end[64] = 8;
		decl_start[65] = 0;
		decl_end[65] = 8;
		decl_start[66] = 1;
		decl_end[66] = 6;
		decl_start[67] = 3;
		decl_end[67] = 8;
		decl_start[68] = 0;
		decl_end[68] = 8;
		decl_start[69] = 1;
		decl_end[69] = 6;
		decl_start[70] = 3;
		decl_end[70] = 8;
		decl_start[71] = 0;
		decl_end[71] = 8;
		decl_start[72] = 0;
		decl_end[72] = 6;
		decl_start[73] = 3;
		decl_end[73] = 8;
		decl_start[74] = 0;
		decl_end[74] = 8;
		decl_start[75] = 0;
		decl_end[75] = 4;
		decl_start[76] = 1;
		decl_end[76] = 8;
		decl_start[77] = 0;
		decl_end[77] = 8;
		decl_start[78] = 0;
		decl_end[78] = 4;
		decl_start[79] = 1;
		decl_end[79] = 6;
		decl_start[80] = 3;
		decl_end[80] = 8;
		decl_start[81] = 0;
		decl_end[81] = 8;
		decl_start[82] = 0;
		decl_end[82] = 4;
		decl_start[83] = 1;
		decl_end[83] = 6;
		decl_start[84] = 3;
		decl_end[84] = 8;
		decl_start[85] = 0;
		decl_end[85] = 8;
		decl_start[86] = 1;
		decl_end[86] = 6;
		decl_start[87] = 3;
		decl_end[87] = 8;
		decl_start[88] = 0;
		decl_end[88] = 8;
		decl_start[89] = 0;
		decl_end[89] = 6;
		decl_start[90] = 0;
		decl_end[90] = 8;
		decl_start[91] = 0;
		decl_end[91] = 6;
		decl_start[92] = 0;
		decl_end[92] = 8;
		decl_start[93] = 0;
		decl_end[93] = 8;
		decl_start[94] = 0;
		decl_end[94] = 8;
		decl_start[95] = 0;
		decl_end[95] = 8;
		decl_start[96] = 0;
		decl_end[96] = 8;
		decl_start[97] = 0;
		decl_end[97] = 8;
		decl_start[98] = 5;
		decl_end[98] = 15;
		decl_start[99] = 7;
		decl_end[99] = 15;
		decl_start[100] = 7;
		decl_end[100] = 15;
		decl_start[101] = 7;
		decl_end[101] = 15;
		decl_start[102] = 7;
		decl_end[102] = 15;
		decl_start[103] = 7;
		decl_end[103] = 15;
		decl_start[104] = 7;
		decl_end[104] = 15;
		decl_start[105] = 7;
		decl_end[105] = 15;
		decl_start[106] = 7;
		decl_end[106] = 15;
		decl_start[107] = 7;
		decl_end[107] = 15;
		decl_start[108] = 7;
		decl_end[108] = 15;
		decl_start[109] = 7;
		decl_end[109] = 12;
		decl_start[110] = 9;
		decl_end[110] = 15;
		decl_start[111] = 7;
		decl_end[111] = 12;
		decl_start[112] = 9;
		decl_end[112] = 15;
		decl_start[113] = 7;
		decl_end[113] = 15;
		decl_start[114] = 7;
		decl_end[114] = 12;
		decl_start[115] = 9;
		decl_end[115] = 15;
		decl_start[116] = 7;
		decl_end[116] = 15;
		decl_start[117] = 7;
		decl_end[117] = 12;
		decl_start[118] = 9;
		decl_end[118] = 14;
		decl_start[119] = 11;
		decl_end[119] = 15;
		decl_start[120] = 7;
		decl_end[120] = 15;
		decl_start[121] = 7;
		decl_end[121] = 12;
		decl_start[122] = 9;
		decl_end[122] = 14;
		decl_start[123] = 11;
		decl_end[123] = 15;
		decl_start[124] = 7;
		decl_end[124] = 15;
		decl_start[125] = 7;
		decl_end[125] = 12;
		decl_start[126] = 9;
		decl_end[126] = 14;
		decl_start[127] = 11;
		decl_end[127] = 15;
		decl_start[128] = 7;
		decl_end[128] = 15;
		decl_start[129] = 9;
		decl_end[129] = 14;
		decl_start[130] = 11;
		decl_end[130] = 15;
		decl_start[131] = 7;
		decl_end[131] = 15;
		decl_start[132] = 9;
		decl_end[132] = 14;
		decl_start[133] = 7;
		decl_end[133] = 15;
		decl_start[134] = 7;
		decl_end[134] = 15;
		decl_start[135] = 7;
		decl_end[135] = 15;
		decl_start[136] = 7;
		decl_end[136] = 15;
		decl_start[137] = 7;
		decl_end[137] = 15;
		decl_start[138] = 7;
		decl_end[138] = 15;
		decl_start[139] = 7;
		decl_end[139] = 15;
		decl_start[140] = 7;
		decl_end[140] = 15;
		decl_start[141] = 7;
		decl_end[141] = 15;
		decl_start[142] = 7;
		decl_end[142] = 15;
		decl_start[143] = 7;
		decl_end[143] = 15;
		decl_start[144] = 7;
		decl_end[144] = 15;
		decl_start[145] = 7;
		decl_end[145] = 15;
		decl_start[146] = 7;
		decl_end[146] = 15;
		decl_start[147] = 7;
		decl_end[147] = 15;
		decl_start[148] = 7;
		decl_end[148] = 15;
		decl_start[149] = 7;
		decl_end[149] = 15;
		decl_start[150] = 7;
		decl_end[150] = 15;
		decl_start[151] = 7;
		decl_end[151] = 15;
		decl_start[152] = 9;
		decl_end[152] = 15;
		decl_start[153] = 7;
		decl_end[153] = 12;
		decl_start[154] = 9;
		decl_end[154] = 15;
		decl_start[155] = 7;
		decl_end[155] = 15;
		decl_start[156] = 9;
		decl_end[156] = 14;
		decl_start[157] = 7;
		decl_end[157] = 15;
		decl_start[158] = 7;
		decl_end[158] = 12;
		decl_start[159] = 9;
		decl_end[159] = 15;
		decl_start[160] = 7;
		decl_end[160] = 15;
		decl_start[161] = 7;
		decl_end[161] = 12;
		decl_start[162] = 9;
		decl_end[162] = 14;
		decl_start[163] = 11;
		decl_end[163] = 15;
		decl_start[164] = 7;
		decl_end[164] = 15;
		decl_start[165] = 7;
		decl_end[165] = 12;
		decl_start[166] = 9;
		decl_end[166] = 13;
		decl_start[167] = 11;
		decl_end[167] = 15;
		decl_start[168] = 7;
		decl_end[168] = 15;
		decl_start[169] = 7;
		decl_end[169] = 12;
		decl_start[170] = 9;
		decl_end[170] = 14;
		decl_start[171] = 11;
		decl_end[171] = 15;
		decl_start[172] = 7;
		decl_end[172] = 15;
		decl_start[173] = 7;
		decl_end[173] = 12;
		decl_start[174] = 9;
		decl_end[174] = 14;
		decl_start[175] = 11;
		decl_end[175] = 15;
		decl_start[176] = 13;
		decl_end[176] = 15;
		decl_start[177] = 7;
		decl_end[177] = 15;
		decl_start[178] = 7;
		decl_end[178] = 12;
		decl_start[179] = 9;
		decl_end[179] = 14;
		decl_start[180] = 11;
		decl_end[180] = 15;
		decl_start[181] = 13;
		decl_end[181] = 15;
		decl_start[182] = 7;
		decl_end[182] = 15;
		decl_start[183] = 7;
		decl_end[183] = 12;
		decl_start[184] = 9;
		decl_end[184] = 14;
		decl_start[185] = 11;
		decl_end[185] = 15;
		decl_start[186] = 7;
		decl_end[186] = 15;
		decl_start[187] = 9;
		decl_end[187] = 14;
		decl_start[188] = 7;
		decl_end[188] = 15;
		decl_start[189] = 7;
		decl_end[189] = 14;
		decl_start[190] = 7;
		decl_end[190] = 15;
		decl_start[191] = 7;
		decl_end[191] = 15;
		decl_start[192] = 7;
		decl_end[192] = 15;
		decl_start[193] = 7;
		decl_end[193] = 15;
		decl_start[194] = 7;
		decl_end[194] = 15;
		decl_start[195] = 7;
		decl_end[195] = 15;
		decl_start[196] = 10;
		decl_end[196] = 18;
		decl_start[197] = 15;
		decl_end[197] = 22;
		decl_start[198] = 15;
		decl_end[198] = 23;
		decl_start[199] = 15;
		decl_end[199] = 23;
		decl_start[200] = 15;
		decl_end[200] = 23;
		decl_start[201] = 15;
		decl_end[201] = 23;
		decl_start[202] = 15;
		decl_end[202] = 23;
		decl_start[203] = 15;
		decl_end[203] = 23;
		decl_start[204] = 15;
		decl_end[204] = 23;
		decl_start[205] = 15;
		decl_end[205] = 23;
		decl_start[206] = 15;
		decl_end[206] = 23;
		decl_start[207] = 15;
		decl_end[207] = 23;
		decl_start[208] = 15;
		decl_end[208] = 23;
		decl_start[209] = 15;
		decl_end[209] = 23;
		decl_start[210] = 15;
		decl_end[210] = 21;
		decl_start[211] = 15;
		decl_end[211] = 23;
		decl_start[212] = 15;
		decl_end[212] = 19;
		decl_start[213] = 16;
		decl_end[213] = 21;
		decl_start[214] = 15;
		decl_end[214] = 23;
		decl_start[215] = 15;
		decl_end[215] = 19;
		decl_start[216] = 16;
		decl_end[216] = 21;
		decl_start[217] = 18;
		decl_end[217] = 21;
		decl_start[218] = 18;
		decl_end[218] = 23;
		decl_start[219] = 15;
		decl_end[219] = 23;
		decl_start[220] = 15;
		decl_end[220] = 19;
		decl_start[221] = 16;
		decl_end[221] = 23;
		decl_start[222] = 15;
		decl_end[222] = 23;
		decl_start[223] = 15;
		decl_end[223] = 19;
		decl_start[224] = 16;
		decl_end[224] = 21;
		decl_start[225] = 18;
		decl_end[225] = 23;
		decl_start[226] = 15;
		decl_end[226] = 23;
		decl_start[227] = 15;
		decl_end[227] = 21;
		decl_start[228] = 15;
		decl_end[228] = 23;
		decl_start[229] = 15;
		decl_end[229] = 19;
		decl_start[230] = 16;
		decl_end[230] = 23;
		decl_start[231] = 15;
		decl_end[231] = 23;
		decl_start[232] = 17;
		decl_end[232] = 23;
		decl_start[233] = 15;
		decl_end[233] = 23;
		decl_start[234] = 15;
		decl_end[234] = 23;
		decl_start[235] = 15;
		decl_end[235] = 23;
		decl_start[236] = 15;
		decl_end[236] = 23;
		decl_start[237] = 15;
		decl_end[237] = 23;
		decl_start[238] = 15;
		decl_end[238] = 23;
		decl_start[239] = 15;
		decl_end[239] = 23;
		decl_start[240] = 15;
		decl_end[240] = 23;
		decl_start[241] = 15;
		decl_end[241] = 23;
		decl_start[242] = 15;
		decl_end[242] = 23;
		decl_start[243] = 15;
		decl_end[243] = 23;
		decl_start[244] = 15;
		decl_end[244] = 23;
		decl_start[245] = 15;
		decl_end[245] = 23;
		decl_start[246] = 15;
		decl_end[246] = 23;
		decl_start[247] = 15;
		decl_end[247] = 23;
		decl_start[248] = 15;
		decl_end[248] = 23;
		decl_start[249] = 15;
		decl_end[249] = 21;
		decl_start[250] = 15;
		decl_end[250] = 23;
		decl_start[251] = 15;
		decl_end[251] = 21;
		decl_start[252] = 15;
		decl_end[252] = 23;
		decl_start[253] = 15;
		decl_end[253] = 19;
		decl_start[254] = 16;
		decl_end[254] = 23;
		decl_start[255] = 15;
		decl_end[255] = 23;
		decl_start[256] = 15;
		decl_end[256] = 19;
		decl_start[257] = 16;
		decl_end[257] = 21;
		decl_start[258] = 15;
		decl_end[258] = 23;
		decl_start[259] = 15;
		decl_end[259] = 19;
		decl_start[260] = 16;
		decl_end[260] = 21;
		decl_start[261] = 18;
		decl_end[261] = 21;
		decl_start[262] = 19;
		decl_end[262] = 23;
		decl_start[263] = 15;
		decl_end[263] = 22;
		decl_start[264] = 16;
		decl_end[264] = 21;
		decl_start[265] = 18;
		decl_end[265] = 23;
		decl_start[266] = 15;
		decl_end[266] = 23;
		decl_start[267] = 15;
		decl_end[267] = 17;
		decl_start[268] = 15;
		decl_end[268] = 19;
		decl_start[269] = 16;
		decl_end[269] = 21;
		decl_start[270] = 15;
		decl_end[270] = 23;
		decl_start[271] = 15;
		decl_end[271] = 17;
		decl_start[272] = 15;
		decl_end[272] = 19;
		decl_start[273] = 16;
		decl_end[273] = 21;
		decl_start[274] = 18;
		decl_end[274] = 21;
		decl_start[275] = 18;
		decl_end[275] = 23;
		decl_start[276] = 15;
		decl_end[276] = 23;
		decl_start[277] = 15;
		decl_end[277] = 19;
		decl_start[278] = 16;
		decl_end[278] = 21;
		decl_start[279] = 18;
		decl_end[279] = 21;
		decl_start[280] = 18;
		decl_end[280] = 23;
		decl_start[281] = 15;
		decl_end[281] = 23;
		decl_start[282] = 15;
		decl_end[282] = 19;
		decl_start[283] = 16;
		decl_end[283] = 21;
		decl_start[284] = 18;
		decl_end[284] = 23;
		decl_start[285] = 15;
		decl_end[285] = 23;
		decl_start[286] = 16;
		decl_end[286] = 23;
		decl_start[287] = 15;
		decl_end[287] = 23;
		decl_start[288] = 16;
		decl_end[288] = 23;
		decl_start[289] = 15;
		decl_end[289] = 23;
		decl_start[290] = 16;
		decl_end[290] = 23;
		decl_start[291] = 15;
		decl_end[291] = 23;
		decl_start[292] = 15;
		decl_end[292] = 23;
		decl_start[293] = 15;
		decl_end[293] = 22;
		decl_start[294] = 17;
		decl_end[294] = 25;
		decl_start[295] = 22;
		decl_end[295] = 28;
		decl_start[296] = 23;
		decl_end[296] = 30;
		decl_start[297] = 22;
		decl_end[297] = 28;
		decl_start[298] = 22;
		decl_end[298] = 30;
		decl_start[299] = 22;
		decl_end[299] = 30;
		decl_start[300] = 22;
		decl_end[300] = 30;
		decl_start[301] = 22;
		decl_end[301] = 30;
		decl_start[302] = 22;
		decl_end[302] = 29;
		decl_start[303] = 22;
		decl_end[303] = 30;
		decl_start[304] = 24;
		decl_end[304] = 30;
		decl_start[305] = 22;
		decl_end[305] = 30;
		decl_start[306] = 24;
		decl_end[306] = 30;
		decl_start[307] = 22;
		decl_end[307] = 30;
		decl_start[308] = 22;
		decl_end[308] = 30;
		decl_start[309] = 22;
		decl_end[309] = 30;
		decl_start[310] = 22;
		decl_end[310] = 29;
		decl_start[311] = 22;
		decl_end[311] = 30;
		decl_start[312] = 22;
		decl_end[312] = 27;
		decl_start[313] = 24;
		decl_end[313] = 29;
		decl_start[314] = 26;
		decl_end[314] = 30;
		decl_start[315] = 22;
		decl_end[315] = 30;
		decl_start[316] = 22;
		decl_end[316] = 25;
		decl_start[317] = 22;
		decl_end[317] = 27;
		decl_start[318] = 24;
		decl_end[318] = 29;
		decl_start[319] = 22;
		decl_end[319] = 30;
		decl_start[320] = 22;
		decl_end[320] = 27;
		decl_start[321] = 24;
		decl_end[321] = 29;
		decl_start[322] = 26;
		decl_end[322] = 30;
		decl_start[323] = 22;
		decl_end[323] = 30;
		decl_start[324] = 22;
		decl_end[324] = 29;
		decl_start[325] = 24;
		decl_end[325] = 30;
		decl_start[326] = 22;
		decl_end[326] = 27;
		decl_start[327] = 24;
		decl_end[327] = 30;
		decl_start[328] = 22;
		decl_end[328] = 30;
		decl_start[329] = 25;
		decl_end[329] = 30;
		decl_start[330] = 22;
		decl_end[330] = 30;
		decl_start[331] = 22;
		decl_end[331] = 30;
		decl_start[332] = 22;
		decl_end[332] = 30;
		decl_start[333] = 22;
		decl_end[333] = 30;
		decl_start[334] = 22;
		decl_end[334] = 30;
		decl_start[335] = 22;
		decl_end[335] = 30;
		decl_start[336] = 22;
		decl_end[336] = 30;
		decl_start[337] = 22;
		decl_end[337] = 30;
		decl_start[338] = 22;
		decl_end[338] = 30;
		decl_start[339] = 22;
		decl_end[339] = 30;
		decl_start[340] = 22;
		decl_end[340] = 30;
		decl_start[341] = 22;
		decl_end[341] = 30;
		decl_start[342] = 22;
		decl_end[342] = 30;
		decl_start[343] = 22;
		decl_end[343] = 30;
		decl_start[344] = 22;
		decl_end[344] = 30;
		decl_start[345] = 22;
		decl_end[345] = 30;
		decl_start[346] = 22;
		decl_end[346] = 30;
		decl_start[347] = 23;
		decl_end[347] = 30;
		decl_start[348] = 22;
		decl_end[348] = 27;
		decl_start[349] = 24;
		decl_end[349] = 30;
		decl_start[350] = 22;
		decl_end[350] = 30;
		decl_start[351] = 22;
		decl_end[351] = 29;
		decl_start[352] = 26;
		decl_end[352] = 30;
		decl_start[353] = 22;
		decl_end[353] = 30;
		decl_start[354] = 22;
		decl_end[354] = 29;
		decl_start[355] = 26;
		decl_end[355] = 30;
		decl_start[356] = 22;
		decl_end[356] = 30;
		decl_start[357] = 22;
		decl_end[357] = 27;
		decl_start[358] = 24;
		decl_end[358] = 27;
		decl_start[359] = 24;
		decl_end[359] = 29;
		decl_start[360] = 26;
		decl_end[360] = 30;
		decl_start[361] = 22;
		decl_end[361] = 30;
		decl_start[362] = 22;
		decl_end[362] = 27;
		decl_start[363] = 24;
		decl_end[363] = 29;
		decl_start[364] = 26;
		decl_end[364] = 30;
		decl_start[365] = 28;
		decl_end[365] = 30;
		decl_start[366] = 22;
		decl_end[366] = 30;
		decl_start[367] = 22;
		decl_end[367] = 27;
		decl_start[368] = 24;
		decl_end[368] = 29;
		decl_start[369] = 26;
		decl_end[369] = 29;
		decl_start[370] = 26;
		decl_end[370] = 30;
		decl_start[371] = 28;
		decl_end[371] = 30;
		decl_start[372] = 22;
		decl_end[372] = 30;
		decl_start[373] = 22;
		decl_end[373] = 27;
		decl_start[374] = 24;
		decl_end[374] = 27;
		decl_start[375] = 24;
		decl_end[375] = 29;
		decl_start[376] = 26;
		decl_end[376] = 30;
		decl_start[377] = 28;
		decl_end[377] = 30;
		decl_start[378] = 22;
		decl_end[378] = 30;
		decl_start[379] = 22;
		decl_end[379] = 27;
		decl_start[380] = 24;
		decl_end[380] = 29;
		decl_start[381] = 26;
		decl_end[381] = 30;
		decl_start[382] = 22;
		decl_end[382] = 30;
		decl_start[383] = 22;
		decl_end[383] = 27;
		decl_start[384] = 24;
		decl_end[384] = 30;
		decl_start[385] = 22;
		decl_end[385] = 30;
		decl_start[386] = 22;
		decl_end[386] = 28;
		decl_start[387] = 26;
		decl_end[387] = 30;
		decl_start[388] = 22;
		decl_end[388] = 30;
		decl_start[389] = 22;
		decl_end[389] = 29;
		decl_start[390] = 26;
		decl_end[390] = 30;
		decl_start[391] = 22;
		decl_end[391] = 30;
		decl_start[392] = 24;
		decl_end[392] = 30;
		decl_start[393] = 22;
		decl_end[393] = 30;
		decl_start[394] = 22;
		decl_end[394] = 30;
		decl_start[395] = 27;
		decl_end[395] = 32;
		decl_start[396] = 30;
		decl_end[396] = 36;
		decl_start[397] = 30;
		decl_end[397] = 38;
		decl_start[398] = 30;
		decl_end[398] = 36;
		decl_start[399] = 31;
		decl_end[399] = 38;
		decl_start[400] = 30;
		decl_end[400] = 34;
		decl_start[401] = 31;
		decl_end[401] = 38;
		decl_start[402] = 30;
		decl_end[402] = 38;
		decl_start[403] = 31;
		decl_end[403] = 38;
		decl_start[404] = 30;
		decl_end[404] = 38;
		decl_start[405] = 30;
		decl_end[405] = 36;
		decl_start[406] = 30;
		decl_end[406] = 38;
		decl_start[407] = 30;
		decl_end[407] = 36;
		decl_start[408] = 30;
		decl_end[408] = 38;
		decl_start[409] = 30;
		decl_end[409] = 36;
		decl_start[410] = 30;
		decl_end[410] = 38;
		decl_start[411] = 30;
		decl_end[411] = 34;
		decl_start[412] = 30;
		decl_end[412] = 38;
		decl_start[413] = 30;
		decl_end[413] = 34;
		decl_start[414] = 31;
		decl_end[414] = 36;
		decl_start[415] = 30;
		decl_end[415] = 38;
		decl_start[416] = 30;
		decl_end[416] = 32;
		decl_start[417] = 30;
		decl_end[417] = 34;
		decl_start[418] = 31;
		decl_end[418] = 36;
		decl_start[419] = 33;
		decl_end[419] = 38;
		decl_start[420] = 30;
		decl_end[420] = 38;
		decl_start[421] = 30;
		decl_end[421] = 34;
		decl_start[422] = 31;
		decl_end[422] = 36;
		decl_start[423] = 33;
		decl_end[423] = 38;
		decl_start[424] = 30;
		decl_end[424] = 38;
		decl_start[425] = 30;
		decl_end[425] = 36;
		decl_start[426] = 33;
		decl_end[426] = 38;
		decl_start[427] = 30;
		decl_end[427] = 38;
		decl_start[428] = 31;
		decl_end[428] = 36;
		decl_start[429] = 30;
		decl_end[429] = 38;
		decl_start[430] = 30;
		decl_end[430] = 36;
		decl_start[431] = 30;
		decl_end[431] = 38;
		decl_start[432] = 30;
		decl_end[432] = 35;
		decl_start[433] = 30;
		decl_end[433] = 38;
		decl_start[434] = 30;
		decl_end[434] = 38;
		decl_start[435] = 30;
		decl_end[435] = 38;
		decl_start[436] = 30;
		decl_end[436] = 38;
		decl_start[437] = 30;
		decl_end[437] = 38;
		decl_start[438] = 30;
		decl_end[438] = 38;
		decl_start[439] = 30;
		decl_end[439] = 38;
		decl_start[440] = 30;
		decl_end[440] = 38;
		decl_start[441] = 30;
		decl_end[441] = 38;
		decl_start[442] = 30;
		decl_end[442] = 38;
		decl_start[443] = 30;
		decl_end[443] = 38;
		decl_start[444] = 30;
		decl_end[444] = 38;
		decl_start[445] = 30;
		decl_end[445] = 38;
		decl_start[446] = 30;
		decl_end[446] = 38;
		decl_start[447] = 30;
		decl_end[447] = 38;
		decl_start[448] = 30;
		decl_end[448] = 38;
		decl_start[449] = 30;
		decl_end[449] = 38;
		decl_start[450] = 30;
		decl_end[450] = 38;
		decl_start[451] = 30;
		decl_end[451] = 38;
		decl_start[452] = 30;
		decl_end[452] = 36;
		decl_start[453] = 30;
		decl_end[453] = 38;
		decl_start[454] = 30;
		decl_end[454] = 34;
		decl_start[455] = 31;
		decl_end[455] = 36;
		decl_start[456] = 30;
		decl_end[456] = 38;
		decl_start[457] = 30;
		decl_end[457] = 34;
		decl_start[458] = 31;
		decl_end[458] = 36;
		decl_start[459] = 33;
		decl_end[459] = 38;
		decl_start[460] = 30;
		decl_end[460] = 38;
		decl_start[461] = 30;
		decl_end[461] = 32;
		decl_start[462] = 30;
		decl_end[462] = 34;
		decl_start[463] = 31;
		decl_end[463] = 36;
		decl_start[464] = 33;
		decl_end[464] = 38;
		decl_start[465] = 30;
		decl_end[465] = 38;
		decl_start[466] = 30;
		decl_end[466] = 32;
		decl_start[467] = 30;
		decl_end[467] = 32;
		decl_start[468] = 30;
		decl_end[468] = 34;
		decl_start[469] = 31;
		decl_end[469] = 34;
		decl_start[470] = 32;
		decl_end[470] = 36;
		decl_start[471] = 33;
		decl_end[471] = 38;
		decl_start[472] = 35;
		decl_end[472] = 38;
		decl_start[473] = 30;
		decl_end[473] = 38;
		decl_start[474] = 30;
		decl_end[474] = 32;
		decl_start[475] = 30;
		decl_end[475] = 32;
		decl_start[476] = 30;
		decl_end[476] = 34;
		decl_start[477] = 31;
		decl_end[477] = 34;
		decl_start[478] = 31;
		decl_end[478] = 36;
		decl_start[479] = 33;
		decl_end[479] = 36;
		decl_start[480] = 33;
		decl_end[480] = 38;
		decl_start[481] = 35;
		decl_end[481] = 38;
		decl_start[482] = 30;
		decl_end[482] = 38;
		decl_start[483] = 30;
		decl_end[483] = 32;
		decl_start[484] = 30;
		decl_end[484] = 34;
		decl_start[485] = 31;
		decl_end[485] = 34;
		decl_start[486] = 31;
		decl_end[486] = 36;
		decl_start[487] = 33;
		decl_end[487] = 36;
		decl_start[488] = 33;
		decl_end[488] = 38;
		decl_start[489] = 35;
		decl_end[489] = 38;
		decl_start[490] = 30;
		decl_end[490] = 38;
		decl_start[491] = 30;
		decl_end[491] = 34;
		decl_start[492] = 31;
		decl_end[492] = 36;
		decl_start[493] = 33;
		decl_end[493] = 36;
		decl_start[494] = 33;
		decl_end[494] = 38;
		decl_start[495] = 35;
		decl_end[495] = 38;
		decl_start[496] = 30;
		decl_end[496] = 38;
		decl_start[497] = 30;
		decl_end[497] = 34;
		decl_start[498] = 31;
		decl_end[498] = 36;
		decl_start[499] = 33;
		decl_end[499] = 38;
		decl_start[500] = 30;
		decl_end[500] = 38;
		decl_start[501] = 30;
		decl_end[501] = 36;
		decl_start[502] = 33;
		decl_end[502] = 38;
		decl_start[503] = 30;
		decl_end[503] = 38;
		decl_start[504] = 30;
		decl_end[504] = 36;
		decl_start[505] = 33;
		decl_end[505] = 38;
		decl_start[506] = 30;
		decl_end[506] = 38;
		decl_start[507] = 30;
		decl_end[507] = 36;
		decl_start[508] = 33;
		decl_end[508] = 38;
		decl_start[509] = 35;
		decl_end[509] = 42;
		decl_start[510] = 39;
		decl_end[510] = 44;
		decl_start[511] = 41;
		decl_end[511] = 45;
		decl_start[512] = 37;
		decl_end[512] = 45;
		decl_start[513] = 39;
		decl_end[513] = 44;
		decl_start[514] = 41;
		decl_end[514] = 45;
		decl_start[515] = 37;
		decl_end[515] = 45;
		decl_start[516] = 39;
		decl_end[516] = 44;
		decl_start[517] = 41;
		decl_end[517] = 45;
		decl_start[518] = 37;
		decl_end[518] = 45;
		decl_start[519] = 37;
		decl_end[519] = 42;
		decl_start[520] = 39;
		decl_end[520] = 44;
		decl_start[521] = 41;
		decl_end[521] = 45;
		decl_start[522] = 37;
		decl_end[522] = 45;
		decl_start[523] = 39;
		decl_end[523] = 44;
		decl_start[524] = 41;
		decl_end[524] = 45;
		decl_start[525] = 37;
		decl_end[525] = 45;
		decl_start[526] = 37;
		decl_end[526] = 42;
		decl_start[527] = 39;
		decl_end[527] = 44;
		decl_start[528] = 41;
		decl_end[528] = 45;
		decl_start[529] = 37;
		decl_end[529] = 45;
		decl_start[530] = 39;
		decl_end[530] = 44;
		decl_start[531] = 41;
		decl_end[531] = 45;
		decl_start[532] = 37;
		decl_end[532] = 45;
		decl_start[533] = 37;
		decl_end[533] = 42;
		decl_start[534] = 39;
		decl_end[534] = 44;
		decl_start[535] = 41;
		decl_end[535] = 45;
		decl_start[536] = 37;
		decl_end[536] = 45;
		decl_start[537] = 37;
		decl_end[537] = 42;
		decl_start[538] = 39;
		decl_end[538] = 42;
		decl_start[539] = 39;
		decl_end[539] = 44;
		decl_start[540] = 41;
		decl_end[540] = 45;
		decl_start[541] = 37;
		decl_end[541] = 45;
		decl_start[542] = 37;
		decl_end[542] = 44;
		decl_start[543] = 41;
		decl_end[543] = 45;
		decl_start[544] = 37;
		decl_end[544] = 45;
		decl_start[545] = 37;
		decl_end[545] = 42;
		decl_start[546] = 39;
		decl_end[546] = 45;
		decl_start[547] = 37;
		decl_end[547] = 45;
		decl_start[548] = 39;
		decl_end[548] = 44;
		decl_start[549] = 37;
		decl_end[549] = 45;
		decl_start[550] = 37;
		decl_end[550] = 43;
		decl_start[551] = 37;
		decl_end[551] = 45;
		decl_start[552] = 37;
		decl_end[552] = 45;
		decl_start[553] = 37;
		decl_end[553] = 45;
		decl_start[554] = 37;
		decl_end[554] = 45;
		decl_start[555] = 37;
		decl_end[555] = 45;
		decl_start[556] = 37;
		decl_end[556] = 45;
		decl_start[557] = 37;
		decl_end[557] = 45;
		decl_start[558] = 37;
		decl_end[558] = 45;
		decl_start[559] = 37;
		decl_end[559] = 45;
		decl_start[560] = 37;
		decl_end[560] = 45;
		decl_start[561] = 37;
		decl_end[561] = 45;
		decl_start[562] = 37;
		decl_end[562] = 45;
		decl_start[563] = 37;
		decl_end[563] = 45;
		decl_start[564] = 37;
		decl_end[564] = 45;
		decl_start[565] = 37;
		decl_end[565] = 45;
		decl_start[566] = 37;
		decl_end[566] = 45;
		decl_start[567] = 37;
		decl_end[567] = 45;
		decl_start[568] = 40;
		decl_end[568] = 45;
		decl_start[569] = 37;
		decl_end[569] = 45;
		decl_start[570] = 39;
		decl_end[570] = 44;
		decl_start[571] = 37;
		decl_end[571] = 45;
		decl_start[572] = 37;
		decl_end[572] = 42;
		decl_start[573] = 39;
		decl_end[573] = 45;
		decl_start[574] = 37;
		decl_end[574] = 45;
		decl_start[575] = 37;
		decl_end[575] = 42;
		decl_start[576] = 39;
		decl_end[576] = 44;
		decl_start[577] = 41;
		decl_end[577] = 45;
		decl_start[578] = 37;
		decl_end[578] = 45;
		decl_start[579] = 37;
		decl_end[579] = 42;
		decl_start[580] = 39;
		decl_end[580] = 44;
		decl_start[581] = 41;
		decl_end[581] = 45;
		decl_start[582] = 37;
		decl_end[582] = 45;
		decl_start[583] = 37;
		decl_end[583] = 40;
		decl_start[584] = 37;
		decl_end[584] = 42;
		decl_start[585] = 39;
		decl_end[585] = 42;
		decl_start[586] = 39;
		decl_end[586] = 44;
		decl_start[587] = 41;
		decl_end[587] = 44;
		decl_start[588] = 41;
		decl_end[588] = 45;
		decl_start[589] = 37;
		decl_end[589] = 46;
		decl_start[590] = 37;
		decl_end[590] = 40;
		decl_start[591] = 37;
		decl_end[591] = 40;
		decl_start[592] = 37;
		decl_end[592] = 42;
		decl_start[593] = 39;
		decl_end[593] = 42;
		decl_start[594] = 39;
		decl_end[594] = 44;
		decl_start[595] = 41;
		decl_end[595] = 44;
		decl_start[596] = 41;
		decl_end[596] = 45;
		decl_start[597] = 37;
		decl_end[597] = 45;
		decl_start[598] = 37;
		decl_end[598] = 40;
		decl_start[599] = 37;
		decl_end[599] = 42;
		decl_start[600] = 39;
		decl_end[600] = 42;
		decl_start[601] = 39;
		decl_end[601] = 44;
		decl_start[602] = 41;
		decl_end[602] = 45;
		decl_start[603] = 43;
		decl_end[603] = 45;
		decl_start[604] = 37;
		decl_end[604] = 45;
		decl_start[605] = 37;
		decl_end[605] = 42;
		decl_start[606] = 39;
		decl_end[606] = 44;
		decl_start[607] = 41;
		decl_end[607] = 44;
		decl_start[608] = 41;
		decl_end[608] = 45;
		decl_start[609] = 37;
		decl_end[609] = 45;
		decl_start[610] = 37;
		decl_end[610] = 42;
		decl_start[611] = 39;
		decl_end[611] = 42;
		decl_start[612] = 39;
		decl_end[612] = 44;
		decl_start[613] = 41;
		decl_end[613] = 45;
		decl_start[614] = 37;
		decl_end[614] = 45;
		decl_start[615] = 37;
		decl_end[615] = 42;
		decl_start[616] = 39;
		decl_end[616] = 44;
		decl_start[617] = 41;
		decl_end[617] = 45;
		decl_start[618] = 37;
		decl_end[618] = 45;
		decl_start[619] = 39;
		decl_end[619] = 44;
		decl_start[620] = 41;
		decl_end[620] = 45;
		decl_start[621] = 43;
		decl_end[621] = 47;
		decl_start[622] = 45;
		decl_end[622] = 49;
		decl_start[623] = 46;
		decl_end[623] = 51;
		decl_start[624] = 48;
		decl_end[624] = 52;
		decl_start[625] = 50;
		decl_end[625] = 53;
		decl_start[626] = 45;
		decl_end[626] = 53;
		decl_start[627] = 45;
		decl_end[627] = 49;
		decl_start[628] = 47;
		decl_end[628] = 51;
		decl_start[629] = 48;
		decl_end[629] = 53;
		decl_start[630] = 45;
		decl_end[630] = 53;
		decl_start[631] = 45;
		decl_end[631] = 49;
		decl_start[632] = 46;
		decl_end[632] = 51;
		decl_start[633] = 48;
		decl_end[633] = 51;
		decl_start[634] = 48;
		decl_end[634] = 53;
		decl_start[635] = 45;
		decl_end[635] = 53;
		decl_start[636] = 45;
		decl_end[636] = 49;
		decl_start[637] = 46;
		decl_end[637] = 49;
		decl_start[638] = 46;
		decl_end[638] = 51;
		decl_start[639] = 48;
		decl_end[639] = 53;
		decl_start[640] = 45;
		decl_end[640] = 53;
		decl_start[641] = 45;
		decl_end[641] = 47;
		decl_start[642] = 45;
		decl_end[642] = 49;
		decl_start[643] = 46;
		decl_end[643] = 51;
		decl_start[644] = 48;
		decl_end[644] = 53;
		decl_start[645] = 45;
		decl_end[645] = 53;
		decl_start[646] = 45;
		decl_end[646] = 51;
		decl_start[647] = 48;
		decl_end[647] = 53;
		decl_start[648] = 45;
		decl_end[648] = 53;
		decl_start[649] = 45;
		decl_end[649] = 49;
		decl_start[650] = 46;
		decl_end[650] = 51;
		decl_start[651] = 45;
		decl_end[651] = 53;
		decl_start[652] = 45;
		decl_end[652] = 49;
		decl_start[653] = 46;
		decl_end[653] = 51;
		decl_start[654] = 45;
		decl_end[654] = 53;
		decl_start[655] = 45;
		decl_end[655] = 49;
		decl_start[656] = 46;
		decl_end[656] = 51;
		decl_start[657] = 45;
		decl_end[657] = 53;
		decl_start[658] = 45;
		decl_end[658] = 49;
		decl_start[659] = 46;
		decl_end[659] = 53;
		decl_start[660] = 45;
		decl_end[660] = 53;
		decl_start[661] = 45;
		decl_end[661] = 53;
		decl_start[662] = 45;
		decl_end[662] = 53;
		decl_start[663] = 45;
		decl_end[663] = 53;
		decl_start[664] = 45;
		decl_end[664] = 50;
		decl_start[665] = 45;
		decl_end[665] = 53;
		decl_start[666] = 45;
		decl_end[666] = 53;
		decl_start[667] = 45;
		decl_end[667] = 53;
		decl_start[668] = 45;
		decl_end[668] = 53;
		decl_start[669] = 45;
		decl_end[669] = 53;
		decl_start[670] = 45;
		decl_end[670] = 53;
		decl_start[671] = 45;
		decl_end[671] = 53;
		decl_start[672] = 45;
		decl_end[672] = 53;
		decl_start[673] = 45;
		decl_end[673] = 53;
		decl_start[674] = 45;
		decl_end[674] = 53;
		decl_start[675] = 45;
		decl_end[675] = 53;
		decl_start[676] = 45;
		decl_end[676] = 53;
		decl_start[677] = 45;
		decl_end[677] = 53;
		decl_start[678] = 47;
		decl_end[678] = 53;
		decl_start[679] = 45;
		decl_end[679] = 52;
		decl_start[680] = 47;
		decl_end[680] = 53;
		decl_start[681] = 45;
		decl_end[681] = 53;
		decl_start[682] = 46;
		decl_end[682] = 53;
		decl_start[683] = 45;
		decl_end[683] = 53;
		decl_start[684] = 45;
		decl_end[684] = 49;
		decl_start[685] = 46;
		decl_end[685] = 51;
		decl_start[686] = 45;
		decl_end[686] = 53;
		decl_start[687] = 45;
		decl_end[687] = 49;
		decl_start[688] = 46;
		decl_end[688] = 49;
		decl_start[689] = 47;
		decl_end[689] = 51;
		decl_start[690] = 49;
		decl_end[690] = 53;
		decl_start[691] = 45;
		decl_end[691] = 53;
		decl_start[692] = 45;
		decl_end[692] = 49;
		decl_start[693] = 46;
		decl_end[693] = 49;
		decl_start[694] = 46;
		decl_end[694] = 51;
		decl_start[695] = 48;
		decl_end[695] = 53;
		decl_start[696] = 45;
		decl_end[696] = 53;
		decl_start[697] = 45;
		decl_end[697] = 47;
		decl_start[698] = 45;
		decl_end[698] = 49;
		decl_start[699] = 46;
		decl_end[699] = 49;
		decl_start[700] = 46;
		decl_end[700] = 51;
		decl_start[701] = 48;
		decl_end[701] = 53;
		decl_start[702] = 50;
		decl_end[702] = 53;
		decl_start[703] = 45;
		decl_end[703] = 53;
		decl_start[704] = 45;
		decl_end[704] = 47;
		decl_start[705] = 45;
		decl_end[705] = 49;
		decl_start[706] = 46;
		decl_end[706] = 49;
		decl_start[707] = 46;
		decl_end[707] = 51;
		decl_start[708] = 48;
		decl_end[708] = 53;
		decl_start[709] = 50;
		decl_end[709] = 53;
		decl_start[710] = 45;
		decl_end[710] = 53;
		decl_start[711] = 45;
		decl_end[711] = 49;
		decl_start[712] = 46;
		decl_end[712] = 49;
		decl_start[713] = 46;
		decl_end[713] = 51;
		decl_start[714] = 48;
		decl_end[714] = 51;
		decl_start[715] = 48;
		decl_end[715] = 53;
		decl_start[716] = 50;
		decl_end[716] = 53;
		decl_start[717] = 45;
		decl_end[717] = 53;
		decl_start[718] = 45;
		decl_end[718] = 47;
		decl_start[719] = 45;
		decl_end[719] = 49;
		decl_start[720] = 46;
		decl_end[720] = 51;
		decl_start[721] = 48;
		decl_end[721] = 51;
		decl_start[722] = 48;
		decl_end[722] = 53;
		decl_start[723] = 45;
		decl_end[723] = 53;
		decl_start[724] = 45;
		decl_end[724] = 49;
		decl_start[725] = 46;
		decl_end[725] = 49;
		decl_start[726] = 46;
		decl_end[726] = 51;
		decl_start[727] = 48;
		decl_end[727] = 53;
		decl_start[728] = 50;
		decl_end[728] = 55;
		decl_start[729] = 52;
		decl_end[729] = 55;
		decl_start[730] = 52;
		decl_end[730] = 57;
		decl_start[731] = 54;
		decl_end[731] = 57;
		decl_start[732] = 54;
		decl_end[732] = 59;
		decl_start[733] = 56;
		decl_end[733] = 60;
		decl_start[734] = 58;
		decl_end[734] = 60;
		decl_start[735] = 52;
		decl_end[735] = 60;
		decl_start[736] = 52;
		decl_end[736] = 57;
		decl_start[737] = 54;
		decl_end[737] = 57;
		decl_start[738] = 54;
		decl_end[738] = 58;
		decl_start[739] = 56;
		decl_end[739] = 59;
		decl_start[740] = 56;
		decl_end[740] = 60;
		decl_start[741] = 58;
		decl_end[741] = 60;
		decl_start[742] = 52;
		decl_end[742] = 60;
		decl_start[743] = 52;
		decl_end[743] = 57;
		decl_start[744] = 54;
		decl_end[744] = 57;
		decl_start[745] = 54;
		decl_end[745] = 59;
		decl_start[746] = 56;
		decl_end[746] = 59;
		decl_start[747] = 56;
		decl_end[747] = 59;
		decl_start[748] = 56;
		decl_end[748] = 60;
		decl_start[749] = 58;
		decl_end[749] = 60;
		decl_start[750] = 52;
		decl_end[750] = 60;
		decl_start[751] = 54;
		decl_end[751] = 59;
		decl_start[752] = 56;
		decl_end[752] = 60;
		decl_start[753] = 52;
		decl_end[753] = 60;
		decl_start[754] = 52;
		decl_end[754] = 59;
		decl_start[755] = 56;
		decl_end[755] = 60;
		decl_start[756] = 52;
		decl_end[756] = 60;
		decl_start[757] = 54;
		decl_end[757] = 59;
		decl_start[758] = 52;
		decl_end[758] = 60;
		decl_start[759] = 52;
		decl_end[759] = 57;
		decl_start[760] = 54;
		decl_end[760] = 60;
		decl_start[761] = 52;
		decl_end[761] = 60;
		decl_start[762] = 52;
		decl_end[762] = 57;
		decl_start[763] = 54;
		decl_end[763] = 60;
		decl_start[764] = 52;
		decl_end[764] = 60;
		decl_start[765] = 54;
		decl_end[765] = 60;
		decl_start[766] = 52;
		decl_end[766] = 60;
		decl_start[767] = 52;
		decl_end[767] = 60;
		decl_start[768] = 52;
		decl_end[768] = 60;
		decl_start[769] = 52;
		decl_end[769] = 60;
		decl_start[770] = 52;
		decl_end[770] = 60;
		decl_start[771] = 52;
		decl_end[771] = 60;
		decl_start[772] = 52;
		decl_end[772] = 60;
		decl_start[773] = 52;
		decl_end[773] = 60;
		decl_start[774] = 52;
		decl_end[774] = 60;
		decl_start[775] = 52;
		decl_end[775] = 60;
		decl_start[776] = 52;
		decl_end[776] = 60;
		decl_start[777] = 52;
		decl_end[777] = 60;
		decl_start[778] = 52;
		decl_end[778] = 60;
		decl_start[779] = 52;
		decl_end[779] = 60;
		decl_start[780] = 52;
		decl_end[780] = 60;
		decl_start[781] = 55;
		decl_end[781] = 60;
		decl_start[782] = 52;
		decl_end[782] = 60;
		decl_start[783] = 54;
		decl_end[783] = 60;
		decl_start[784] = 52;
		decl_end[784] = 60;
		decl_start[785] = 52;
		decl_end[785] = 58;
		decl_start[786] = 56;
		decl_end[786] = 60;
		decl_start[787] = 52;
		decl_end[787] = 60;
		decl_start[788] = 52;
		decl_end[788] = 57;
		decl_start[789] = 54;
		decl_end[789] = 59;
		decl_start[790] = 56;
		decl_end[790] = 60;
		decl_start[791] = 52;
		decl_end[791] = 60;
		decl_start[792] = 52;
		decl_end[792] = 57;
		decl_start[793] = 54;
		decl_end[793] = 57;
		decl_start[794] = 54;
		decl_end[794] = 59;
		decl_start[795] = 56;
		decl_end[795] = 60;
		decl_start[796] = 52;
		decl_end[796] = 60;
		decl_start[797] = 52;
		decl_end[797] = 57;
		decl_start[798] = 54;
		decl_end[798] = 59;
		decl_start[799] = 56;
		decl_end[799] = 60;
		decl_start[800] = 52;
		decl_end[800] = 60;
		decl_start[801] = 52;
		decl_end[801] = 55;
		decl_start[802] = 52;
		decl_end[802] = 57;
		decl_start[803] = 54;
		decl_end[803] = 57;
		decl_start[804] = 54;
		decl_end[804] = 59;
		decl_start[805] = 56;
		decl_end[805] = 60;
		decl_start[806] = 52;
		decl_end[806] = 60;
		decl_start[807] = 52;
		decl_end[807] = 55;
		decl_start[808] = 52;
		decl_end[808] = 57;
		decl_start[809] = 54;
		decl_end[809] = 57;
		decl_start[810] = 54;
		decl_end[810] = 59;
		decl_start[811] = 56;
		decl_end[811] = 59;
		decl_start[812] = 56;
		decl_end[812] = 60;
		decl_start[813] = 52;
		decl_end[813] = 60;
		decl_start[814] = 52;
		decl_end[814] = 55;
		decl_start[815] = 52;
		decl_end[815] = 57;
		decl_start[816] = 54;
		decl_end[816] = 59;
		decl_start[817] = 56;
		decl_end[817] = 59;
		decl_start[818] = 56;
		decl_end[818] = 60;
		decl_start[819] = 58;
		decl_end[819] = 62;
		decl_start[820] = 60;
		decl_end[820] = 62;
		decl_start[821] = 60;
		decl_end[821] = 64;
		decl_start[822] = 61;
		decl_end[822] = 66;
		decl_start[823] = 63;
		decl_end[823] = 68;
		decl_start[824] = 60;
		decl_end[824] = 68;
		decl_start[825] = 60;
		decl_end[825] = 62;
		decl_start[826] = 60;
		decl_end[826] = 64;
		decl_start[827] = 61;
		decl_end[827] = 66;
		decl_start[828] = 63;
		decl_end[828] = 66;
		decl_start[829] = 60;
		decl_end[829] = 68;
		decl_start[830] = 60;
		decl_end[830] = 62;
		decl_start[831] = 60;
		decl_end[831] = 64;
		decl_start[832] = 61;
		decl_end[832] = 66;
		decl_start[833] = 60;
		decl_end[833] = 68;
		decl_start[834] = 60;
		decl_end[834] = 64;
		decl_start[835] = 61;
		decl_end[835] = 66;
		decl_start[836] = 63;
		decl_end[836] = 68;
		decl_start[837] = 60;
		decl_end[837] = 68;
		decl_start[838] = 61;
		decl_end[838] = 66;
		decl_start[839] = 63;
		decl_end[839] = 68;
		decl_start[840] = 60;
		decl_end[840] = 68;
		decl_start[841] = 61;
		decl_end[841] = 66;
		decl_start[842] = 60;
		decl_end[842] = 68;
		decl_start[843] = 60;
		decl_end[843] = 64;
		decl_start[844] = 61;
		decl_end[844] = 68;
		decl_start[845] = 60;
		decl_end[845] = 68;
		decl_start[846] = 62;
		decl_end[846] = 68;
		decl_start[847] = 60;
		decl_end[847] = 68;
		decl_start[848] = 60;
		decl_end[848] = 68;
		decl_start[849] = 60;
		decl_end[849] = 68;
		decl_start[850] = 60;
		decl_end[850] = 68;
		decl_start[851] = 60;
		decl_end[851] = 68;
		decl_start[852] = 60;
		decl_end[852] = 68;
		decl_start[853] = 60;
		decl_end[853] = 68;
		decl_start[854] = 60;
		decl_end[854] = 68;
		decl_start[855] = 60;
		decl_end[855] = 68;
		decl_start[856] = 62;
		decl_end[856] = 68;
		decl_start[857] = 60;
		decl_end[857] = 68;
		decl_start[858] = 60;
		decl_end[858] = 68;
		decl_start[859] = 60;
		decl_end[859] = 64;
		decl_start[860] = 61;
		decl_end[860] = 68;
		decl_start[861] = 60;
		decl_end[861] = 68;
		decl_start[862] = 60;
		decl_end[862] = 64;
		decl_start[863] = 61;
		decl_end[863] = 68;
		decl_start[864] = 60;
		decl_end[864] = 68;
		decl_start[865] = 60;
		decl_end[865] = 64;
		decl_start[866] = 61;
		decl_end[866] = 66;
		decl_start[867] = 63;
		decl_end[867] = 68;
		decl_start[868] = 60;
		decl_end[868] = 68;
		decl_start[869] = 60;
		decl_end[869] = 64;
		decl_start[870] = 61;
		decl_end[870] = 66;
		decl_start[871] = 60;
		decl_end[871] = 68;
		decl_start[872] = 60;
		decl_end[872] = 62;
		decl_start[873] = 60;
		decl_end[873] = 64;
		decl_start[874] = 61;
		decl_end[874] = 66;
		decl_start[875] = 60;
		decl_end[875] = 68;
		decl_start[876] = 60;
		decl_end[876] = 62;
		decl_start[877] = 60;
		decl_end[877] = 64;
		decl_start[878] = 61;
		decl_end[878] = 64;
		decl_start[879] = 61;
		decl_end[879] = 66;
		decl_start[880] = 63;
		decl_end[880] = 70;
		decl_start[881] = 67;
		decl_end[881] = 72;
		decl_start[882] = 69;
		decl_end[882] = 74;
		decl_start[883] = 71;
		decl_end[883] = 75;
		decl_start[884] = 67;
		decl_end[884] = 75;
		decl_start[885] = 67;
		decl_end[885] = 72;
		decl_start[886] = 69;
		decl_end[886] = 75;
		decl_start[887] = 67;
		decl_end[887] = 75;
		decl_start[888] = 67;
		decl_end[888] = 72;
		decl_start[889] = 69;
		decl_end[889] = 74;
		decl_start[890] = 67;
		decl_end[890] = 75;
		decl_start[891] = 67;
		decl_end[891] = 72;
		decl_start[892] = 69;
		decl_end[892] = 74;
		decl_start[893] = 71;
		decl_end[893] = 75;
		decl_start[894] = 67;
		decl_end[894] = 75;
		decl_start[895] = 69;
		decl_end[895] = 74;
		decl_start[896] = 67;
		decl_end[896] = 75;
		decl_start[897] = 67;
		decl_end[897] = 73;
		decl_start[898] = 70;
		decl_end[898] = 75;
		decl_start[899] = 67;
		decl_end[899] = 75;
		decl_start[900] = 70;
		decl_end[900] = 75;
		decl_start[901] = 67;
		decl_end[901] = 75;
		decl_start[902] = 67;
		decl_end[902] = 75;
		decl_start[903] = 67;
		decl_end[903] = 75;
		decl_start[904] = 67;
		decl_end[904] = 75;
		decl_start[905] = 67;
		decl_end[905] = 75;
		decl_start[906] = 67;
		decl_end[906] = 75;
		decl_start[907] = 67;
		decl_end[907] = 75;
		decl_start[908] = 67;
		decl_end[908] = 75;
		decl_start[909] = 67;
		decl_end[909] = 72;
		decl_start[910] = 69;
		decl_end[910] = 75;
		decl_start[911] = 67;
		decl_end[911] = 75;
		decl_start[912] = 67;
		decl_end[912] = 74;
		decl_start[913] = 67;
		decl_end[913] = 75;
		decl_start[914] = 67;
		decl_end[914] = 72;
		decl_start[915] = 69;
		decl_end[915] = 74;
		decl_start[916] = 67;
		decl_end[916] = 75;
		decl_start[917] = 67;
		decl_end[917] = 72;
		decl_start[918] = 69;
		decl_end[918] = 74;
		decl_start[919] = 71;
		decl_end[919] = 76;
		decl_start[920] = 75;
		decl_end[920] = 79;
		decl_start[921] = 76;
		decl_end[921] = 81;
		decl_start[922] = 75;
		decl_end[922] = 83;
		decl_start[923] = 75;
		decl_end[923] = 79;
		decl_start[924] = 76;
		decl_end[924] = 81;
		decl_start[925] = 75;
		decl_end[925] = 83;
		decl_start[926] = 74;
		decl_end[926] = 79;
		decl_start[927] = 76;
		decl_end[927] = 83;
		decl_start[928] = 75;
		decl_end[928] = 83;
		decl_start[929] = 75;
		decl_end[929] = 80;
		decl_start[930] = 75;
		decl_end[930] = 83;
		decl_start[931] = 75;
		decl_end[931] = 80;
		decl_start[932] = 75;
		decl_end[932] = 83;
		decl_start[933] = 75;
		decl_end[933] = 80;
		decl_start[934] = 75;
		decl_end[934] = 83;
		decl_start[935] = 75;
		decl_end[935] = 79;
		decl_start[936] = 76;
		decl_end[936] = 83;
		decl_start[937] = 74;
		decl_end[937] = 83;
		decl_start[938] = 75;
		decl_end[938] = 81;
		decl_start[939] = 75;
		decl_end[939] = 83;
		decl_start[940] = 75;
		decl_end[940] = 79;
		decl_start[941] = 76;
		decl_end[941] = 81;
		decl_start[942] = 78;
		decl_end[942] = 85;
		decl_start[943] = 82;
		decl_end[943] = 85;
		decl_start[944] = 82;
		decl_end[944] = 88;
		decl_start[945] = 82;
		decl_end[945] = 90;
		decl_start[946] = 82;
		decl_end[946] = 87;
		decl_start[947] = 82;
		decl_end[947] = 90;
		decl_start[948] = 82;
		decl_end[948] = 87;
		decl_start[949] = -2;
		decl_end[949] = 90;
		decl_start[950] = -8;
		decl_end[950] = 0;
		decl_start[951] = -8;
		decl_end[951] = 0;
		decl_start[952] = -8;
		decl_end[952] = 0;
		decl_start[953] = -8;
		decl_end[953] = 0;
		decl_start[954] = -8;
		decl_end[954] = 0;
		decl_start[955] = -8;
		decl_end[955] = 0;
		decl_start[956] = -8;
		decl_end[956] = 0;
		decl_start[957] = -8;
		decl_end[957] = 0;
		decl_start[958] = -8;
		decl_end[958] = 0;
		decl_start[959] = -8;
		decl_end[959] = 0;
		decl_start[960] = -8;
		decl_end[960] = 0;
		decl_start[961] = -8;
		decl_end[961] = 0;
		decl_start[962] = -6;
		decl_end[962] = -1;
		decl_start[963] = -8;
		decl_end[963] = 0;
		decl_start[964] = -4;
		decl_end[964] = 0;
		decl_start[965] = -6;
		decl_end[965] = -1;
		decl_start[966] = -8;
		decl_end[966] = -1;
		decl_start[967] = -4;
		decl_end[967] = 0;
		decl_start[968] = -8;
		decl_end[968] = -1;
		decl_start[969] = -8;
		decl_end[969] = 0;
		decl_start[970] = -4;
		decl_end[970] = 0;
		decl_start[971] = -8;
		decl_end[971] = -1;
		decl_start[972] = -8;
		decl_end[972] = 0;
		decl_start[973] = -4;
		decl_end[973] = 0;
		decl_start[974] = -4;
		decl_end[974] = -1;
		decl_start[975] = -6;
		decl_end[975] = -1;
		decl_start[976] = -8;
		decl_end[976] = -3;
		decl_start[977] = -8;
		decl_end[977] = 0;
		decl_start[978] = -4;
		decl_end[978] = 0;
		decl_start[979] = -4;
		decl_end[979] = -1;
		decl_start[980] = -6;
		decl_end[980] = -1;
		decl_start[981] = -8;
		decl_end[981] = -3;
		decl_start[982] = -8;
		decl_end[982] = -5;
		decl_start[983] = -8;
		decl_end[983] = 0;
		decl_start[984] = -4;
		decl_end[984] = 0;
		decl_start[985] = -6;
		decl_end[985] = -1;
		decl_start[986] = -8;
		decl_end[986] = -3;
		decl_start[987] = -8;
		decl_end[987] = 0;
		decl_start[988] = -4;
		decl_end[988] = 0;
		decl_start[989] = -6;
		decl_end[989] = -1;
		decl_start[990] = -8;
		decl_end[990] = -3;
		decl_start[991] = -8;
		decl_end[991] = 0;
		decl_start[992] = -6;
		decl_end[992] = 0;
		decl_start[993] = -8;
		decl_end[993] = -3;
		decl_start[994] = -8;
		decl_end[994] = 0;
		decl_start[995] = -8;
		decl_end[995] = -1;
		decl_start[996] = -8;
		decl_end[996] = 0;
		decl_start[997] = -8;
		decl_end[997] = 0;
		decl_start[998] = -8;
		decl_end[998] = 0;
		decl_start[999] = -8;
		decl_end[999] = 0;
		decl_start[1000] = -8;
		decl_end[1000] = 0;
		decl_start[1001] = -8;
		decl_end[1001] = 0;
		decl_start[1002] = -8;
		decl_end[1002] = 0;
		decl_start[1003] = -8;
		decl_end[1003] = 0;
		decl_start[1004] = -8;
		decl_end[1004] = 0;
		decl_start[1005] = -8;
		decl_end[1005] = 0;
		decl_start[1006] = -8;
		decl_end[1006] = 0;
		decl_start[1007] = -8;
		decl_end[1007] = 0;
		decl_start[1008] = -8;
		decl_end[1008] = 0;
		decl_start[1009] = -8;
		decl_end[1009] = 0;
		decl_start[1010] = -8;
		decl_end[1010] = 0;
		decl_start[1011] = -8;
		decl_end[1011] = 0;
		decl_start[1012] = -8;
		decl_end[1012] = 0;
		decl_start[1013] = -8;
		decl_end[1013] = 0;
		decl_start[1014] = -8;
		decl_end[1014] = 0;
		decl_start[1015] = -8;
		decl_end[1015] = 0;
		decl_start[1016] = -8;
		decl_end[1016] = 0;
		decl_start[1017] = -6;
		decl_end[1017] = 0;
		decl_start[1018] = -8;
		decl_end[1018] = 0;
		decl_start[1019] = -8;
		decl_end[1019] = 0;
		decl_start[1020] = -6;
		decl_end[1020] = 0;
		decl_start[1021] = -8;
		decl_end[1021] = 0;
		decl_start[1022] = -4;
		decl_end[1022] = 0;
		decl_start[1023] = -8;
		decl_end[1023] = -1;
		decl_start[1024] = -8;
		decl_end[1024] = 0;
		decl_start[1025] = -6;
		decl_end[1025] = 0;
		decl_start[1026] = -8;
		decl_end[1026] = -3;
		decl_start[1027] = -8;
		decl_end[1027] = 0;
		decl_start[1028] = -6;
		decl_end[1028] = -1;
		decl_start[1029] = -8;
		decl_end[1029] = 0;
		decl_start[1030] = -4;
		decl_end[1030] = 0;
		decl_start[1031] = -6;
		decl_end[1031] = -1;
		decl_start[1032] = -8;
		decl_end[1032] = 0;
		decl_start[1033] = -6;
		decl_end[1033] = 0;
		decl_start[1034] = -8;
		decl_end[1034] = 0;
		decl_start[1035] = -8;
		decl_end[1035] = 0;
		decl_start[1036] = -8;
		decl_end[1036] = 0;
		decl_start[1037] = -8;
		decl_end[1037] = 0;
		decl_start[1038] = -8;
		decl_end[1038] = 0;
		decl_start[1039] = -8;
		decl_end[1039] = 0;
		decl_start[1040] = -8;
		decl_end[1040] = 0;
		decl_start[1041] = -13;
		decl_end[1041] = -2;
		decl_start[1042] = -15;
		decl_end[1042] = -7;
		decl_start[1043] = -15;
		decl_end[1043] = -7;
		decl_start[1044] = -15;
		decl_end[1044] = -7;
		decl_start[1045] = -15;
		decl_end[1045] = -7;
		decl_start[1046] = -15;
		decl_end[1046] = -7;
		decl_start[1047] = -15;
		decl_end[1047] = -7;
		decl_start[1048] = -15;
		decl_end[1048] = -7;
		decl_start[1049] = -15;
		decl_end[1049] = -7;
		decl_start[1050] = -15;
		decl_end[1050] = -7;
		decl_start[1051] = -15;
		decl_end[1051] = -7;
		decl_start[1052] = -15;
		decl_end[1052] = -7;
		decl_start[1053] = -13;
		decl_end[1053] = -7;
		decl_start[1054] = -15;
		decl_end[1054] = -10;
		decl_start[1055] = -15;
		decl_end[1055] = -7;
		decl_start[1056] = -14;
		decl_end[1056] = -9;
		decl_start[1057] = -15;
		decl_end[1057] = -7;
		decl_start[1058] = -12;
		decl_end[1058] = -7;
		decl_start[1059] = -15;
		decl_end[1059] = -9;
		decl_start[1060] = -15;
		decl_end[1060] = -7;
		decl_start[1061] = -14;
		decl_end[1061] = -7;
		decl_start[1062] = -15;
		decl_end[1062] = -11;
		decl_start[1063] = -15;
		decl_end[1063] = -7;
		decl_start[1064] = -12;
		decl_end[1064] = -7;
		decl_start[1065] = -14;
		decl_end[1065] = -9;
		decl_start[1066] = -14;
		decl_end[1066] = -11;
		decl_start[1067] = -15;
		decl_end[1067] = -11;
		decl_start[1068] = -15;
		decl_end[1068] = -7;
		decl_start[1069] = -12;
		decl_end[1069] = -7;
		decl_start[1070] = -12;
		decl_end[1070] = -9;
		decl_start[1071] = -14;
		decl_end[1071] = -9;
		decl_start[1072] = -15;
		decl_end[1072] = -11;
		decl_start[1073] = -15;
		decl_end[1073] = -13;
		decl_start[1074] = -15;
		decl_end[1074] = -7;
		decl_start[1075] = -10;
		decl_end[1075] = -7;
		decl_start[1076] = -12;
		decl_end[1076] = -8;
		decl_start[1077] = -14;
		decl_end[1077] = -9;
		decl_start[1078] = -15;
		decl_end[1078] = -11;
		decl_start[1079] = -15;
		decl_end[1079] = -13;
		decl_start[1080] = -15;
		decl_end[1080] = -7;
		decl_start[1081] = -12;
		decl_end[1081] = -7;
		decl_start[1082] = -14;
		decl_end[1082] = -9;
		decl_start[1083] = -15;
		decl_end[1083] = -11;
		decl_start[1084] = -15;
		decl_end[1084] = -7;
		decl_start[1085] = -14;
		decl_end[1085] = -7;
		decl_start[1086] = -15;
		decl_end[1086] = -11;
		decl_start[1087] = -15;
		decl_end[1087] = -7;
		decl_start[1088] = -15;
		decl_end[1088] = -9;
		decl_start[1089] = -15;
		decl_end[1089] = -7;
		decl_start[1090] = -15;
		decl_end[1090] = -9;
		decl_start[1091] = -15;
		decl_end[1091] = -7;
		decl_start[1092] = -15;
		decl_end[1092] = -7;
		decl_start[1093] = -15;
		decl_end[1093] = -7;
		decl_start[1094] = -15;
		decl_end[1094] = -7;
		decl_start[1095] = -15;
		decl_end[1095] = -7;
		decl_start[1096] = -15;
		decl_end[1096] = -7;
		decl_start[1097] = -15;
		decl_end[1097] = -7;
		decl_start[1098] = -15;
		decl_end[1098] = -7;
		decl_start[1099] = -15;
		decl_end[1099] = -7;
		decl_start[1100] = -15;
		decl_end[1100] = -7;
		decl_start[1101] = -15;
		decl_end[1101] = -7;
		decl_start[1102] = -15;
		decl_end[1102] = -7;
		decl_start[1103] = -15;
		decl_end[1103] = -7;
		decl_start[1104] = -15;
		decl_end[1104] = -9;
		decl_start[1105] = -15;
		decl_end[1105] = -7;
		decl_start[1106] = -15;
		decl_end[1106] = -7;
		decl_start[1107] = -15;
		decl_end[1107] = -7;
		decl_start[1108] = -15;
		decl_end[1108] = -7;
		decl_start[1109] = -15;
		decl_end[1109] = -7;
		decl_start[1110] = -15;
		decl_end[1110] = -7;
		decl_start[1111] = -15;
		decl_end[1111] = -8;
		decl_start[1112] = -15;
		decl_end[1112] = -7;
		decl_start[1113] = -15;
		decl_end[1113] = -7;
		decl_start[1114] = -12;
		decl_end[1114] = -7;
		decl_start[1115] = -15;
		decl_end[1115] = -9;
		decl_start[1116] = -15;
		decl_end[1116] = -7;
		decl_start[1117] = -12;
		decl_end[1117] = -7;
		decl_start[1118] = -15;
		decl_end[1118] = -9;
		decl_start[1119] = -15;
		decl_end[1119] = -7;
		decl_start[1120] = -13;
		decl_end[1120] = -7;
		decl_start[1121] = -16;
		decl_end[1121] = -11;
		decl_start[1122] = -15;
		decl_end[1122] = -7;
		decl_start[1123] = -14;
		decl_end[1123] = -9;
		decl_start[1124] = -15;
		decl_end[1124] = -7;
		decl_start[1125] = -12;
		decl_end[1125] = -7;
		decl_start[1126] = -15;
		decl_end[1126] = -9;
		decl_start[1127] = -15;
		decl_end[1127] = -7;
		decl_start[1128] = -15;
		decl_end[1128] = -9;
		decl_start[1129] = -15;
		decl_end[1129] = -7;
		decl_start[1130] = -15;
		decl_end[1130] = -9;
		decl_start[1131] = -15;
		decl_end[1131] = -7;
		decl_start[1132] = -15;
		decl_end[1132] = -7;
		decl_start[1133] = -15;
		decl_end[1133] = -7;
		decl_start[1134] = -15;
		decl_end[1134] = -7;
		decl_start[1135] = -15;
		decl_end[1135] = -7;
		decl_start[1136] = -20;
		decl_end[1136] = -10;
		decl_start[1137] = -23;
		decl_end[1137] = -15;
		decl_start[1138] = -23;
		decl_end[1138] = -15;
		decl_start[1139] = -23;
		decl_end[1139] = -15;
		decl_start[1140] = -23;
		decl_end[1140] = -15;
		decl_start[1141] = -23;
		decl_end[1141] = -15;
		decl_start[1142] = -22;
		decl_end[1142] = -15;
		decl_start[1143] = -23;
		decl_end[1143] = -15;
		decl_start[1144] = -23;
		decl_end[1144] = -15;
		decl_start[1145] = -23;
		decl_end[1145] = -15;
		decl_start[1146] = -22;
		decl_end[1146] = -15;
		decl_start[1147] = -23;
		decl_end[1147] = -17;
		decl_start[1148] = -23;
		decl_end[1148] = -15;
		decl_start[1149] = -23;
		decl_end[1149] = -16;
		decl_start[1150] = -23;
		decl_end[1150] = -15;
		decl_start[1151] = -19;
		decl_end[1151] = -15;
		decl_start[1152] = -23;
		decl_end[1152] = -16;
		decl_start[1153] = -23;
		decl_end[1153] = -15;
		decl_start[1154] = -19;
		decl_end[1154] = -15;
		decl_start[1155] = -21;
		decl_end[1155] = -16;
		decl_start[1156] = -23;
		decl_end[1156] = -18;
		decl_start[1157] = -23;
		decl_end[1157] = -15;
		decl_start[1158] = -19;
		decl_end[1158] = -15;
		decl_start[1159] = -21;
		decl_end[1159] = -16;
		decl_start[1160] = -23;
		decl_end[1160] = -18;
		decl_start[1161] = -23;
		decl_end[1161] = -15;
		decl_start[1162] = -17;
		decl_end[1162] = -15;
		decl_start[1163] = -19;
		decl_end[1163] = -15;
		decl_start[1164] = -19;
		decl_end[1164] = -16;
		decl_start[1165] = -21;
		decl_end[1165] = -16;
		decl_start[1166] = -21;
		decl_end[1166] = -18;
		decl_start[1167] = -23;
		decl_end[1167] = -19;
		decl_start[1168] = -23;
		decl_end[1168] = -20;
		decl_start[1169] = -22;
		decl_end[1169] = -15;
		decl_start[1170] = -19;
		decl_end[1170] = -15;
		decl_start[1171] = -19;
		decl_end[1171] = -16;
		decl_start[1172] = -21;
		decl_end[1172] = -16;
		decl_start[1173] = -21;
		decl_end[1173] = -18;
		decl_start[1174] = -23;
		decl_end[1174] = -18;
		decl_start[1175] = -23;
		decl_end[1175] = -20;
		decl_start[1176] = -23;
		decl_end[1176] = -15;
		decl_start[1177] = -19;
		decl_end[1177] = -15;
		decl_start[1178] = -21;
		decl_end[1178] = -16;
		decl_start[1179] = -23;
		decl_end[1179] = -18;
		decl_start[1180] = -23;
		decl_end[1180] = -20;
		decl_start[1181] = -22;
		decl_end[1181] = -15;
		decl_start[1182] = -21;
		decl_end[1182] = -15;
		decl_start[1183] = -23;
		decl_end[1183] = -18;
		decl_start[1184] = -23;
		decl_end[1184] = -15;
		decl_start[1185] = -21;
		decl_end[1185] = -15;
		decl_start[1186] = -23;
		decl_end[1186] = -18;
		decl_start[1187] = -23;
		decl_end[1187] = -15;
		decl_start[1188] = -23;
		decl_end[1188] = -16;
		decl_start[1189] = -23;
		decl_end[1189] = -15;
		decl_start[1190] = -23;
		decl_end[1190] = -18;
		decl_start[1191] = -22;
		decl_end[1191] = -15;
		decl_start[1192] = -23;
		decl_end[1192] = -15;
		decl_start[1193] = -23;
		decl_end[1193] = -15;
		decl_start[1194] = -23;
		decl_end[1194] = -15;
		decl_start[1195] = -23;
		decl_end[1195] = -17;
		decl_start[1196] = -23;
		decl_end[1196] = -15;
		decl_start[1197] = -23;
		decl_end[1197] = -15;
		decl_start[1198] = -23;
		decl_end[1198] = -15;
		decl_start[1199] = -23;
		decl_end[1199] = -15;
		decl_start[1200] = -23;
		decl_end[1200] = -15;
		decl_start[1201] = -23;
		decl_end[1201] = -15;
		decl_start[1202] = -21;
		decl_end[1202] = -15;
		decl_start[1203] = -23;
		decl_end[1203] = -15;
		decl_start[1204] = -23;
		decl_end[1204] = -16;
		decl_start[1205] = -23;
		decl_end[1205] = -15;
		decl_start[1206] = -23;
		decl_end[1206] = -16;
		decl_start[1207] = -23;
		decl_end[1207] = -15;
		decl_start[1208] = -23;
		decl_end[1208] = -15;
		decl_start[1209] = -23;
		decl_end[1209] = -15;
		decl_start[1210] = -23;
		decl_end[1210] = -15;
		decl_start[1211] = -21;
		decl_end[1211] = -16;
		decl_start[1212] = -23;
		decl_end[1212] = -15;
		decl_start[1213] = -19;
		decl_end[1213] = -15;
		decl_start[1214] = -23;
		decl_end[1214] = -16;
		decl_start[1215] = -23;
		decl_end[1215] = -15;
		decl_start[1216] = -17;
		decl_end[1216] = -15;
		decl_start[1217] = -19;
		decl_end[1217] = -15;
		decl_start[1218] = -21;
		decl_end[1218] = -16;
		decl_start[1219] = -21;
		decl_end[1219] = -18;
		decl_start[1220] = -23;
		decl_end[1220] = -18;
		decl_start[1221] = -23;
		decl_end[1221] = -15;
		decl_start[1222] = -19;
		decl_end[1222] = -15;
		decl_start[1223] = -21;
		decl_end[1223] = -16;
		decl_start[1224] = -23;
		decl_end[1224] = -15;
		decl_start[1225] = -19;
		decl_end[1225] = -15;
		decl_start[1226] = -21;
		decl_end[1226] = -16;
		decl_start[1227] = -23;
		decl_end[1227] = -18;
		decl_start[1228] = -23;
		decl_end[1228] = -15;
		decl_start[1229] = -23;
		decl_end[1229] = -16;
		decl_start[1230] = -23;
		decl_end[1230] = -15;
		decl_start[1231] = -21;
		decl_end[1231] = -15;
		decl_start[1232] = -23;
		decl_end[1232] = -18;
		decl_start[1233] = -23;
		decl_end[1233] = -14;
		decl_start[1234] = -23;
		decl_end[1234] = -15;
		decl_start[1235] = -21;
		decl_end[1235] = -15;
		decl_start[1236] = -23;
		decl_end[1236] = -15;
		decl_start[1237] = -23;
		decl_end[1237] = -15;
		decl_start[1238] = -23;
		decl_end[1238] = -15;
		decl_start[1239] = -23;
		decl_end[1239] = -15;
		decl_start[1240] = -23;
		decl_end[1240] = -15;
		decl_start[1241] = -25;
		decl_end[1241] = -15;
		decl_start[1242] = -30;
		decl_end[1242] = -22;
		decl_start[1243] = -30;
		decl_end[1243] = -22;
		decl_start[1244] = -30;
		decl_end[1244] = -22;
		decl_start[1245] = -30;
		decl_end[1245] = -22;
		decl_start[1246] = -30;
		decl_end[1246] = -22;
		decl_start[1247] = -30;
		decl_end[1247] = -22;
		decl_start[1248] = -30;
		decl_end[1248] = -22;
		decl_start[1249] = -30;
		decl_end[1249] = -22;
		decl_start[1250] = -30;
		decl_end[1250] = -22;
		decl_start[1251] = -30;
		decl_end[1251] = -22;
		decl_start[1252] = -30;
		decl_end[1252] = -25;
		decl_start[1253] = -30;
		decl_end[1253] = -22;
		decl_start[1254] = -30;
		decl_end[1254] = -25;
		decl_start[1255] = -30;
		decl_end[1255] = -22;
		decl_start[1256] = -30;
		decl_end[1256] = -24;
		decl_start[1257] = -30;
		decl_end[1257] = -22;
		decl_start[1258] = -27;
		decl_end[1258] = -22;
		decl_start[1259] = -30;
		decl_end[1259] = -24;
		decl_start[1260] = -30;
		decl_end[1260] = -22;
		decl_start[1261] = -27;
		decl_end[1261] = -22;
		decl_start[1262] = -29;
		decl_end[1262] = -24;
		decl_start[1263] = -29;
		decl_end[1263] = -26;
		decl_start[1264] = -30;
		decl_end[1264] = -22;
		decl_start[1265] = -25;
		decl_end[1265] = -22;
		decl_start[1266] = -26;
		decl_end[1266] = -22;
		decl_start[1267] = -27;
		decl_end[1267] = -24;
		decl_start[1268] = -29;
		decl_end[1268] = -24;
		decl_start[1269] = -29;
		decl_end[1269] = -26;
		decl_start[1270] = -30;
		decl_end[1270] = -26;
		decl_start[1271] = -30;
		decl_end[1271] = -22;
		decl_start[1272] = -25;
		decl_end[1272] = -22;
		decl_start[1273] = -25;
		decl_end[1273] = -22;
		decl_start[1274] = -27;
		decl_end[1274] = -22;
		decl_start[1275] = -27;
		decl_end[1275] = -24;
		decl_start[1276] = -29;
		decl_end[1276] = -24;
		decl_start[1277] = -29;
		decl_end[1277] = -26;
		decl_start[1278] = -30;
		decl_end[1278] = -26;
		decl_start[1279] = -30;
		decl_end[1279] = -28;
		decl_start[1280] = -30;
		decl_end[1280] = -22;
		decl_start[1281] = -25;
		decl_end[1281] = -22;
		decl_start[1282] = -27;
		decl_end[1282] = -22;
		decl_start[1283] = -27;
		decl_end[1283] = -24;
		decl_start[1284] = -29;
		decl_end[1284] = -24;
		decl_start[1285] = -29;
		decl_end[1285] = -26;
		decl_start[1286] = -30;
		decl_end[1286] = -26;
		decl_start[1287] = -30;
		decl_end[1287] = -28;
		decl_start[1288] = -30;
		decl_end[1288] = -28;
		decl_start[1289] = -30;
		decl_end[1289] = -22;
		decl_start[1290] = -27;
		decl_end[1290] = -22;
		decl_start[1291] = -29;
		decl_end[1291] = -24;
		decl_start[1292] = -29;
		decl_end[1292] = -26;
		decl_start[1293] = -30;
		decl_end[1293] = -26;
		decl_start[1294] = -30;
		decl_end[1294] = -22;
		decl_start[1295] = -28;
		decl_end[1295] = -22;
		decl_start[1296] = -30;
		decl_end[1296] = -26;
		decl_start[1297] = -30;
		decl_end[1297] = -22;
		decl_start[1298] = -29;
		decl_end[1298] = -22;
		decl_start[1299] = -30;
		decl_end[1299] = -26;
		decl_start[1300] = -30;
		decl_end[1300] = -22;
		decl_start[1301] = -30;
		decl_end[1301] = -24;
		decl_start[1302] = -30;
		decl_end[1302] = -22;
		decl_start[1303] = -29;
		decl_end[1303] = -22;
		decl_start[1304] = -30;
		decl_end[1304] = -22;
		decl_start[1305] = -27;
		decl_end[1305] = -22;
		decl_start[1306] = -30;
		decl_end[1306] = -24;
		decl_start[1307] = -30;
		decl_end[1307] = -22;
		decl_start[1308] = -30;
		decl_end[1308] = -24;
		decl_start[1309] = -30;
		decl_end[1309] = -22;
		decl_start[1310] = -30;
		decl_end[1310] = -22;
		decl_start[1311] = -29;
		decl_end[1311] = -22;
		decl_start[1312] = -30;
		decl_end[1312] = -22;
		decl_start[1313] = -30;
		decl_end[1313] = -23;
		decl_start[1314] = -30;
		decl_end[1314] = -22;
		decl_start[1315] = -30;
		decl_end[1315] = -24;
		decl_start[1316] = -30;
		decl_end[1316] = -22;
		decl_start[1317] = -29;
		decl_end[1317] = -24;
		decl_start[1318] = -30;
		decl_end[1318] = -22;
		decl_start[1319] = -29;
		decl_end[1319] = -22;
		decl_start[1320] = -30;
		decl_end[1320] = -22;
		decl_start[1321] = -29;
		decl_end[1321] = -22;
		decl_start[1322] = -30;
		decl_end[1322] = -26;
		decl_start[1323] = -30;
		decl_end[1323] = -22;
		decl_start[1324] = -30;
		decl_end[1324] = -24;
		decl_start[1325] = -30;
		decl_end[1325] = -22;
		decl_start[1326] = -29;
		decl_end[1326] = -24;
		decl_start[1327] = -30;
		decl_end[1327] = -26;
		decl_start[1328] = -30;
		decl_end[1328] = -22;
		decl_start[1329] = -30;
		decl_end[1329] = -24;
		decl_start[1330] = -30;
		decl_end[1330] = -22;
		decl_start[1331] = -27;
		decl_end[1331] = -22;
		decl_start[1332] = -29;
		decl_end[1332] = -24;
		decl_start[1333] = -30;
		decl_end[1333] = -26;
		decl_start[1334] = -30;
		decl_end[1334] = -22;
		decl_start[1335] = -27;
		decl_end[1335] = -22;
		decl_start[1336] = -29;
		decl_end[1336] = -24;
		decl_start[1337] = -30;
		decl_end[1337] = -22;
		decl_start[1338] = -27;
		decl_end[1338] = -22;
		decl_start[1339] = -29;
		decl_end[1339] = -24;
		decl_start[1340] = -30;
		decl_end[1340] = -22;
		decl_start[1341] = -27;
		decl_end[1341] = -22;
		decl_start[1342] = -30;
		decl_end[1342] = -24;
		decl_start[1343] = -30;
		decl_end[1343] = -22;
		decl_start[1344] = -29;
		decl_end[1344] = -24;
		decl_start[1345] = -30;
		decl_end[1345] = -22;
		decl_start[1346] = -29;
		decl_end[1346] = -22;
		decl_start[1347] = -31;
		decl_end[1347] = -22;
		decl_start[1348] = -29;
		decl_end[1348] = -22;
		decl_start[1349] = -30;
		decl_end[1349] = -22;
		decl_start[1350] = -30;
		decl_end[1350] = -25;
		decl_start[1351] = -30;
		decl_end[1351] = -22;
		decl_start[1352] = -30;
		decl_end[1352] = -22;
		decl_start[1353] = -30;
		decl_end[1353] = -22;
		decl_start[1354] = -30;
		decl_end[1354] = -22;
		decl_start[1355] = -38;
		decl_end[1355] = -27;
		decl_start[1356] = -38;
		decl_end[1356] = -30;
		decl_start[1357] = -38;
		decl_end[1357] = -30;
		decl_start[1358] = -38;
		decl_end[1358] = -30;
		decl_start[1359] = -38;
		decl_end[1359] = -30;
		decl_start[1360] = -38;
		decl_end[1360] = -30;
		decl_start[1361] = -38;
		decl_end[1361] = -30;
		decl_start[1362] = -38;
		decl_end[1362] = -30;
		decl_start[1363] = -38;
		decl_end[1363] = -30;
		decl_start[1364] = -38;
		decl_end[1364] = -30;
		decl_start[1365] = -38;
		decl_end[1365] = -30;
		decl_start[1366] = -38;
		decl_end[1366] = -32;
		decl_start[1367] = -38;
		decl_end[1367] = -30;
		decl_start[1368] = -38;
		decl_end[1368] = -30;
		decl_start[1369] = -38;
		decl_end[1369] = -30;
		decl_start[1370] = -34;
		decl_end[1370] = -30;
		decl_start[1371] = -38;
		decl_end[1371] = -33;
		decl_start[1372] = -38;
		decl_end[1372] = -30;
		decl_start[1373] = -34;
		decl_end[1373] = -30;
		decl_start[1374] = -36;
		decl_end[1374] = -31;
		decl_start[1375] = -38;
		decl_end[1375] = -30;
		decl_start[1376] = -32;
		decl_end[1376] = -30;
		decl_start[1377] = -34;
		decl_end[1377] = -30;
		decl_start[1378] = -36;
		decl_end[1378] = -31;
		decl_start[1379] = -38;
		decl_end[1379] = -33;
		decl_start[1380] = -38;
		decl_end[1380] = -30;
		decl_start[1381] = -32;
		decl_end[1381] = -30;
		decl_start[1382] = -34;
		decl_end[1382] = -30;
		decl_start[1383] = -34;
		decl_end[1383] = -31;
		decl_start[1384] = -36;
		decl_end[1384] = -33;
		decl_start[1385] = -38;
		decl_end[1385] = -33;
		decl_start[1386] = -38;
		decl_end[1386] = -30;
		decl_start[1387] = -32;
		decl_end[1387] = -30;
		decl_start[1388] = -34;
		decl_end[1388] = -30;
		decl_start[1389] = -34;
		decl_end[1389] = -31;
		decl_start[1390] = -36;
		decl_end[1390] = -31;
		decl_start[1391] = -36;
		decl_end[1391] = -33;
		decl_start[1392] = -38;
		decl_end[1392] = -33;
		decl_start[1393] = -38;
		decl_end[1393] = -35;
		decl_start[1394] = -38;
		decl_end[1394] = -30;
		decl_start[1395] = -34;
		decl_end[1395] = -30;
		decl_start[1396] = -34;
		decl_end[1396] = -31;
		decl_start[1397] = -36;
		decl_end[1397] = -31;
		decl_start[1398] = -38;
		decl_end[1398] = -33;
		decl_start[1399] = -38;
		decl_end[1399] = -35;
		decl_start[1400] = -38;
		decl_end[1400] = -30;
		decl_start[1401] = -34;
		decl_end[1401] = -30;
		decl_start[1402] = -36;
		decl_end[1402] = -31;
		decl_start[1403] = -36;
		decl_end[1403] = -33;
		decl_start[1404] = -38;
		decl_end[1404] = -33;
		decl_start[1405] = -38;
		decl_end[1405] = -30;
		decl_start[1406] = -34;
		decl_end[1406] = -30;
		decl_start[1407] = -36;
		decl_end[1407] = -31;
		decl_start[1408] = -38;
		decl_end[1408] = -33;
		decl_start[1409] = -38;
		decl_end[1409] = -30;
		decl_start[1410] = -36;
		decl_end[1410] = -31;
		decl_start[1411] = -38;
		decl_end[1411] = -33;
		decl_start[1412] = -38;
		decl_end[1412] = -30;
		decl_start[1413] = -36;
		decl_end[1413] = -30;
		decl_start[1414] = -38;
		decl_end[1414] = -33;
		decl_start[1415] = -38;
		decl_end[1415] = -30;
		decl_start[1416] = -36;
		decl_end[1416] = -31;
		decl_start[1417] = -38;
		decl_end[1417] = -30;
		decl_start[1418] = -34;
		decl_end[1418] = -30;
		decl_start[1419] = -38;
		decl_end[1419] = -31;
		decl_start[1420] = -38;
		decl_end[1420] = -30;
		decl_start[1421] = -36;
		decl_end[1421] = -31;
		decl_start[1422] = -38;
		decl_end[1422] = -30;
		decl_start[1423] = -36;
		decl_end[1423] = -30;
		decl_start[1424] = -38;
		decl_end[1424] = -33;
		decl_start[1425] = -38;
		decl_end[1425] = -30;
		decl_start[1426] = -36;
		decl_end[1426] = -31;
		decl_start[1427] = -38;
		decl_end[1427] = -30;
		decl_start[1428] = -34;
		decl_end[1428] = -30;
		decl_start[1429] = -38;
		decl_end[1429] = -31;
		decl_start[1430] = -38;
		decl_end[1430] = -30;
		decl_start[1431] = -34;
		decl_end[1431] = -30;
		decl_start[1432] = -38;
		decl_end[1432] = -33;
		decl_start[1433] = -38;
		decl_end[1433] = -30;
		decl_start[1434] = -34;
		decl_end[1434] = -30;
		decl_start[1435] = -38;
		decl_end[1435] = -31;
		decl_start[1436] = -38;
		decl_end[1436] = -30;
		decl_start[1437] = -34;
		decl_end[1437] = -30;
		decl_start[1438] = -38;
		decl_end[1438] = -31;
		decl_start[1439] = -38;
		decl_end[1439] = -30;
		decl_start[1440] = -34;
		decl_end[1440] = -30;
		decl_start[1441] = -36;
		decl_end[1441] = -31;
		decl_start[1442] = -38;
		decl_end[1442] = -33;
		decl_start[1443] = -38;
		decl_end[1443] = -30;
		decl_start[1444] = -34;
		decl_end[1444] = -30;
		decl_start[1445] = -34;
		decl_end[1445] = -31;
		decl_start[1446] = -36;
		decl_end[1446] = -32;
		decl_start[1447] = -38;
		decl_end[1447] = -33;
		decl_start[1448] = -38;
		decl_end[1448] = -30;
		decl_start[1449] = -34;
		decl_end[1449] = -30;
		decl_start[1450] = -36;
		decl_end[1450] = -31;
		decl_start[1451] = -38;
		decl_end[1451] = -33;
		decl_start[1452] = -38;
		decl_end[1452] = -30;
		decl_start[1453] = -34;
		decl_end[1453] = -30;
		decl_start[1454] = -36;
		decl_end[1454] = -31;
		decl_start[1455] = -38;
		decl_end[1455] = -33;
		decl_start[1456] = -38;
		decl_end[1456] = -30;
		decl_start[1457] = -36;
		decl_end[1457] = -30;
		decl_start[1458] = -38;
		decl_end[1458] = -31;
		decl_start[1459] = -34;
		decl_end[1459] = -30;
		decl_start[1460] = -38;
		decl_end[1460] = -31;
		decl_start[1461] = -38;
		decl_end[1461] = -30;
		decl_start[1462] = -36;
		decl_end[1462] = -31;
		decl_start[1463] = -38;
		decl_end[1463] = -30;
		decl_start[1464] = -36;
		decl_end[1464] = -30;
		decl_start[1465] = -38;
		decl_end[1465] = -30;
		decl_start[1466] = -38;
		decl_end[1466] = -30;
		decl_start[1467] = -38;
		decl_end[1467] = -30;
		decl_start[1468] = -38;
		decl_end[1468] = -30;
		decl_start[1469] = -38;
		decl_end[1469] = -30;
		decl_start[1470] = -38;
		decl_end[1470] = -30;
		decl_start[1471] = -43;
		decl_end[1471] = -35;
		decl_start[1472] = -45;
		decl_end[1472] = -37;
		decl_start[1473] = -45;
		decl_end[1473] = -37;
		decl_start[1474] = -45;
		decl_end[1474] = -37;
		decl_start[1475] = -45;
		decl_end[1475] = -37;
		decl_start[1476] = -45;
		decl_end[1476] = -37;
		decl_start[1477] = -45;
		decl_end[1477] = -37;
		decl_start[1478] = -45;
		decl_end[1478] = -37;
		decl_start[1479] = -45;
		decl_end[1479] = -40;
		decl_start[1480] = -45;
		decl_end[1480] = -37;
		decl_start[1481] = -45;
		decl_end[1481] = -37;
		decl_start[1482] = -43;
		decl_end[1482] = -37;
		decl_start[1483] = -45;
		decl_end[1483] = -40;
		decl_start[1484] = -45;
		decl_end[1484] = -37;
		decl_start[1485] = -44;
		decl_end[1485] = -39;
		decl_start[1486] = -45;
		decl_end[1486] = -41;
		decl_start[1487] = -45;
		decl_end[1487] = -37;
		decl_start[1488] = -44;
		decl_end[1488] = -39;
		decl_start[1489] = -45;
		decl_end[1489] = -41;
		decl_start[1490] = -45;
		decl_end[1490] = -37;
		decl_start[1491] = -42;
		decl_end[1491] = -37;
		decl_start[1492] = -44;
		decl_end[1492] = -39;
		decl_start[1493] = -45;
		decl_end[1493] = -41;
		decl_start[1494] = -45;
		decl_end[1494] = -37;
		decl_start[1495] = -42;
		decl_end[1495] = -37;
		decl_start[1496] = -43;
		decl_end[1496] = -39;
		decl_start[1497] = -44;
		decl_end[1497] = -41;
		decl_start[1498] = -45;
		decl_end[1498] = -41;
		decl_start[1499] = -45;
		decl_end[1499] = -37;
		decl_start[1500] = -40;
		decl_end[1500] = -37;
		decl_start[1501] = -42;
		decl_end[1501] = -37;
		decl_start[1502] = -42;
		decl_end[1502] = -39;
		decl_start[1503] = -44;
		decl_end[1503] = -39;
		decl_start[1504] = -44;
		decl_end[1504] = -41;
		decl_start[1505] = -45;
		decl_end[1505] = -43;
		decl_start[1506] = -45;
		decl_end[1506] = -37;
		decl_start[1507] = -40;
		decl_end[1507] = -37;
		decl_start[1508] = -42;
		decl_end[1508] = -37;
		decl_start[1509] = -42;
		decl_end[1509] = -39;
		decl_start[1510] = -44;
		decl_end[1510] = -39;
		decl_start[1511] = -45;
		decl_end[1511] = -41;
		decl_start[1512] = -45;
		decl_end[1512] = -43;
		decl_start[1513] = -45;
		decl_end[1513] = -37;
		decl_start[1514] = -42;
		decl_end[1514] = -37;
		decl_start[1515] = -44;
		decl_end[1515] = -39;
		decl_start[1516] = -44;
		decl_end[1516] = -41;
		decl_start[1517] = -45;
		decl_end[1517] = -41;
		decl_start[1518] = -45;
		decl_end[1518] = -37;
		decl_start[1519] = -42;
		decl_end[1519] = -37;
		decl_start[1520] = -42;
		decl_end[1520] = -39;
		decl_start[1521] = -44;
		decl_end[1521] = -39;
		decl_start[1522] = -45;
		decl_end[1522] = -41;
		decl_start[1523] = -45;
		decl_end[1523] = -37;
		decl_start[1524] = -42;
		decl_end[1524] = -37;
		decl_start[1525] = -44;
		decl_end[1525] = -39;
		decl_start[1526] = -45;
		decl_end[1526] = -41;
		decl_start[1527] = -45;
		decl_end[1527] = -37;
		decl_start[1528] = -42;
		decl_end[1528] = -37;
		decl_start[1529] = -45;
		decl_end[1529] = -39;
		decl_start[1530] = -45;
		decl_end[1530] = -37;
		decl_start[1531] = -42;
		decl_end[1531] = -37;
		decl_start[1532] = -45;
		decl_end[1532] = -39;
		decl_start[1533] = -45;
		decl_end[1533] = -37;
		decl_start[1534] = -42;
		decl_end[1534] = -37;
		decl_start[1535] = -45;
		decl_end[1535] = -39;
		decl_start[1536] = -45;
		decl_end[1536] = -37;
		decl_start[1537] = -43;
		decl_end[1537] = -37;
		decl_start[1538] = -45;
		decl_end[1538] = -41;
		decl_start[1539] = -45;
		decl_end[1539] = -37;
		decl_start[1540] = -42;
		decl_end[1540] = -37;
		decl_start[1541] = -44;
		decl_end[1541] = -39;
		decl_start[1542] = -45;
		decl_end[1542] = -41;
		decl_start[1543] = -45;
		decl_end[1543] = -37;
		decl_start[1544] = -42;
		decl_end[1544] = -37;
		decl_start[1545] = -44;
		decl_end[1545] = -39;
		decl_start[1546] = -45;
		decl_end[1546] = -41;
		decl_start[1547] = -45;
		decl_end[1547] = -43;
		decl_start[1548] = -40;
		decl_end[1548] = -37;
		decl_start[1549] = -42;
		decl_end[1549] = -37;
		decl_start[1550] = -44;
		decl_end[1550] = -39;
		decl_start[1551] = -45;
		decl_end[1551] = -41;
		decl_start[1552] = -45;
		decl_end[1552] = -37;
		decl_start[1553] = -42;
		decl_end[1553] = -37;
		decl_start[1554] = -45;
		decl_end[1554] = -39;
		decl_start[1555] = -45;
		decl_end[1555] = -37;
		decl_start[1556] = -40;
		decl_end[1556] = -37;
		decl_start[1557] = -42;
		decl_end[1557] = -37;
		decl_start[1558] = -44;
		decl_end[1558] = -39;
		decl_start[1559] = -45;
		decl_end[1559] = -41;
		decl_start[1560] = -45;
		decl_end[1560] = -43;
		decl_start[1561] = -45;
		decl_end[1561] = -37;
		decl_start[1562] = -42;
		decl_end[1562] = -37;
		decl_start[1563] = -42;
		decl_end[1563] = -39;
		decl_start[1564] = -44;
		decl_end[1564] = -39;
		decl_start[1565] = -45;
		decl_end[1565] = -41;
		decl_start[1566] = -45;
		decl_end[1566] = -43;
		decl_start[1567] = -45;
		decl_end[1567] = -37;
		decl_start[1568] = -42;
		decl_end[1568] = -37;
		decl_start[1569] = -44;
		decl_end[1569] = -39;
		decl_start[1570] = -45;
		decl_end[1570] = -41;
		decl_start[1571] = -45;
		decl_end[1571] = -37;
		decl_start[1572] = -42;
		decl_end[1572] = -37;
		decl_start[1573] = -44;
		decl_end[1573] = -39;
		decl_start[1574] = -45;
		decl_end[1574] = -41;
		decl_start[1575] = -45;
		decl_end[1575] = -37;
		decl_start[1576] = -44;
		decl_end[1576] = -39;
		decl_start[1577] = -45;
		decl_end[1577] = -37;
		decl_start[1578] = -42;
		decl_end[1578] = -37;
		decl_start[1579] = -45;
		decl_end[1579] = -39;
		decl_start[1580] = -45;
		decl_end[1580] = -37;
		decl_start[1581] = -44;
		decl_end[1581] = -39;
		decl_start[1582] = -45;
		decl_end[1582] = -37;
		decl_start[1583] = -44;
		decl_end[1583] = -37;
		decl_start[1584] = -45;
		decl_end[1584] = -37;
		decl_start[1585] = -45;
		decl_end[1585] = -37;
		decl_start[1586] = -45;
		decl_end[1586] = -37;
		decl_start[1587] = -45;
		decl_end[1587] = -37;
		decl_start[1588] = -48;
		decl_end[1588] = -37;
		decl_start[1589] = -52;
		decl_end[1589] = -45;
		decl_start[1590] = -53;
		decl_end[1590] = -45;
		decl_start[1591] = -53;
		decl_end[1591] = -45;
		decl_start[1592] = -53;
		decl_end[1592] = -45;
		decl_start[1593] = -53;
		decl_end[1593] = -45;
		decl_start[1594] = -53;
		decl_end[1594] = -45;
		decl_start[1595] = -53;
		decl_end[1595] = -45;
		decl_start[1596] = -53;
		decl_end[1596] = -45;
		decl_start[1597] = -53;
		decl_end[1597] = -45;
		decl_start[1598] = -53;
		decl_end[1598] = -45;
		decl_start[1599] = -53;
		decl_end[1599] = -47;
		decl_start[1600] = -53;
		decl_end[1600] = -45;
		decl_start[1601] = -51;
		decl_end[1601] = -46;
		decl_start[1602] = -53;
		decl_end[1602] = -45;
		decl_start[1603] = -49;
		decl_end[1603] = -45;
		decl_start[1604] = -51;
		decl_end[1604] = -46;
		decl_start[1605] = -53;
		decl_end[1605] = -48;
		decl_start[1606] = -53;
		decl_end[1606] = -45;
		decl_start[1607] = -49;
		decl_end[1607] = -45;
		decl_start[1608] = -51;
		decl_end[1608] = -46;
		decl_start[1609] = -53;
		decl_end[1609] = -48;
		decl_start[1610] = -53;
		decl_end[1610] = -45;
		decl_start[1611] = -49;
		decl_end[1611] = -45;
		decl_start[1612] = -49;
		decl_end[1612] = -46;
		decl_start[1613] = -51;
		decl_end[1613] = -46;
		decl_start[1614] = -53;
		decl_end[1614] = -48;
		decl_start[1615] = -53;
		decl_end[1615] = -45;
		decl_start[1616] = -49;
		decl_end[1616] = -45;
		decl_start[1617] = -49;
		decl_end[1617] = -46;
		decl_start[1618] = -51;
		decl_end[1618] = -46;
		decl_start[1619] = -51;
		decl_end[1619] = -48;
		decl_start[1620] = -53;
		decl_end[1620] = -48;
		decl_start[1621] = -53;
		decl_end[1621] = -45;
		decl_start[1622] = -47;
		decl_end[1622] = -45;
		decl_start[1623] = -49;
		decl_end[1623] = -45;
		decl_start[1624] = -51;
		decl_end[1624] = -46;
		decl_start[1625] = -53;
		decl_end[1625] = -48;
		decl_start[1626] = -53;
		decl_end[1626] = -50;
		decl_start[1627] = -53;
		decl_end[1627] = -45;
		decl_start[1628] = -47;
		decl_end[1628] = -45;
		decl_start[1629] = -49;
		decl_end[1629] = -45;
		decl_start[1630] = -51;
		decl_end[1630] = -46;
		decl_start[1631] = -51;
		decl_end[1631] = -48;
		decl_start[1632] = -53;
		decl_end[1632] = -48;
		decl_start[1633] = -53;
		decl_end[1633] = -45;
		decl_start[1634] = -49;
		decl_end[1634] = -45;
		decl_start[1635] = -49;
		decl_end[1635] = -46;
		decl_start[1636] = -51;
		decl_end[1636] = -47;
		decl_start[1637] = -53;
		decl_end[1637] = -48;
		decl_start[1638] = -53;
		decl_end[1638] = -45;
		decl_start[1639] = -49;
		decl_end[1639] = -45;
		decl_start[1640] = -51;
		decl_end[1640] = -46;
		decl_start[1641] = -53;
		decl_end[1641] = -48;
		decl_start[1642] = -53;
		decl_end[1642] = -50;
		decl_start[1643] = -53;
		decl_end[1643] = -45;
		decl_start[1644] = -49;
		decl_end[1644] = -45;
		decl_start[1645] = -51;
		decl_end[1645] = -46;
		decl_start[1646] = -53;
		decl_end[1646] = -48;
		decl_start[1647] = -53;
		decl_end[1647] = -45;
		decl_start[1648] = -49;
		decl_end[1648] = -45;
		decl_start[1649] = -51;
		decl_end[1649] = -46;
		decl_start[1650] = -53;
		decl_end[1650] = -48;
		decl_start[1651] = -53;
		decl_end[1651] = -45;
		decl_start[1652] = -49;
		decl_end[1652] = -45;
		decl_start[1653] = -51;
		decl_end[1653] = -46;
		decl_start[1654] = -53;
		decl_end[1654] = -48;
		decl_start[1655] = -53;
		decl_end[1655] = -45;
		decl_start[1656] = -47;
		decl_end[1656] = -45;
		decl_start[1657] = -49;
		decl_end[1657] = -45;
		decl_start[1658] = -51;
		decl_end[1658] = -46;
		decl_start[1659] = -53;
		decl_end[1659] = -48;
		decl_start[1660] = -53;
		decl_end[1660] = -45;
		decl_start[1661] = -47;
		decl_end[1661] = -45;
		decl_start[1662] = -49;
		decl_end[1662] = -45;
		decl_start[1663] = -51;
		decl_end[1663] = -46;
		decl_start[1664] = -51;
		decl_end[1664] = -48;
		decl_start[1665] = -53;
		decl_end[1665] = -48;
		decl_start[1666] = -53;
		decl_end[1666] = -50;
		decl_start[1667] = -53;
		decl_end[1667] = -45;
		decl_start[1668] = -49;
		decl_end[1668] = -45;
		decl_start[1669] = -49;
		decl_end[1669] = -46;
		decl_start[1670] = -51;
		decl_end[1670] = -47;
		decl_start[1671] = -53;
		decl_end[1671] = -48;
		decl_start[1672] = -53;
		decl_end[1672] = -50;
		decl_start[1673] = -53;
		decl_end[1673] = -50;
		decl_start[1674] = -52;
		decl_end[1674] = -45;
		decl_start[1675] = -49;
		decl_end[1675] = -45;
		decl_start[1676] = -49;
		decl_end[1676] = -46;
		decl_start[1677] = -51;
		decl_end[1677] = -46;
		decl_start[1678] = -53;
		decl_end[1678] = -48;
		decl_start[1679] = -53;
		decl_end[1679] = -45;
		decl_start[1680] = -47;
		decl_end[1680] = -45;
		decl_start[1681] = -49;
		decl_end[1681] = -45;
		decl_start[1682] = -51;
		decl_end[1682] = -46;
		decl_start[1683] = -51;
		decl_end[1683] = -48;
		decl_start[1684] = -53;
		decl_end[1684] = -48;
		decl_start[1685] = -53;
		decl_end[1685] = -45;
		decl_start[1686] = -49;
		decl_end[1686] = -45;
		decl_start[1687] = -51;
		decl_end[1687] = -46;
		decl_start[1688] = -53;
		decl_end[1688] = -48;
		decl_start[1689] = -53;
		decl_end[1689] = -45;
		decl_start[1690] = -49;
		decl_end[1690] = -45;
		decl_start[1691] = -51;
		decl_end[1691] = -46;
		decl_start[1692] = -53;
		decl_end[1692] = -45;
		decl_start[1693] = -49;
		decl_end[1693] = -45;
		decl_start[1694] = -53;
		decl_end[1694] = -46;
		decl_start[1695] = -53;
		decl_end[1695] = -45;
		decl_start[1696] = -49;
		decl_end[1696] = -45;
		decl_start[1697] = -53;
		decl_end[1697] = -46;
		decl_start[1698] = -53;
		decl_end[1698] = -45;
		decl_start[1699] = -53;
		decl_end[1699] = -46;
		decl_start[1700] = -53;
		decl_end[1700] = -45;
		decl_start[1701] = -53;
		decl_end[1701] = -47;
		decl_start[1702] = -53;
		decl_end[1702] = -45;
		decl_start[1703] = -53;
		decl_end[1703] = -45;
		decl_start[1704] = -53;
		decl_end[1704] = -45;
		decl_start[1705] = -58;
		decl_end[1705] = -50;
		decl_start[1706] = -60;
		decl_end[1706] = -52;
		decl_start[1707] = -60;
		decl_end[1707] = -52;
		decl_start[1708] = -60;
		decl_end[1708] = -52;
		decl_start[1709] = -60;
		decl_end[1709] = -52;
		decl_start[1710] = -60;
		decl_end[1710] = -52;
		decl_start[1711] = -60;
		decl_end[1711] = -52;
		decl_start[1712] = -60;
		decl_end[1712] = -55;
		decl_start[1713] = -60;
		decl_end[1713] = -52;
		decl_start[1714] = -60;
		decl_end[1714] = -55;
		decl_start[1715] = -60;
		decl_end[1715] = -52;
		decl_start[1716] = -59;
		decl_end[1716] = -54;
		decl_start[1717] = -60;
		decl_end[1717] = -52;
		decl_start[1718] = -57;
		decl_end[1718] = -52;
		decl_start[1719] = -59;
		decl_end[1719] = -54;
		decl_start[1720] = -60;
		decl_end[1720] = -56;
		decl_start[1721] = -60;
		decl_end[1721] = -52;
		decl_start[1722] = -57;
		decl_end[1722] = -52;
		decl_start[1723] = -59;
		decl_end[1723] = -54;
		decl_start[1724] = -60;
		decl_end[1724] = -52;
		decl_start[1725] = -55;
		decl_end[1725] = -52;
		decl_start[1726] = -57;
		decl_end[1726] = -52;
		decl_start[1727] = -59;
		decl_end[1727] = -54;
		decl_start[1728] = -60;
		decl_end[1728] = -56;
		decl_start[1729] = -60;
		decl_end[1729] = -52;
		decl_start[1730] = -55;
		decl_end[1730] = -52;
		decl_start[1731] = -57;
		decl_end[1731] = -52;
		decl_start[1732] = -57;
		decl_end[1732] = -54;
		decl_start[1733] = -58;
		decl_end[1733] = -54;
		decl_start[1734] = -59;
		decl_end[1734] = -56;
		decl_start[1735] = -60;
		decl_end[1735] = -56;
		decl_start[1736] = -60;
		decl_end[1736] = -58;
		decl_start[1737] = -60;
		decl_end[1737] = -52;
		decl_start[1738] = -55;
		decl_end[1738] = -52;
		decl_start[1739] = -57;
		decl_end[1739] = -52;
		decl_start[1740] = -57;
		decl_end[1740] = -54;
		decl_start[1741] = -59;
		decl_end[1741] = -54;
		decl_start[1742] = -59;
		decl_end[1742] = -56;
		decl_start[1743] = -59;
		decl_end[1743] = -56;
		decl_start[1744] = -60;
		decl_end[1744] = -56;
		decl_start[1745] = -60;
		decl_end[1745] = -58;
		decl_start[1746] = -60;
		decl_end[1746] = -58;
		decl_start[1747] = -60;
		decl_end[1747] = -52;
		decl_start[1748] = -55;
		decl_end[1748] = -52;
		decl_start[1749] = -57;
		decl_end[1749] = -52;
		decl_start[1750] = -57;
		decl_end[1750] = -54;
		decl_start[1751] = -59;
		decl_end[1751] = -54;
		decl_start[1752] = -59;
		decl_end[1752] = -56;
		decl_start[1753] = -60;
		decl_end[1753] = -56;
		decl_start[1754] = -60;
		decl_end[1754] = -58;
		decl_start[1755] = -60;
		decl_end[1755] = -58;
		decl_start[1756] = -60;
		decl_end[1756] = -58;
		decl_start[1757] = -60;
		decl_end[1757] = -52;
		decl_start[1758] = -55;
		decl_end[1758] = -52;
		decl_start[1759] = -57;
		decl_end[1759] = -52;
		decl_start[1760] = -57;
		decl_end[1760] = -54;
		decl_start[1761] = -59;
		decl_end[1761] = -54;
		decl_start[1762] = -60;
		decl_end[1762] = -56;
		decl_start[1763] = -60;
		decl_end[1763] = -58;
		decl_start[1764] = -60;
		decl_end[1764] = -53;
		decl_start[1765] = -55;
		decl_end[1765] = -52;
		decl_start[1766] = -57;
		decl_end[1766] = -52;
		decl_start[1767] = -59;
		decl_end[1767] = -54;
		decl_start[1768] = -59;
		decl_end[1768] = -56;
		decl_start[1769] = -60;
		decl_end[1769] = -56;
		decl_start[1770] = -60;
		decl_end[1770] = -58;
		decl_start[1771] = -60;
		decl_end[1771] = -52;
		decl_start[1772] = -57;
		decl_end[1772] = -52;
		decl_start[1773] = -59;
		decl_end[1773] = -54;
		decl_start[1774] = -59;
		decl_end[1774] = -56;
		decl_start[1775] = -60;
		decl_end[1775] = -56;
		decl_start[1776] = -60;
		decl_end[1776] = -58;
		decl_start[1777] = -60;
		decl_end[1777] = -52;
		decl_start[1778] = -57;
		decl_end[1778] = -52;
		decl_start[1779] = -57;
		decl_end[1779] = -54;
		decl_start[1780] = -59;
		decl_end[1780] = -54;
		decl_start[1781] = -60;
		decl_end[1781] = -56;
		decl_start[1782] = -60;
		decl_end[1782] = -58;
		decl_start[1783] = -60;
		decl_end[1783] = -52;
		decl_start[1784] = -55;
		decl_end[1784] = -52;
		decl_start[1785] = -57;
		decl_end[1785] = -52;
		decl_start[1786] = -57;
		decl_end[1786] = -54;
		decl_start[1787] = -59;
		decl_end[1787] = -54;
		decl_start[1788] = -59;
		decl_end[1788] = -56;
		decl_start[1789] = -60;
		decl_end[1789] = -56;
		decl_start[1790] = -60;
		decl_end[1790] = -52;
		decl_start[1791] = -55;
		decl_end[1791] = -52;
		decl_start[1792] = -55;
		decl_end[1792] = -52;
		decl_start[1793] = -57;
		decl_end[1793] = -52;
		decl_start[1794] = -57;
		decl_end[1794] = -54;
		decl_start[1795] = -59;
		decl_end[1795] = -54;
		decl_start[1796] = -59;
		decl_end[1796] = -56;
		decl_start[1797] = -60;
		decl_end[1797] = -56;
		decl_start[1798] = -60;
		decl_end[1798] = -52;
		decl_start[1799] = -57;
		decl_end[1799] = -52;
		decl_start[1800] = -57;
		decl_end[1800] = -54;
		decl_start[1801] = -59;
		decl_end[1801] = -54;
		decl_start[1802] = -60;
		decl_end[1802] = -56;
		decl_start[1803] = -60;
		decl_end[1803] = -52;
		decl_start[1804] = -57;
		decl_end[1804] = -52;
		decl_start[1805] = -59;
		decl_end[1805] = -54;
		decl_start[1806] = -60;
		decl_end[1806] = -52;
		decl_start[1807] = -57;
		decl_end[1807] = -52;
		decl_start[1808] = -59;
		decl_end[1808] = -54;
		decl_start[1809] = -60;
		decl_end[1809] = -52;
		decl_start[1810] = -57;
		decl_end[1810] = -52;
		decl_start[1811] = -60;
		decl_end[1811] = -54;
		decl_start[1812] = -60;
		decl_end[1812] = -52;
		decl_start[1813] = -59;
		decl_end[1813] = -52;
		decl_start[1814] = -60;
		decl_end[1814] = -52;
		decl_start[1815] = -60;
		decl_end[1815] = -53;
		decl_start[1816] = -60;
		decl_end[1816] = -52;
		decl_start[1817] = -60;
		decl_end[1817] = -52;
		decl_start[1818] = -60;
		decl_end[1818] = -52;
		decl_start[1819] = -63;
		decl_end[1819] = -55;
		decl_start[1820] = -68;
		decl_end[1820] = -60;
		decl_start[1821] = -68;
		decl_end[1821] = -60;
		decl_start[1822] = -68;
		decl_end[1822] = -60;
		decl_start[1823] = -65;
		decl_end[1823] = -60;
		decl_start[1824] = -68;
		decl_end[1824] = -60;
		decl_start[1825] = -68;
		decl_end[1825] = -60;
		decl_start[1826] = -68;
		decl_end[1826] = -60;
		decl_start[1827] = -66;
		decl_end[1827] = -61;
		decl_start[1828] = -68;
		decl_end[1828] = -60;
		decl_start[1829] = -64;
		decl_end[1829] = -60;
		decl_start[1830] = -66;
		decl_end[1830] = -61;
		decl_start[1831] = -68;
		decl_end[1831] = -60;
		decl_start[1832] = -64;
		decl_end[1832] = -60;
		decl_start[1833] = -66;
		decl_end[1833] = -61;
		decl_start[1834] = -68;
		decl_end[1834] = -63;
		decl_start[1835] = -68;
		decl_end[1835] = -60;
		decl_start[1836] = -64;
		decl_end[1836] = -60;
		decl_start[1837] = -66;
		decl_end[1837] = -61;
		decl_start[1838] = -68;
		decl_end[1838] = -63;
		decl_start[1839] = -68;
		decl_end[1839] = -60;
		decl_start[1840] = -62;
		decl_end[1840] = -60;
		decl_start[1841] = -62;
		decl_end[1841] = -60;
		decl_start[1842] = -64;
		decl_end[1842] = -60;
		decl_start[1843] = -66;
		decl_end[1843] = -61;
		decl_start[1844] = -68;
		decl_end[1844] = -63;
		decl_start[1845] = -68;
		decl_end[1845] = -65;
		decl_start[1846] = -68;
		decl_end[1846] = -60;
		decl_start[1847] = -62;
		decl_end[1847] = -59;
		decl_start[1848] = -62;
		decl_end[1848] = -60;
		decl_start[1849] = -62;
		decl_end[1849] = -60;
		decl_start[1850] = -64;
		decl_end[1850] = -60;
		decl_start[1851] = -66;
		decl_end[1851] = -61;
		decl_start[1852] = -66;
		decl_end[1852] = -63;
		decl_start[1853] = -68;
		decl_end[1853] = -63;
		decl_start[1854] = -66;
		decl_end[1854] = -60;
		decl_start[1855] = -62;
		decl_end[1855] = -60;
		decl_start[1856] = -62;
		decl_end[1856] = -60;
		decl_start[1857] = -64;
		decl_end[1857] = -60;
		decl_start[1858] = -64;
		decl_end[1858] = -61;
		decl_start[1859] = -64;
		decl_end[1859] = -61;
		decl_start[1860] = -66;
		decl_end[1860] = -61;
		decl_start[1861] = -66;
		decl_end[1861] = -63;
		decl_start[1862] = -68;
		decl_end[1862] = -64;
		decl_start[1863] = -68;
		decl_end[1863] = -60;
		decl_start[1864] = -62;
		decl_end[1864] = -60;
		decl_start[1865] = -64;
		decl_end[1865] = -60;
		decl_start[1866] = -64;
		decl_end[1866] = -61;
		decl_start[1867] = -64;
		decl_end[1867] = -61;
		decl_start[1868] = -66;
		decl_end[1868] = -62;
		decl_start[1869] = -68;
		decl_end[1869] = -63;
		decl_start[1870] = -68;
		decl_end[1870] = -65;
		decl_start[1871] = -68;
		decl_end[1871] = -60;
		decl_start[1872] = -62;
		decl_end[1872] = -60;
		decl_start[1873] = -64;
		decl_end[1873] = -60;
		decl_start[1874] = -64;
		decl_end[1874] = -61;
		decl_start[1875] = -64;
		decl_end[1875] = -61;
		decl_start[1876] = -66;
		decl_end[1876] = -61;
		decl_start[1877] = -66;
		decl_end[1877] = -63;
		decl_start[1878] = -68;
		decl_end[1878] = -63;
		decl_start[1879] = -68;
		decl_end[1879] = -60;
		decl_start[1880] = -62;
		decl_end[1880] = -60;
		decl_start[1881] = -64;
		decl_end[1881] = -60;
		decl_start[1882] = -64;
		decl_end[1882] = -61;
		decl_start[1883] = -66;
		decl_end[1883] = -61;
		decl_start[1884] = -67;
		decl_end[1884] = -63;
		decl_start[1885] = -68;
		decl_end[1885] = -65;
		decl_start[1886] = -68;
		decl_end[1886] = -60;
		decl_start[1887] = -62;
		decl_end[1887] = -60;
		decl_start[1888] = -64;
		decl_end[1888] = -60;
		decl_start[1889] = -64;
		decl_end[1889] = -61;
		decl_start[1890] = -64;
		decl_end[1890] = -61;
		decl_start[1891] = -66;
		decl_end[1891] = -61;
		decl_start[1892] = -66;
		decl_end[1892] = -63;
		decl_start[1893] = -68;
		decl_end[1893] = -63;
		decl_start[1894] = -68;
		decl_end[1894] = -65;
		decl_start[1895] = -68;
		decl_end[1895] = -60;
		decl_start[1896] = -64;
		decl_end[1896] = -60;
		decl_start[1897] = -66;
		decl_end[1897] = -61;
		decl_start[1898] = -68;
		decl_end[1898] = -63;
		decl_start[1899] = -68;
		decl_end[1899] = -60;
		decl_start[1900] = -64;
		decl_end[1900] = -60;
		decl_start[1901] = -66;
		decl_end[1901] = -61;
		decl_start[1902] = -68;
		decl_end[1902] = -63;
		decl_start[1903] = -68;
		decl_end[1903] = -60;
		decl_start[1904] = -66;
		decl_end[1904] = -60;
		decl_start[1905] = -68;
		decl_end[1905] = -60;
		decl_start[1906] = -64;
		decl_end[1906] = -60;
		decl_start[1907] = -68;
		decl_end[1907] = -62;
		decl_start[1908] = -68;
		decl_end[1908] = -60;
		decl_start[1909] = -68;
		decl_end[1909] = -62;
		decl_start[1910] = -68;
		decl_end[1910] = -60;
		decl_start[1911] = -68;
		decl_end[1911] = -62;
		decl_start[1912] = -73;
		decl_end[1912] = -65;
		decl_start[1913] = -76;
		decl_end[1913] = -70;
		decl_start[1914] = -75;
		decl_end[1914] = -67;
		decl_start[1915] = -75;
		decl_end[1915] = -70;
		decl_start[1916] = -75;
		decl_end[1916] = -67;
		decl_start[1917] = -75;
		decl_end[1917] = -70;
		decl_start[1918] = -72;
		decl_end[1918] = -67;
		decl_start[1919] = -74;
		decl_end[1919] = -69;
		decl_start[1920] = -75;
		decl_end[1920] = -67;
		decl_start[1921] = -72;
		decl_end[1921] = -67;
		decl_start[1922] = -75;
		decl_end[1922] = -69;
		decl_start[1923] = -75;
		decl_end[1923] = -67;
		decl_start[1924] = -72;
		decl_end[1924] = -67;
		decl_start[1925] = -74;
		decl_end[1925] = -69;
		decl_start[1926] = -75;
		decl_end[1926] = -71;
		decl_start[1927] = -75;
		decl_end[1927] = -67;
		decl_start[1928] = -70;
		decl_end[1928] = -67;
		decl_start[1929] = -72;
		decl_end[1929] = -67;
		decl_start[1930] = -74;
		decl_end[1930] = -69;
		decl_start[1931] = -75;
		decl_end[1931] = -71;
		decl_start[1932] = -75;
		decl_end[1932] = -67;
		decl_start[1933] = -72;
		decl_end[1933] = -67;
		decl_start[1934] = -72;
		decl_end[1934] = -69;
		decl_start[1935] = -74;
		decl_end[1935] = -69;
		decl_start[1936] = -75;
		decl_end[1936] = -67;
		decl_start[1937] = -70;
		decl_end[1937] = -67;
		decl_start[1938] = -72;
		decl_end[1938] = -67;
		decl_start[1939] = -72;
		decl_end[1939] = -69;
		decl_start[1940] = -74;
		decl_end[1940] = -69;
		decl_start[1941] = -75;
		decl_end[1941] = -71;
		decl_start[1942] = -75;
		decl_end[1942] = -67;
		decl_start[1943] = -70;
		decl_end[1943] = -67;
		decl_start[1944] = -72;
		decl_end[1944] = -67;
		decl_start[1945] = -72;
		decl_end[1945] = -69;
		decl_start[1946] = -74;
		decl_end[1946] = -69;
		decl_start[1947] = -75;
		decl_end[1947] = -71;
		decl_start[1948] = -75;
		decl_end[1948] = -67;
		decl_start[1949] = -70;
		decl_end[1949] = -67;
		decl_start[1950] = -71;
		decl_end[1950] = -67;
		decl_start[1951] = -72;
		decl_end[1951] = -69;
		decl_start[1952] = -74;
		decl_end[1952] = -69;
		decl_start[1953] = -75;
		decl_end[1953] = -71;
		decl_start[1954] = -75;
		decl_end[1954] = -67;
		decl_start[1955] = -72;
		decl_end[1955] = -67;
		decl_start[1956] = -74;
		decl_end[1956] = -69;
		decl_start[1957] = -75;
		decl_end[1957] = -71;
		decl_start[1958] = -75;
		decl_end[1958] = -67;
		decl_start[1959] = -74;
		decl_end[1959] = -69;
		decl_start[1960] = -75;
		decl_end[1960] = -67;
		decl_start[1961] = -72;
		decl_end[1961] = -67;
		decl_start[1962] = -75;
		decl_end[1962] = -69;
		decl_start[1963] = -75;
		decl_end[1963] = -67;
		decl_start[1964] = -74;
		decl_end[1964] = -67;
		decl_start[1965] = -77;
		decl_end[1965] = -72;
		decl_start[1966] = -81;
		decl_end[1966] = -75;
		decl_start[1967] = -83;
		decl_end[1967] = -75;
		decl_start[1968] = -81;
		decl_end[1968] = -75;
		decl_start[1969] = -83;
		decl_end[1969] = -75;
		decl_start[1970] = -79;
		decl_end[1970] = -75;
		decl_start[1971] = -83;
		decl_end[1971] = -76;
		decl_start[1972] = -83;
		decl_end[1972] = -75;
		decl_start[1973] = -81;
		decl_end[1973] = -75;
		decl_start[1974] = -83;
		decl_end[1974] = -78;
		decl_start[1975] = -83;
		decl_end[1975] = -75;
		decl_start[1976] = -81;
		decl_end[1976] = -76;
		decl_start[1977] = -83;
		decl_end[1977] = -75;
		decl_start[1978] = -77;
		decl_end[1978] = -75;
		decl_start[1979] = -79;
		decl_end[1979] = -75;
		decl_start[1980] = -81;
		decl_end[1980] = -76;
		decl_start[1981] = -83;
		decl_end[1981] = -75;
		decl_start[1982] = -79;
		decl_end[1982] = -75;
		decl_start[1983] = -81;
		decl_end[1983] = -76;
		decl_start[1984] = -83;
		decl_end[1984] = -75;
		decl_start[1985] = -79;
		decl_end[1985] = -75;
		decl_start[1986] = -81;
		decl_end[1986] = -76;
		decl_start[1987] = -83;
		decl_end[1987] = -75;
		decl_start[1988] = -81;
		decl_end[1988] = -76;
		decl_start[1989] = -85;
		decl_end[1989] = -78;
		decl_start[1990] = -87;
		decl_end[1990] = -82;
		decl_start[1991] = -90;
		decl_end[1991] = -82;
		decl_start[1992] = -87;
		decl_end[1992] = -82;
		decl_start[1993] = -89;
		decl_end[1993] = -84;
		decl_start[1994] = -90;
		decl_end[1994] = -82;
		decl_start[1995] = -87;
		decl_end[1995] = -82;
		decl_start[1996] = -90;
		decl_end[1996] = -84;
	}

	/**
	 * Sets the R.A. range of each block.
	 */
	static {
		ra_start = new int[1997];
		ra_end = new int[1997];
		decl_start = new int[1997];
		decl_end = new int[1997];

		initialize_ra();
		initialize_decl();
	}
}
